@@ -2,7 +2,7 @@
 //                                CmdLinePcr.cpp                              *
 //                               ----------------                             *
 //  Started     : 22/02/2005                                                  *
-//  Last Update : 15/03/2010                                                  *
+//  Last Update : 02/09/2011                                                  *
 //  Copyright   : (C) 2005 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -25,7 +25,7 @@ CmdLinePcr::CmdLinePcr( void ) : wxCmdLineParser( )
 {
   bClear( );
 
-  m_iArgC   = 0;
+  m_iArgC   = -1;
   m_ppsArgV = NULL;
 }
 
@@ -107,6 +107,26 @@ bool  CmdLinePcr::bProcOption_c( int * piArg )
     return( TRUE );
   }
 
+  return( TRUE );
+}
+
+//*****************************************************************************
+// Process command line option -d : Enable debug mode. Print debug info. to the
+//                                  console during program execution.
+//
+// Argument List :
+//   piArg - A pointer to the current command line argument
+//           (incremented as part of processing)
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  CmdLinePcr::bProcOption_d( int * piArg )
+{
+  g_bDebug = TRUE;
+
+  std::cout << "\nDEBUG : Debug mode enabled\n";
 
   return( TRUE );
 }
@@ -271,7 +291,8 @@ bool  CmdLinePcr::bProcOption_v( int * piArg )
 {
   wxString  os1;
 
-  os1 << APP_NAME << wxT(", ") << APP_VERSION << wxT('\n');
+  os1 << APP_NAME << wxT(", Version ") << APP_VERSION
+      << wxT(" (") << APP_DATE << wxT(")") << wxT('\n');
   std::cout << os1.mb_str( );
 
   return( FALSE );
@@ -303,8 +324,8 @@ bool  CmdLinePcr::bProcOption_w( int * piArg )
   osArg = m_ppsArgV[ *piArg ];
   osArg.MakeUpper( );
 
-  if(      wxString(CLP_GWAVE).Upper().StartsWith( osArg ) ) osArg = CLP_GWAVE;
-  else if( wxString(CLP_GAW  ).Upper().StartsWith( osArg ) ) osArg = CLP_GAW;
+  if(      wxString(CLP_GWAVE).Upper().StartsWith(osArg) ) osArg = CLP_GWAVE;
+  else if( wxString(CLP_GAW  ).Upper().StartsWith(osArg) ) osArg = CLP_GAW;
   else
   {
     std::cout << "Invalid waveform viewer specifier : "
@@ -455,6 +476,7 @@ void  CmdLinePcr::Usage( void )
       << wxT("\n")
       << wxT("OPTIONS : -h        : Print usage (this message)\n")
       << wxT("          -v        : Print version information\n")
+      << wxT("          -d        : Enable debug mode (generates console spew on standard error)\n")
       << wxT("          -r RCFILE : Specify a configuration file\n")
       << wxT("                      RCFILE = ~/.gspiceui.conf (default)\n")
       << wxT("          -c        : Rebuild/clean the configuration file\n")
@@ -465,11 +487,11 @@ void  CmdLinePcr::Usage( void )
       << wxT("          -g [PROC] : Guile procedure for importing a schematic file with gNetList\n")
       << wxT("                      PROC   = spice-sdb (default), pcb, protelii, verilog, etc.\n")
       << wxT("          -w VIEWER : Specify the waveform viewer to be used\n")
-      << wxT("                      VIEWER = gwave (default) or gaw\n")
+      << wxT("                      VIEWER = gwave (default), gaw or gwave2\n")
       << wxT("\n")
       << wxT("ARGS    : FILE/S    : Import schematic file/s or load a circuit description file\n")
       << wxT("\n")
-      << wxT("NOTES   : Option -s must come before -a if both are specified\n")
+      << wxT("NOTES   : Option -s should come before -a if both are specified\n")
       << wxT("\n");
 
   std::cout << os1.mb_str( );
@@ -482,8 +504,9 @@ void  CmdLinePcr::Version( void )
 {
   wxString  os1;
 
-  os1 << wxT("\n            ") << APP_NAME
-      << wxT("\n  ") << APP_VERSION << wxT("\n\n");
+  os1 << wxT("\n           ") << APP_NAME
+      << wxT("\n  Version ") << APP_VERSION << wxT(" (") << APP_DATE
+      << wxT(")\n\n");
 
   std::cout << os1.mb_str( );
 }
@@ -661,12 +684,14 @@ bool  CmdLinePcr::bProcArgs( void )
   int       iArg;
 
   // Check validity of arguments
-  if( m_iArgC <= 0 )                 return( FALSE );
-  if( *m_ppsArgV == NULL )           return( FALSE );
+  if( m_iArgC   <= 0 )               return( FALSE );
+  if( m_ppsArgV == NULL )            return( FALSE );
 
   // Process options
-  for( iArg=1, osArg=m_ppsArgV[1]; iArg<m_iArgC; ++iArg, osArg=m_ppsArgV[iArg] )
+  for( iArg=1; iArg<m_iArgC; ++iArg )
   {
+    osArg = (wxChar *) m_ppsArgV[ iArg ];
+
     if( osArg.GetChar( 0 )=='-' && osArg.Length( )>2 )
     { // Found concatenated options --> error
       std::cout << "Options must be specfied separately : " << osArg.mb_str( ) << '\n';
@@ -680,6 +705,10 @@ bool  CmdLinePcr::bProcArgs( void )
     { // Print usage information
       if( ! bProcOption_h( &iArg ) ) return( FALSE );
     }
+    else if( osArg == wxT("-d") )
+    { // Enable debug mode
+      if( ! bProcOption_d( &iArg ) ) return( FALSE );
+    }
     else if( osArg == wxT("-r") )
     { // Specify a configuration file
       if( ! bProcOption_r( &iArg ) ) return( FALSE );
@@ -758,7 +787,7 @@ void  CmdLinePcr::Print( const wxString & rosPrefix )
   osPrefix = rosPrefix + wxT( "CmdLinePcr::" );
 
   std::cout << osPrefix .mb_str( ) << "m_iArgC            : "
-       << m_iArgC << '\n';
+            << m_iArgC << '\n';
 
   std::cout << osPrefix .mb_str( ) << "m_ppsArgV          :";
   for( i1=0; i1<m_iArgC; i1++ )
@@ -769,22 +798,22 @@ void  CmdLinePcr::Print( const wxString & rosPrefix )
   std::cout << '\n';
 
   std::cout << osPrefix .mb_str( ) << "m_osSimrType       : "
-       << m_osSimrType  .mb_str( ) << '\n';
+            << m_osSimrType  .mb_str( ) << '\n';
 
   std::cout << osPrefix .mb_str( ) << "m_osAnaType        : "
-       << m_osAnaType   .mb_str( ) << '\n';
+            << m_osAnaType   .mb_str( ) << '\n';
 
   std::cout << osPrefix .mb_str( ) << "m_osGuileProc      : "
-       << m_osGuileProc .mb_str( ) << '\n';
+            << m_osGuileProc .mb_str( ) << '\n';
 
   std::cout << osPrefix .mb_str( ) << "m_osViewer         : "
-       << m_osViewer    .mb_str( ) << '\n';
+            << m_osViewer    .mb_str( ) << '\n';
 
   std::cout << osPrefix .mb_str( ) << "m_osConfigFile     : "
-       << m_osConfigFile.mb_str( ) << '\n';
+            << m_osConfigFile.mb_str( ) << '\n';
 
   std::cout << osPrefix .mb_str( ) << "m_osNetLstFile     : "
-       << m_osNetLstFile.mb_str( ) << '\n';
+            << m_osNetLstFile.mb_str( ) << '\n';
 
   std::cout << osPrefix .mb_str( ) << "m_osaSchemFiles[ ] : ";
   for( i1=0; i1<(int)m_osaSchemFiles.GetCount( ); i1++ )
