@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                                TypeDefs.hpp                                *
 //                               --------------                               *
-//  Description : This header file mostly contains enumerated type            *
-//                definitions which may be used anywhere in the application.  *
-//  Started     : 06/09/2007                                                  *
-//  Last Update : 16/04/2010                                                  *
-//  Copyright   : (C) 2007 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : This header file mostly contains enumerated type             *
+//               definitions which may be used anywhere in the application.   *
+// Started     : 06/09/2007                                                   *
+// Last Update : 23/06/2011                                                   *
+// Copyright   : (C) 2007 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -21,11 +21,19 @@
 #ifndef TYPEDEFS_HPP
 #define TYPEDEFS_HPP
 
-// wxWindows Includes
+// System Includes
+
+#include <climits>
+
+// wxWidgets Includes
 
 #include <wx/wx.h>
 #include <wx/filename.h>
 
+// External Variables
+
+extern  bool  g_bDebug;
+
 //*****************************************************************************
 // Type definitions
 
@@ -35,6 +43,12 @@ typedef   unsigned char   uchar;
 
 typedef   wxStaticText    wxLabel;
 
+//*****************************************************************************
+// Useful #defines
+
+#define  NOVAL_INT  -INT_MAX
+#define  NOVAL_FLT  -FLT_MAX
+
 //*****************************************************************************
 // Fonts
 
@@ -129,6 +143,23 @@ enum  eCpntType
   eCPNT_LST = eCPNT_SUBCKT
 };
 
+// The various variable types supported by this class
+enum eVarType
+{
+  eVAR_BIN = 0, // Binary
+  eVAR_OCT,     // Octal
+  eVAR_HEX,     // Hexadecimal
+  eVAR_INT,     // Integer
+  eVAR_FLT,     // Floating point
+  eVAR_SCI,     // Floating point (scientific  notation)
+  eVAR_ENG,     // Floating point (engineering notation)
+
+  eVAR_NONE,    // No variable type specified
+
+  eVAR_FST = eVAR_INT,
+  eVAR_LST = eVAR_ENG
+};
+
 // Enumerated type for the various types of units
 enum eUnitsType
 {
@@ -220,7 +251,7 @@ enum eTypeTmpFileMgt
 //*****************************************************************************
 // Declare new array types (which are based on wxWidgets types)
 
-WX_DECLARE_OBJARRAY( wxFileName, ArrayFileName  );
+WX_DECLARE_OBJARRAY( wxFileName, ArrayFileName );
 
 //*****************************************************************************
 
