@@ -5,7 +5,7 @@
 // Started     : 15/08/2003                                                   *
 // Last Update : Refer below                                                  *
 // Copyright   : (C) 2003 by MSWaters                                         *
-// Email       : M.Waters@bom.gov.au                                          *
+// Email       : m.waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -21,7 +21,8 @@
 #define VERSION_HPP
 
 #define  APP_NAME       wxT("gSpiceUI")
-#define  APP_VERSION    wxT("Version 0.9.99 Alpha (16/04/2010)")
+#define  APP_VERSION    wxT("1.0.00")
+#define  APP_DATE       wxT("23/09/2011")
 #define  APP_COPYRIGHT  wxT("Copyright (c) MSWaters 2003")
 
 #endif // VERSION_HPP
@@ -29,29 +30,81 @@
 //*****************************************************************************
 // THINGS TO DO before v1.0.00 :
 //
-// (19/04/2010) Check that all the example schematics work.
-// (19/04/2010) Documentation.
-// (15/04/2010) Locale stuff still appears to be broken.
-// (30/03/2010) If a schematic file is open in gSchem a gSpiceUI reload
-//              operation kills gSchem.
-// (26/03/2010) Apparently, gSpiceUI opens new FIFOs every time gWave, etc. are
-//              started but never closes them. In a long session the user
-//              eventually runs out of file handles.
+// (02/09/2011) Look for ???'s in the ChangeLog and resolve them.
 //*****************************************************************************
 // THINGS TO TEST before v1.0.00 :
 //
-// (09/03/2010) Check that all examples work eg. models can be found.
+// (12/04/2011) Test GNU-Cap OP analysis.
+// (12/04/2011) Test GNU-Cap DC analysis.
+// (12/04/2011) Test GNU-Cap AC analysis.
+// (12/04/2011) Test GNU-Cap TR analysis.
+// (12/04/2011) Test GNU-Cap FO analysis.
 //*****************************************************************************
 // THINGS TO DO in the "fullness of time" :
 //
-// (16/04/2010) In classes PnlValue, SpinCtrl and ChoUnits the method bClear( )
-//              doesn't mean clear it means set defaults. Use bSetDef*( )
-//              methods instead and change bClear( ) methods to clear object.
+// (07/09/2011) Source synchronization isn't quite working in both the NG-Spice
+//              and the GNU-Cap DC analyses. Source synchronization begins with
+//              a page changed event which is first intercepted by
+//              Nbk<SimEng>::OnPageChangd( ) which then allows
+//              NbkSimrBase::OnPageChangd( ) to actually handle the event.
+//              NbkSimrBase::OnPageChangd( ) gets a pointer to a PnlAnaBase
+//              object and changes the source name, however events can only
+//              propagate down from Pnl<SimEng>DC to PnlAnaBase but not back
+//              the other way so Pnl<SimEng>DC never knows about the event.
+//              Pnl<SimEng>DC::OnSrcName( ) is where the sweep units type is
+//              ste so this doesn't happen.
+// (15/04/2010) Locale stuff still appears to be broken.
+//              (Maybe fixed in v0.9.99; check. Change my locale.)
+// (05/09/2011) wxWidgets v2.9.2 breaks when changing simulation engines.
+// (26/08/2011) Still producing "prcbase.log".
+// (29/06/2011) Do include directives need to be expanded by gnetlist?
+//              Simulation engine could be left to do this.
+// (26/05/2011) Implement the bSaveSimCmds( ) method in the classes SimnGnuCap
+//              and SimnNgSpice.
+// (24/05/2011) In the simulation file place simulation commands ahead of
+//              models and sub-circuits.
+// (11/05/2011) Investigate replacing parts of SpinCtrl with wxSpinCtrl.
+// (11/05/2011) Change class names containing "Simr" to "SimEng" and "Simn" to
+//              "Sim" eg. NbkSimrBase to NbkSimEngBase and SimnBase to SimBase.
+// (05/05/2011) Allow the user to set the spin control repeat rate.
+// (28/04/2011) When a netlist created by gSpiceUI is loaded into the NetList
+//              text control load it into the Simulation text control as well.
+//              If gSpiceUI created the netlist it can be simulated.
+// (28/04/2011) Now and then a spin control decrements from 1.00 to 0.00, this
+//              should never happen.
+// (27/04/2011) NG-Spice doesn't like probes where one of two nodes is ground,
+//              eg. ".PRINT TRAN V(Trigger,0)". It complains with the message :
+//                "Warning: can't parse '0': ignored"
+// (19/04/2011) The way the wxProcess class is used is fault prone. wxProcess
+//              objects should be created dynamically when a process is to run
+//              and deleted soon after the process terminates. PrcBase inherits
+//              from wxProcess, it should contain a pointer to wxProcess object
+//              as an attribute.
+// (23/03/2011) In the class PrcSimrBase the console spew logging mechanism is
+//              clumsy; PrcSimrBase::bSaveOutput( ) does almost the same thing
+//              as PrcBase::bLogOutput( ). Shouldn't have a results file should
+//              just use the PrcBase log file system.
+// (02/03/2011) The GNU-Cap OP analysis the "Temp" column header is missing in
+//              the formatted results. Talk to GNU-Cap developer.
+// (02/03/2011) When a gschem process is exited and the schematic file has
+//              changed automatically do a reload and maybe re-create the
+//              simulation file.
+// (30/06/2010) Abbreviate most names containing NgSpice and GnuCap to Ngs and
+//              Gcp respectively.
+// (29/04/2010) Resolve issues compiling the code under OSX. How?
+// (19/04/2010) In FrmMain::Initialize( ) if the call to m_oFileTsks.Initialize()
+//              causes an error message to be displayed FrmMain is only
+//              partially initialized and it looks broken.
+//              Test Method :
+//                1. delete the netlist file named in the config. file under
+//                   "Files/NetList",
+//                2. arrange it so that gnetlist can't be found by gspiceui.
+// (19/04/2010) Create a Web page on sourceforge!
 // (31/03/2010) At startup the simulation engine specified in a netlist file
 //              should over-rule that stored in the configuration file.
-// (31/03/2010) If gSchem is open and the user presses the Schematic button an
-//              error message is displayed. Bring gSchem to the foreground
-//              instead. Same probably applies for gWave and Gaw.
+// (31/03/2010) If gschem is open and the user presses the Schematic button an
+//              error message is displayed, bring gschem to the foreground
+//              instead. Same probably applies for gwave and Gaw.
 // (30/03/2010) For all structure objects use the prefix 't' instead of 'o'.
 // (01/03/2010) Implement Fourier analysis for NG-Spice.
 // (11/06/2009) The NG-Spice Transient analysis cold initial conditions doesn't
@@ -137,7 +190,7 @@
 //*****************************************************************************
 // gWave :
 //
-// (29/03/2004) GWave can't handle the banner that Gnu-CAP includes in it's
+// (29/03/2004) GWave can't handle the banner that GNU-Cap includes in it's
 //              output.
 //*****************************************************************************
 // Gaw :
@@ -147,29 +200,30 @@
 //
 // (03/09/2009) v2.8.10 : Class wxToolTip seems to be broken ie. can't globally
 //                        enable/disable tooltips or set the tooltip delay.
-// (07/09/2007) v2.8.5 : Cannot set the font in the choice control in the
-//                       PnlValue class when no file loaded at startup. It
-//                       should inherit the font from it's parent; every other
-//                       control does. This seems to be bug in wxWidgets v2.8.5
-//                       and v2.6.3.
-// (28/05/2007) v2.8.3 : In the class PnlValue class and function DoLayout( )
-//                       wxWidgets ignores the request to vertically align the
-//                       StaticText object.
-// (04/02/2007) v2.8.3 : The class wxFileName has an undocumented function
-//                       SetPath( ).
-// (12/04/2005) v2.5.4 : "make uninstall" does nothing.
-// (06/04/2005) v2.5.2 : When the wxFrame is resized wxStatusBar isn't.
-// (01/10/2004) v2.5.2 : No mention of wxControl constructor in documentation.
-// (18/09/2004) v2.5.2 : In the class wxTextCtrl style setting wxTE_RIGHT is
-//                       ignored in Create( ) function.
-// (13/08/2004) v2.4.2 : In class wxFileDialog styles can only be set in the
-//                       constructor. The method SetStyle( ) does nothing.
-// (21/02/2004) v2.4.2 : In the class wxTextFile function IsOpened( ) returns
-//                       TRUE after Open( ) but FALSE after Create( ).
-// (19/02/2004) v2.4.2 : In the class wxSpinCtrl when using SetValue( (int) 0 )
-//                       for initialization the spin control is left blank.
-// (17/11/2003) v2.4.1 : In class wxFileDialog wildcards can only be set in the
-//                       constructor. The method SetWildcard( ) is not properly
-//                       implemented. See constructor in src/generic/filedlgg.cpp
-//                       and set method in include/wx/generic/filedlgg.h.
+// (07/09/2007) v2.8.5  : Cannot set the font in the choice control in the
+//                        PnlValue class when no file loaded at startup. It
+//                        should inherit the font from it's parent; every other
+//                        control does. This seems to be bug in wxWidgets
+//                        v2.8.5 and v2.6.3.
+// (28/05/2007) v2.8.3  : In the class PnlValue class and function DoLayout( )
+//                        wxWidgets ignores the request to vertically align the
+//                        StaticText object.
+// (04/02/2007) v2.8.3  : The class wxFileName has an undocumented function
+//                        SetPath( ).
+// (12/04/2005) v2.5.4  : "make uninstall" does nothing.
+// (06/04/2005) v2.5.2  : When the wxFrame is resized wxStatusBar isn't.
+// (01/10/2004) v2.5.2  : No mention of wxControl constructor in documentation.
+// (18/09/2004) v2.5.2  : In the class wxTextCtrl style setting wxTE_RIGHT is
+//                        ignored in Create( ) function.
+// (13/08/2004) v2.4.2  : In class wxFileDialog styles can only be set in the
+//                        constructor. The method SetStyle( ) does nothing.
+// (21/02/2004) v2.4.2  : In the class wxTextFile function IsOpened( ) returns
+//                        TRUE after Open( ) but FALSE after Create( ).
+// (19/02/2004) v2.4.2  : In the class wxSpinCtrl when using SetValue( (int) 0 )
+//                        for initialization the spin control is left blank.
+// (17/11/2003) v2.4.1  : In class wxFileDialog wildcards can only be set in
+//                        the constructor. The method SetWildcard( ) is not
+//                        properly implemented. See constructor in
+//                        src/generic/filedlgg.cpp and set method in
+//                        include/wx/generic/filedlgg.h.
 //*****************************************************************************
