@@ -1,10 +1,10 @@
 //*****************************************************************************
 //                                PrcBase.cpp                                 *
 //                               -------------                                *
-//  Started     : 29/01/2004                                                  *
-//  Last Update : 14/07/2009                                                  *
-//  Copyright   : (C) 2004 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Started     : 29/01/2004                                                   *
+// Last Update : 23/03/2011                                                   *
+// Copyright   : (C) 2004 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -23,9 +23,10 @@
 
 PrcBase::PrcBase( int iFlags ) : wxProcess( iFlags )
 {
-  m_iPid   = -1;            // Clear the process ID number
-  m_ofnLog = DEF_LOG_FILE;  // Set the default log file path and name
-  m_osErrMsg.Empty( );      // Clear the error message
+  m_iPid      = -1;            // Clear the process ID number
+  m_iExitCode = -1;            // Clear the process exit code
+  m_ofnLog    = DEF_LOG_FILE;  // Set the default log file path and name
+  m_osErrMsg  = wxT("");       // Clear the error message
 }
 
 //*****************************************************************************
@@ -48,30 +49,39 @@ PrcBase::~PrcBase( )
 //   TRUE  - Success (path prepended to oFnBinary)
 //   FALSE - Failure
 
-bool  PrcBase::bFindBinary( wxFileName & ofnBinary )
+bool  PrcBase::bFindBinary( wxFileName & rofnBinary )
 {
   wxPathList  opl1;
   wxFileName  ofn1;
-  wxString    os1, os2;
+  wxString    os1, os2, os3;
 
-  m_osErrMsg.Empty( );
+  m_osErrMsg = wxT("");
 
   // Initial checks
-  if( ! ofnBinary.IsOk( ) ) return( FALSE );
+  if( ! rofnBinary.IsOk( ) ) return( FALSE );
 
-  // Searth the env. var. PATH for the first occurrence of the binary
+  // Search enviroment variable PATH for the first occurrence of the binary
   opl1.AddEnvList( wxT("PATH") );
-  ofn1 = opl1.FindAbsoluteValidPath( ofnBinary.GetFullName( ) );
+  ofn1 = opl1.FindAbsoluteValidPath( rofnBinary.GetFullName( ) );
 
   // Check whether the binary was successfully found
   if( !ofn1.IsOk( ) || !ofn1.FileExists( ) )
   {
-    os1.Empty( );
-    os1 << wxT("Can't find the binary :  ") << ofnBinary.GetFullName( )
-        << wxT("\n\nYour PATH is :\n") << os1;
+    os1 << wxT("Can't find the binary : ") << m_ofnBinary.GetFullName( );
     wxGetEnv( wxT("PATH"), &os2 );
-    os1 << os2;
-    SetErrMsg( os1 );
+    os2.Prepend( wxT("$PATH = \n") );
+
+    // Set the object error message
+    os3 = os1 + wxT("\n\n") + os2;
+    SetErrMsg( os3 );
+
+    // If debug mode is enabled send the error message to the console
+    if( g_bDebug )
+    {
+      os3 = os1 + wxT(" (") + os2 + wxT(").");
+      std::cerr << "DEBUG : " << rosStrToLine( os3 ).mb_str( ) << "\n\n";
+    }
+
     return( FALSE );
   }
 
@@ -90,9 +100,11 @@ bool  PrcBase::bFindBinary( wxFileName & ofnBinary )
 
 bool  PrcBase::bLogOutput( void )
 {
-  wxString  os1, os2;
-  size_t    szt1;
-  wxChar    oc1;
+  wxOutputStream * poStdOut;
+  wxInputStream  * poStdIn;
+  wxInputStream  * poStdErr;
+  wxString         os1, os2;
+  wxChar           oc1;
 
   // Check that the log file name is valid
   if( ! m_ofnLog.IsOk( ) )          return( FALSE );
@@ -104,24 +116,28 @@ bool  PrcBase::bLogOutput( void )
   else { if( ! oFileLog.Create( ) ) return( FALSE ); }
 
   // Clear the file if it contains lines
-  for( szt1=oFileLog.GetLineCount( ); szt1>0; szt1-- )
-    oFileLog.RemoveLine( 0 );
+  oFileLog.Clear( );
+
+  // Get pointers to the input streams
+  poStdOut = GetOutputStream( );
+  poStdIn  = GetInputStream( );
+  poStdErr = GetErrorStream( );
 
   // Read the console input
-  while( bIsExec( ) || GetInputStream( )->IsOk() || GetErrorStream( )->IsOk() )
+  while( bIsExec( ) || poStdIn->IsOk( ) || poStdErr->IsOk( ) )
   {
     // Get a line of data from stdout
-    while( IsInputAvailable( ) )
+    while( poStdIn->CanRead( ) )
     {
-      oc1 = GetInputStream( )->GetC( );
+      oc1 = poStdIn->GetC( );
       if( oc1==wxT('\t') || (oc1>31 && oc1!=127) ) os1 << oc1;
       if( oc1 == wxT('\n') ) { oFileLog.AddLine( os1 ); os1 = wxT(""); }
     }
 
     // Get a line of data from stderr
-    while( IsErrorAvailable( ) )
+    while( poStdErr->CanRead( ) )
     {
-      oc1 = GetErrorStream( )->GetC( );
+      oc1 = poStdErr->GetC( );
       if( oc1==wxT('\t') || (oc1>31 && oc1!=127) ) os2 << oc1;
       if( oc1 == wxT('\n') ) { oFileLog.AddLine( os2 ); os2 = wxT(""); }
     }
@@ -129,11 +145,17 @@ bool  PrcBase::bLogOutput( void )
     wxYield( ); // Yield CPU to other processes
   }
 
+  // Delete the stream objects
+  delete poStdOut;
+  delete poStdIn;
+  delete poStdErr;
+  SetPipeStreams( NULL, NULL, NULL );
+
   if( ! os1.IsEmpty( ) ) oFileLog.AddLine( os1 );
   if( ! os2.IsEmpty( ) ) oFileLog.AddLine( os2 );
 
   oFileLog.Write( ); // Save the changes to disk
-  oFileLog.Close( ); // Close the results file
+  oFileLog.Close( ); // Close the log file
 
   return( TRUE );
 }
@@ -147,20 +169,8 @@ bool  PrcBase::bLogOutput( void )
 
 bool  PrcBase::bBinExists( void )
 {
-  wxString  os1, os2;
-
-  m_osErrMsg.Empty( );
-
   if( !m_ofnBinary.FileExists( ) || !m_ofnBinary.IsOk( ) )
-  {
-    os1.Empty( );
-    os1 << wxT("Can't find the binary :  ") << m_ofnBinary.GetFullName( )
-        << wxT("\n\nYour PATH is :\n") << os1;
-    wxGetEnv( wxT("PATH"), &os2 );
-    os1 << os2;
-    SetErrMsg( os1 );
     return( FALSE );
-  }
 
   return( TRUE );
 }
@@ -169,17 +179,17 @@ bool  PrcBase::bBinExists( void )
 // Set the file name of the binary to be executed.
 //
 // Argument List :
-//   rosFileName - A string containing the binary file name
+//   rosFName - A string containing the binary file name
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  PrcBase::bSetBinary( const wxString & rosFileName )
+bool  PrcBase::bSetBinary( const wxString & rosFName )
 {
-  if( rosFileName.IsEmpty( ) )       return( FALSE );
+  if( rosFName.IsEmpty( ) )          return( FALSE );
 
-  m_ofnBinary = rosFileName;
+  m_ofnBinary = rosFName;
 
   if( ! bFindBinary( m_ofnBinary ) ) return( FALSE );
 
@@ -210,17 +220,17 @@ bool  PrcBase::bSetArgLst( const wxString & rosArgLst )
 // (If set all process output can be captured to this file.)
 //
 // Argument List :
-//   rosFileName - A string containing the full path and file name
+//   rosFName - A string containing the full path and file name
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  PrcBase::bSetLogFile( const wxString & rosFileName )
+bool  PrcBase::bSetLogFile( const wxString & rosFName )
 {
   wxFileName  ofn1;
 
-  ofn1 = rosFileName;
+  ofn1 = rosFName;
 
   if( ! ofn1.IsOk( ) ) return( FALSE );
 
@@ -231,22 +241,64 @@ bool  PrcBase::bSetLogFile( const wxString & rosFileName )
   return( TRUE );
 }
 
+//*****************************************************************************
+// Execute a process asynchronously.
+// (Ie. Return as soon as the process has been launched).
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  PrcBase::bExecAsync( void )
+{
+  wxString  os1, os2;
+
+  // Only execute simulation if it isn't already running
+  if( bIsExec( ) )      return( FALSE );
+
+  // Clear error attributes
+  m_osErrMsg = wxT("");
+
+  // Check that the binary exists
+  if( ! bBinExists( ) ) return( FALSE );
+
+  // Construct the command line to be executed
+  os1 = roGetBinary( ).GetFullPath( );
+  if( ! rosGetArgLst( ).IsEmpty( ) )
+    os1 << wxT(' ') << rosGetArgLst( );
+
+  // Attempt to execute the simulation
+  m_iPid = (int) wxExecute( os1, wxEXEC_ASYNC, this );
+  if( m_iPid <= 0 )
+  {
+    os2.Empty( );
+    os2 << wxT("Couldn't start process : ") << os1;
+    SetErrMsg( os2 );
+    return( FALSE );
+  }
+
+  return( TRUE );
+}
+
 //*****************************************************************************
 // Execute a process synchronously.
 // (Ie. wait for the process to terminate before returning).
 //
-// ???
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  PrcBase::bExecSync( void )
+{
+  // Not yet implemented ??? 12/03/2010
+
+  return( FALSE );
 
-//bool  PrcBase::bExecSync( const wxString & rosCmd )
-//{
 //  long  liRtn;
 
 //  wxEnableTopLevelWindows( FALSE );
-
 //  liRtn = wxExecute( rosCmd, wxEXEC_SYNC );
-
 //  wxEnableTopLevelWindows( TRUE );
-
 //  if( liRtn != 0 ) return( FALSE );
 
 //  return( TRUE );
@@ -278,48 +330,6 @@ bool  PrcBase::bSetLogFile( const wxString & rosFileName )
 //         << "execute and so was terminated prematurely.";
 //    return( FALSE );
 //  }
-//}
-
-//*****************************************************************************
-// Execute a process asynchronously.
-// (Ie. Return as soon as the process has been launched).
-//
-// Argument List :
-//   rosArgList - The argument list to be passed to the binary
-//
-// Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
-
-bool  PrcBase::bExec( void )
-{
-  wxString  os1, os2;
-
-  // Only execute simulation if it isn't already running
-  if( bIsExec( ) )      return( FALSE );
-
-  // Clear error attributes
-  m_osErrMsg.Empty( );
-
-  // Check that the binary exists
-  if( ! bBinExists( ) ) return( FALSE );
-
-  // Construct the command line to be executed
-  os1 = rofnGetBinary( ).GetFullPath( );
-  if( ! rosGetArgLst( ).IsEmpty( ) )
-    os1 << wxT(' ') << rosGetArgLst( );
-
-  // Attempt to execute the simulation
-  m_iPid = (int) wxExecute( os1, wxEXEC_ASYNC, this );
-  if( m_iPid <= 0 )
-  {
-    os2.Empty( );
-    os2 << wxT("Couldn't start process : ") << os1;
-    SetErrMsg( os2 );
-    return( FALSE );
-  }
-
-  return( TRUE );
 }
 
 //*****************************************************************************
@@ -336,7 +346,8 @@ bool  PrcBase::bKill( void )
 
   if( Kill( m_iPid, wxSIGTERM ) != wxKILL_OK ) return( FALSE );
 
-  m_iPid = -1;
+  m_iPid      = -1;
+  m_iExitCode = 0;
 
   return( TRUE );
 }
@@ -355,20 +366,6 @@ bool  PrcBase::bDelLogFile( void )
   return( ::wxRemoveFile( m_ofnLog.GetFullPath( ) ) );
 }
 
-//*****************************************************************************
-// Call-back function called when the simulator process terminates.
-// (WARNING: Be careful of this function definition, if it is incorrect the
-//           application can segment fault.)
-//
-// Argument List :
-//   iPid    - The PID of the process which just terminated
-//   iStatus - The exit code of the process
-
-void  PrcBase::OnTerminate( int iPid, int iStatus )
-{
-  m_iPid = -1;
-}
-
 //*****************************************************************************
 // Collect the output from the simulator and print to a text control.
 //
@@ -401,7 +398,7 @@ void  PrcBase::PrintCmd( TextCtrl & roTxtCtl )
   roTxtCtl.bAppendLine( os1 );
   os1.Empty( );
   roTxtCtl.bAppendLine( os1 );
-  os1 << rofnGetBinary( ).GetFullPath( );
+  os1 << roGetBinary( ).GetFullPath( );
   if( ! rosGetArgLst( ).IsEmpty( ) ) os1 << wxT(' ') << rosGetArgLst( );
   roTxtCtl.bAppendLine( os1 );
   os1.Empty( );
@@ -439,3 +436,21 @@ void  PrcBase::PrintRsp( TextCtrl & roTxtCtl )
 }
 
 //*****************************************************************************
+// Call-back function called when the process terminates.
+// (WARNING : Be careful of this function definition, if it is incorrect the
+//            application can segment fault.)
+//
+// Argument List :
+//   iPid    - The PID of the process which just terminated
+//   iStatus - The exit code of the process
+
+void  PrcBase::OnTerminate( int iPid, int iStatus )
+{
+  if( iPid == m_iPid )
+  {
+    m_iPid      = -1;
+    m_iExitCode = iStatus;
+  }
+}
+
+//*****************************************************************************
