@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                                PrcBase.hpp                                 *
 //                               -------------                                *
-//  Description : Provides a wrapper for the wxProcess class adding a bit of  *
-//                extra desirable functionality.                              *
-//  Started     : 29/01/2004                                                  *
-//  Last Update : 14/07/2009                                                  *
-//  Copyright   : (C) 2004 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : Provides a wrapper for the wxProcess class adding a bit of   *
+//               extra desirable functionality.                               *
+// Started     : 29/01/2004                                                   *
+// Last Update : 14/04/2011                                                   *
+// Copyright   : (C) 2004 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -27,7 +27,7 @@ using  namespace  std;
 
 #include <iostream>
 
-// wxWindows Includes
+// wxWidgets Includes
 
 #include <wx/wx.h>
 #include <wx/filename.h>
@@ -36,7 +36,9 @@ using  namespace  std;
 
 // Application Includes
 
+#include "TypeDefs.hpp"
 #include "utility/TextCtrl.hpp"
+#include "utility/StrUtils.hpp"
 
 // Local Constant Declarations
 
@@ -44,17 +46,18 @@ using  namespace  std;
 
 //*****************************************************************************
 
-class PrcBase : public wxProcess
+class PrcBase : protected wxProcess
 {
   protected :
 
     wxFileName  m_ofnBinary;  // The file name of the binary to be executed
     wxString    m_osArgLst;   // The argument list appended to the binary name
-    int         m_iPid;       // The process ID
+    int         m_iPid;       // The process ID number
+    int         m_iExitCode;  // The process exit code
     wxFileName  m_ofnLog;     // The file name of the simulation log
     wxString    m_osErrMsg;   // Error message
 
-    bool  bFindBinary( wxFileName & ofnBinary );
+    bool  bFindBinary( wxFileName & rofnBinary );
     bool  bLogOutput ( void );
 
   public :
@@ -65,29 +68,31 @@ class PrcBase : public wxProcess
     bool  bBinExists( void );
 
     bool  bIsExec( void ) { return( m_iPid>0 ? TRUE : FALSE ); }
-    bool  bIsOk  ( void ) { return( m_osErrMsg.IsEmpty( ) ); }
+    bool  bIsOk  ( void ) { return( m_iExitCode==0 && m_osErrMsg.IsEmpty( ) ); }
 
-    bool  bSetBinary ( const wxString & rosFileName );
+    bool  bSetBinary ( const wxString & rosFName );
     bool  bSetArgLst ( const wxString & rosArgLst   );
-    bool  bSetLogFile( const wxString & rosFileName );
+    bool  bSetLogFile( const wxString & rosFName );
     void   SetErrMsg ( const wxString & rosErrMsg   )
                                      { if( bIsOk( ) ) m_osErrMsg = rosErrMsg; }
 
-    const wxFileName & rofnGetBinary ( void ) { return( m_ofnBinary ); }
-    const wxString   &  rosGetArgLst ( void ) { return( m_osArgLst  ); }
-    const wxFileName & rofnGetLogFile( void ) { return( m_ofnLog    ); }
-    const wxString   &  rosGetErrMsg ( void ) { return( m_osErrMsg  ); }
+    const wxFileName &  roGetBinary ( void ) { return( m_ofnBinary ); }
+    const wxString   & rosGetArgLst ( void ) { return( m_osArgLst  ); }
+    const wxFileName &  roGetLogFile( void ) { return( m_ofnLog    ); }
+    const wxString   & rosGetErrMsg ( void ) { return( m_osErrMsg  ); }
 
-    virtual  bool  bExec( void );
-    virtual  bool  bKill( void );
+    virtual  bool  bExecAsync( void );
+    virtual  bool  bExecSync ( void );
+    virtual  bool  bKill     ( void );
 
     bool  bDelLogFile( void );
 
-    void  OnTerminate( int iPid, int iStatus );
-
     void  Print   ( TextCtrl & roTxtCtl );
     void  PrintCmd( TextCtrl & roTxtCtl );
     void  PrintRsp( TextCtrl & roTxtCtl );
+
+    // Event handlers
+    void  OnTerminate( int iPid, int iStatus );
 };
 
 //*****************************************************************************
