@@ -1,10 +1,10 @@
 //*****************************************************************************
 //                               PrcSimrBase.cpp                              *
 //                              -----------------                             *
-//  Started     : 25/04/2004                                                  *
-//  Last Update : 05/10/2009                                                  *
-//  Copyright   : (C) 2004 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Started     : 25/04/2004                                                   *
+// Last Update : 12/03/2010                                                   *
+// Copyright   : (C) 2004 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -52,7 +52,7 @@ bool  PrcSimrBase::bSetResultsFile( const wxString & rosFName )
 
   if( ! ofn1.IsOk( ) ) return( FALSE );
 
-  m_oFnResults = ofn1;
+  m_ofnResults = ofn1;
 
   return( TRUE );
 }
@@ -69,55 +69,84 @@ bool  PrcSimrBase::bSetResultsFile( const wxString & rosFName )
 
 bool  PrcSimrBase::bSaveOutput( const wxString & rosFName )
 {
-  wxFileName  ofn1;
-  wxString    os1, os2;
-  wxChar      oc1;
+  wxOutputStream * poStdOut;
+  wxInputStream  * poStdIn;
+  wxInputStream  * poStdErr;
+  wxFileName       ofn1;
+  wxString         os1, os2;
+  wxChar           oc1;
 
   // Check the validity of the save file name
   if( rosFName.IsEmpty( ) )         return( FALSE );
   ofn1 = rosFName;
   if( ! ofn1.IsOk( ) )              return( FALSE );
 
-  // Open the save file and delete any lines it may contain
+  // Open the file
   wxTextFile  oFileCct( ofn1.GetFullPath( ) );
   if( oFileCct.Exists( ) )
        { if( ! oFileCct.Open( ) )   return( FALSE ); }
   else { if( ! oFileCct.Create( ) ) return( FALSE ); }
+
+  // Clear the file if it contains lines
   oFileCct.Clear( );
 
-  wxMicroSleep( 100 );
+  wxMicroSleep( 100 ); // 23/03/2011 ??? What's this for?
+
+  // Get input stream objects to standard out and standard error
+  poStdOut = GetOutputStream( );
+  poStdIn  = GetInputStream( );
+  poStdErr = GetErrorStream( );
 
   // Save the simulator output to file
-  while( bIsExec( ) || IsInputAvailable( ) || IsErrorAvailable( ) )
+  while( bIsExec( ) || poStdIn->CanRead( ) || poStdErr->CanRead( ) )
   {
-    while( IsInputAvailable( ) )
-    { // Input characters from stdout
-      oc1 = GetInputStream( )->GetC( );
+    // Input characters from stdout
+    while( poStdIn->CanRead( ) )
+    {
+      // Get a character from the input stream
+      oc1 = poStdIn->GetC( );
+
+      // Build each string
+      if( oc1==wxT('\t') || (oc1>31 && oc1!=127) )
+        os1 << oc1;
+
+      // Append completed strings to the log file
       if( oc1 == wxT('\n') )
       {
         oFileCct.AddLine( os1 );
         os1 = wxT("");
-        continue;
       }
-      if( oc1==wxT('\t') || (oc1>31 && oc1!=127) ) os1 << oc1;
     }
 
-    while( IsErrorAvailable( ) )
-    { // Input characters from stderr
-      oc1 = GetErrorStream( )->GetC( );
+    // Input characters from stderr
+    while( poStdErr->CanRead( ) )
+    {
+      // Get a character from the input stream
+      oc1 = poStdErr->GetC( );
+
+      // Build each string
+      if( oc1==wxT('\t') || (oc1>31 && oc1!=127) )
+        os2 << oc1;
+
+      // Append completed strings to the log file
       if( oc1 == wxT('\n') )
       {
         oFileCct.AddLine( os2 );
         os2 = wxT("");
-        continue;
       }
-      if( oc1==wxT('\t') || (oc1>31 && oc1!=127) ) os2 << oc1;
     }
 
-    if( !IsInputAvailable( ) && !IsErrorAvailable( ) )
-      wxTheApp->Yield( );  // Release the processor for other tasks
+    // Release the processor for other tasks
+    wxTheApp->Yield( );
   }
 
+  // Delete the stream objects
+  delete poStdOut;
+  delete poStdIn;
+  delete poStdErr;
+  SetPipeStreams( NULL, NULL, NULL );
+
+  // Save any unterminated strings
   if( os1.Length( ) > 0 ) oFileCct.AddLine( os1 );
   if( os2.Length( ) > 0 ) oFileCct.AddLine( os2 );
   oFileCct.AddLine( wxT("") );
@@ -154,11 +183,11 @@ bool  PrcSimrBase::bMakeArgLst( SimnBase & roSimn )
   }
 
   // Create the results file name
-  os1 = roSimn.rofnGetLoadFile( ).GetPath( ) + wxT('/')
-      + roSimn.rofnGetLoadFile( ).GetName( );
+  os1 = roSimn.roGetLoadFile( ).GetPath( ) + wxT('/')
+      + roSimn.roGetLoadFile( ).GetName( );
   i1 = os1.Find( wxT(".gspiceui") );
   if( i1 > 0 ) os1 = os1.Truncate( (size_t) i1 );
-  os1 << wxT('.') << rofnGetBinary( ).GetName( );
+  os1 << wxT('.') << roGetBinary( ).GetName( );
   switch( roSimn.eGetAnaType( ) )
   {
     case eCMD_OP : os1 << wxT(".op"); break;
@@ -182,7 +211,7 @@ bool  PrcSimrBase::bMakeArgLst( SimnBase & roSimn )
   }
 
   // Construct the default argument list
-  os1 = roSimn.rofnGetSaveFile( ).GetFullPath( );
+  os1 = roSimn.roGetSaveFile( ).GetFullPath( );
   if( ! bSetArgLst( os1 ) )
   {
     SetErrMsg( wxT("Couldn't set argument list") );
@@ -207,10 +236,10 @@ bool  PrcSimrBase::bExec( void )
   wxString  os1, os2;
 
   // Execute the simulation
-  if( ! PrcBase::bExec( ) )      return( FALSE );
+  if( ! PrcBase::bExecAsync( ) ) return( FALSE );
 
   // Save the simulation results to the log file
-  os1 = rofnGetLogFile( ).GetFullPath( );
+  os1 = roGetLogFile( ).GetFullPath( );
   if( ! bSaveOutput( os1 ) )     return( FALSE );
 
   // Copy the log file to the results file
