@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                               PrcSimrBase.hpp                              *
 //                              -----------------                             *
-//  Description : This is the base class for classes which provide the        *
-//                interface to the SPICE circuit simulator.                   *
-//  Started     : 25/04/2004                                                  *
-//  Last Update : 19/08/2009                                                  *
-//  Copyright   : (C) 2004 by M.S.Waters                                      *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : This is the base class for classes which provide the         *
+//               interface to the SPICE circuit simulator.                    *
+// Started     : 25/04/2004                                                   *
+// Last Update : 01/04/2011                                                   *
+// Copyright   : (C) 2004 by M.S.Waters                                       *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -24,7 +24,7 @@
 // System Includes
 
 
-// wxWindows Includes
+// wxWidgets Includes
 
 #include <wx/wx.h>
 
@@ -46,7 +46,7 @@ class PrcSimrBase : public PrcBase
 
     eSimrType   m_eSimEng;       // Simulation engine specifier
 
-    wxFileName  m_oFnResults;    // The file name of the process output
+    wxFileName  m_ofnResults;    // The file name of the process output
     wxTextFile  m_oFileResults;  // A text file object for the above
 
     // Save the console output to file
@@ -61,7 +61,7 @@ class PrcSimrBase : public PrcBase
     bool  bSetResultsFile( const wxString & rosFName );
 
           eSimrType     eGetSimEng     ( void ) { return( m_eSimEng    ); }
-    const wxFileName & roGetResultsFile( void ) { return( m_oFnResults ); }
+    const wxFileName & roGetResultsFile( void ) { return( m_ofnResults ); }
 
     // Create the process argument list
     virtual  bool  bMakeArgLst( SimnBase & roSimn );
