@@ -1,10 +1,10 @@
 //*****************************************************************************
 //                                 NbkGnuCap.cpp                              *
 //                                ---------------                             *
-//  Started     : 05/09/2003                                                  *
-//  Last Update : 12/04/2010                                                  *
-//  Copyright   : (C) 2003 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Started     : 05/09/2003                                                   *
+// Last Update : 06/09/2011                                                   *
+// Copyright   : (C) 2003 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -21,11 +21,11 @@
 //*****************************************************************************
 // Implement an event table.
 
-BEGIN_EVENT_TABLE( NbkGnuCap, wxNotebook )
+BEGIN_EVENT_TABLE( NbkGnuCap, NbkSimrBase )
 
-  EVT_NOTEBOOK_PAGE_CHANGED( -1,          NbkSimrBase::OnPageChanged )
+  EVT_NOTEBOOK_PAGE_CHANGED( -1,          NbkGnuCap::OnPageChangd )
 
-  EVT_BUTTON( PnlAnaBase::ID_BTN_OPTIONS, NbkGnuCap::OnBtnOptions    )
+  EVT_BUTTON( PnlAnaBase::ID_BTN_OPTIONS, NbkGnuCap::OnBtnOptions )
 
 END_EVENT_TABLE( )
 
@@ -62,16 +62,6 @@ NbkGnuCap::NbkGnuCap( wxWindow * poParent, wxWindowID oWinID )
   SetSelection( 0 );
 }
 
-//*****************************************************************************
-// Default constructor.
-// (Used for two stage creation ie. must call Create( ) method.
-
-NbkGnuCap::NbkGnuCap( void ) : NbkSimrBase( ), m_oDlgCfgOPT( this )
-{
-  // Set the simulator engine type specifier
-  m_eSimEng = eSIMR_GNUCAP;
-}
-
 //*****************************************************************************
 // Destructor.
 
@@ -120,6 +110,8 @@ bool  NbkGnuCap::bLoad( const SimnBase & roSimn )
 
   if( roSimn.eGetSimEng( ) != eSIMR_GNUCAP )             return( FALSE );
 
+  PnlAnaBase::m_oCpntSwpSrcs = roSimn.m_oCpntSwpSrc;
+
   SimnGnuCap & roSimnGcp = (SimnGnuCap &) roSimn;
 
   if( ! bSetPage( roSimnGcp.eGetAnaType( ) ) )           bRtn = FALSE;
@@ -224,7 +216,6 @@ bool  NbkGnuCap::bSetPage( eCmdType eAnalysis )
 
   switch( eAnalysis )
   {
-    case eCMD_NONE :
     case eCMD_OP   : iPage = 0; break;
     case eCMD_DC   : iPage = 1; break;
     case eCMD_AC   : iPage = 2; break;
@@ -301,7 +292,7 @@ const wxString & NbkGnuCap::rosGetPage( void )
 //
 // Return Values:
 //   Success - The enumerated analysis specifier
-//   Failure - Simulation::eANA_NONE
+//   Failure - eCMD_NONE
 
 eCmdType  NbkGnuCap::eGetPage( void )
 {
@@ -325,7 +316,46 @@ eCmdType  NbkGnuCap::eGetPage( void )
 //                             Event Handlers                                 *
 //                                                                            *
 //*****************************************************************************
-// .OPTIONS command setup button control event handler.
+// This event is generated when a notebook page has just changed.
+//
+// Argument List:
+//   roEvtNbk - An object holding information about the event
+
+void  NbkGnuCap::OnPageChangd( wxNotebookEvent & roEvtNbk )
+{
+  PnlAnaBase * poPnlAna;
+  wxString     os1;
+  int          i1;
+
+  // Transfer the ambient temperature from the previous page to OPTIONS dialog
+  i1 = roEvtNbk.GetOldSelection( );
+  if( i1 != -1 )
+  {
+    poPnlAna = (PnlAnaBase *) GetPage( (size_t) i1 );
+    if( poPnlAna->bIsCreated( PnlAnaBase::eCTLGRP_TEMP ) )
+    {
+      os1 = poPnlAna->m_oPnlTemp.rosGetValue( );
+      m_oDlgCfgOPT.bSetValue( DlgGcpCfgOPT::ID_PNL_TEMPAMB, os1 );
+    }
+  }
+
+  // Transfer the ambient temperature from the OPTIONS dialog to current page
+  poPnlAna = (PnlAnaBase *) GetCurrentPage( );
+  if( poPnlAna != NULL )
+  {
+    if( poPnlAna->bIsCreated( PnlAnaBase::eCTLGRP_TEMP ) )
+    {
+      os1 = m_oDlgCfgOPT.rosGetValue( DlgGcpCfgOPT::ID_PNL_TEMPAMB );
+      poPnlAna->m_oPnlTemp.bSetValue( os1 );
+    }
+  }
+
+  // Allow additional event handlers to be called
+  roEvtNbk.Skip( );
+}
+
+//*****************************************************************************
+// Setup .OPTIONS command button event handler.
 //
 // Argument List:
 //   roEvtCmd - An object holding information about the event
@@ -336,8 +366,11 @@ void  NbkGnuCap::OnBtnOptions( wxCommandEvent & roEvtCmd )
   wxString     os1;
   int          i1;
 
+  // Get a pointer to the currently displayed analysis page
+  poPnlAna = (PnlAnaBase *) GetCurrentPage( );
+  if( poPnlAna == NULL ) return;
+
   // Set the temperature in the OPTIONS dialog
-  poPnlAna = (PnlAnaBase *) GetPage( GetSelection( ) );
   if( poPnlAna->bIsCreated( PnlAnaBase::eCTLGRP_TEMP ) )
   {
     os1 = poPnlAna->m_oPnlTemp.rosGetValue( );
