@@ -1,13 +1,13 @@
 //*****************************************************************************
 //                                 NbkGnuCap.hpp                              *
 //                                ---------------                             *
-//  Description : Provides a container class for the analysis configuration   *
-//                panels for the different analyses provided by GNU-Cap       *
-//                electronic circuit simulator.                               *
-//  Started     : 05/09/2003                                                  *
-//  Last Update : 30/06/2009                                                  *
-//  Copyright   : (C) 2003 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : Provides a container class for the analysis configuration    *
+//               panels for the different analyses provided by GNU-Cap        *
+//               electronic circuit simulator.                                *
+// Started     : 05/09/2003                                                   *
+// Last Update : 23/05/2011                                                   *
+// Copyright   : (C) 2003 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -25,7 +25,7 @@
 // System Includes
 
 
-// wxWindows Includes
+// wxWidgets Includes
 
 #include <wx/wx.h>
 
@@ -62,7 +62,6 @@ class NbkGnuCap : public NbkSimrBase
   public:
 
     NbkGnuCap( wxWindow * poParent, wxWindowID oWinID );
-    NbkGnuCap( void );
    ~NbkGnuCap( );
 
     virtual  bool  bClear( void );
@@ -77,7 +76,8 @@ class NbkGnuCap : public NbkSimrBase
     virtual         eCmdType     eGetPage( void );
 
     // Event handlers
-    void  OnBtnOptions( wxCommandEvent & roEvtCmd );
+    void  OnPageChangd( wxNotebookEvent & roEvtNbk );
+    void  OnBtnOptions( wxCommandEvent  & roEvtCmd );
 
     // Leave this as the last line as private access is envoked by macro
     DECLARE_EVENT_TABLE( )
