@@ -4,7 +4,7 @@
 // Description : This class contains values associated with the GNU-Cap       *
 //               AC command. It inherits from the class CmdBase.              *
 // Started     : 21/02/2008                                                   *
-// Last Update : 13/05/2009                                                   *
+// Last Update : 24/12/2010                                                   *
 // Copyright   : (C) 2008 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -18,8 +18,8 @@
 //                                                                            *
 //*****************************************************************************
 
-#ifndef CMDGNUCAPAC_HPP
-#define CMDGNUCAPAC_HPP
+#ifndef CMDGCPAC_HPP
+#define CMDGCPAC_HPP
 
 // System Includes
 
@@ -61,7 +61,7 @@ struct CmdGnuCapAC : public CmdBase
              CmdGnuCapAC( void );
     virtual ~CmdGnuCapAC( );
 
-    virtual  bool  bClear( void );
+    virtual  bool  bSetDefaults( void );
 
     virtual  bool  bParse ( void );
     virtual  bool  bFormat( void );
@@ -73,4 +73,4 @@ struct CmdGnuCapAC : public CmdBase
 
 //*****************************************************************************
 
-#endif // CMDGNUCAPAC_HPP
+#endif // CMDGCPAC_HPP
