@@ -2,7 +2,7 @@
 //                              CmdGnuCapOPT.cpp                              *
 //                             ------------------                             *
 // Started     : 11/09/2006                                                   *
-// Last Update : 16/04/2010                                                   *
+// Last Update : 12/08/2011                                                   *
 // Copyright   : (C) 2006 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -23,7 +23,7 @@
 
 CmdGnuCapOPT::CmdGnuCapOPT( void )
 {
-  bClear( );
+  bSetDefaults( );
 }
 
 //*****************************************************************************
@@ -134,15 +134,15 @@ bool  CmdGnuCapOPT::bValidate( void )
 }
 
 //*****************************************************************************
-// Clear the object attributes.
+// Set the object attributes to they're default values.
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  CmdGnuCapOPT::bClear( void )
+bool  CmdGnuCapOPT::bSetDefaults( void )
 {
-  CmdBase::bClear( );
+  CmdBase::bSetDefaults( );
 
   m_eSimEng  = eSIMR_GNUCAP;
   m_eCmdType = eCMD_OPT;
@@ -227,7 +227,7 @@ bool  CmdGnuCapOPT::bParse( void )
 
   // Clear the object attributes
   os1 = (wxString &) *this;
-  bClear( );
+  bSetDefaults( );
   assign( os1 );
 
   // Tokenize the command string
@@ -305,7 +305,6 @@ bool  CmdGnuCapOPT::bParse( void )
     else if( os1 == wxT("VMIN")     ) m_osVMIN     = os2;
     else if( os1 == wxT("VNTOL")    ) m_osVNTOL    = os2;
     else if( os1 == wxT("WCZERO")   ) m_osWCZERO   = os2;
-    else                              return( bValidate( ) );
   }
 
   return( bValidate( ) );
@@ -648,7 +647,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdGnuCapOPT Test Utility"
-       << "\n     Version 1.02 (04/06/2009)\n";
+       << "\n     Version 1.03 (12/08/2011)\n";
 
   // Create a NG-SPICE OPTIONS command object
   CmdGnuCapOPT  oCmd_OPT;
@@ -666,7 +665,6 @@ int  main( int argc, char * argv[ ] )
         << wxT("VMIN=-20.00 VNTOL=3.00u WCZERO=1.10n");
 
   // Set things up for a formatter test
-  oCmd_OPT.bClear( );
   oCmd_OPT.m_osABSTOL   = wxT("1.20p");
   oCmd_OPT.m_bBYPASS    = FALSE;
   oCmd_OPT.m_osCHGTOL   = wxT("12.00f");
@@ -719,7 +717,6 @@ int  main( int argc, char * argv[ ] )
   cout << "\noCmd_OPT Contents : " << oCmd_OPT.mb_str( ) << '\n';
 
   // Set things up for a parser test
-  oCmd_OPT.bClear( );
   oCmd_OPT.bSetString( osCmd );
   cout << "\nRun Parser        : " << ( oCmd_OPT.bParse( ) ? "OK" : "FAULT" );
   oCmd_OPT.bFormat( );
