@@ -4,7 +4,7 @@
 // Description : This class contains values associated with the GNU-Cap       *
 //               OPTIONS command. It inherits from the class CmdBase.         *
 // Started     : 11/09/2006                                                   *
-// Last Update : 16/04/2010                                                   *
+// Last Update : 24/12/2010                                                   *
 // Copyright   : (C) 2006 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -152,7 +152,7 @@ struct CmdGnuCapOPT : public CmdBase
               CmdGnuCapOPT( void );
     virtual  ~CmdGnuCapOPT( );
 
-    virtual  bool  bClear( void );
+    virtual  bool  bSetDefaults( void );
 
     virtual  bool  bParse ( void );
     virtual  bool  bFormat( void );
