@@ -2,7 +2,7 @@
 //                               CmdGnuCapPR.cpp                              *
 //                              -----------------                             *
 // Started     : 17/03/2008                                                   *
-// Last Update : 16/04/2010                                                   *
+// Last Update : 12/08/2011                                                   *
 // Copyright   : (C) 2008 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -23,7 +23,7 @@
 
 CmdGnuCapPR::CmdGnuCapPR( void )
 {
-  bClear( );
+  bSetDefaults( );
 }
 
 //*****************************************************************************
@@ -58,17 +58,17 @@ bool  CmdGnuCapPR::bValidate( void )
 }
 
 //*****************************************************************************
-// Clear the object attributes.
+// Set the object attributes to they're default values.
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  CmdGnuCapPR::bClear( void )
+bool  CmdGnuCapPR::bSetDefaults( void )
 {
   int  i1;
 
-  CmdBase::bClear( );
+  CmdBase::bSetDefaults( );
 
   m_eSimEng  = eSIMR_GNUCAP;
   m_eCmdType = eCMD_PR;
@@ -133,7 +133,7 @@ bool  CmdGnuCapPR::bParse( void )
 
   // Clear the object attributes
   os1 = (wxString &) *this;
-  bClear( );
+  bSetDefaults( );
   assign( os1 );
 
   // Tokenize the command string
@@ -161,7 +161,7 @@ bool  CmdGnuCapPR::bParse( void )
     os1 = ostk1.GetNextToken( );
 
     // Extract the parameter specifiers
-    switch( os1.GetChar( 0 ) )
+    switch( (char) os1.GetChar( 0 ) )
     {
       case wxT('V') : m_bParmtrs[ ePAR_VLT ] = TRUE; break;
       case wxT('I') : m_bParmtrs[ ePAR_CUR ] = TRUE; break;
@@ -173,7 +173,7 @@ bool  CmdGnuCapPR::bParse( void )
     // Extract the complex parts if the analysis type is AC
     if( m_eAnaType == eCMD_AC )
     {
-      switch( os1.GetChar( 1 ) )
+      switch( (char) os1.GetChar( 1 ) )
       {
         case wxT('M') : m_bCpxPrts[ eCPX_MAG   ] = TRUE; break;
         case wxT('P') : m_bCpxPrts[ eCPX_PHASE ] = TRUE; break;
@@ -186,7 +186,7 @@ bool  CmdGnuCapPR::bParse( void )
             m_bCpxPrts[ eCPX_MAGDB ] = TRUE;
             break;
           }
-        default:                 return( bValidate( ) );
+        default :                return( bValidate( ) );
       }
     }
 
@@ -195,8 +195,13 @@ bool  CmdGnuCapPR::bParse( void )
     i2 = os1.Index( wxT(')') );
     if( i1!=-1 && i2!=-1 && i2>(i1+1) )
     {
+      // Get the label
       os1 = os1.Mid( (size_t) i1+1, (size_t) i2-i1-1 );
-      if( wxIsdigit( os1.GetChar( 0 ) ) )
+
+      // Add the label to the node or component label lists
+      if( wxIsdigit( os1.GetChar( 0 ) )                ||
+          Component::eGetCpntType( os1 ) == eCPNT_NONE ||
+          NetList::m_osaNodeLbls.Index( os1 ) != wxNOT_FOUND )
         { if( m_osaNodes.Index( os1 ) == wxNOT_FOUND ) m_osaNodes.Add( os1 ); }
       else
         { if( m_osaCpnts.Index( os1 ) == wxNOT_FOUND ) m_osaCpnts.Add( os1 ); }
@@ -411,7 +416,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdGnuCapPR Test Utility"
-       << "\n    Version 1.00 (15/04/2010)\n";
+       << "\n    Version 1.01 (12/08/2011)\n";
 
   // Create a NG-SPICE PRINT command object
   CmdGnuCapPR  oCmd_PR;
@@ -420,7 +425,6 @@ int  main( int argc, char * argv[ ] )
   osCmd = wxT(".PRINT AC VM(C1) VM(R1) VM(2) VP(C1) VP(R1) VP(2)");
 
   // Set things up for a formatter test
-  oCmd_PR.bClear( );
   oCmd_PR.m_eAnaType = eCMD_AC;
   oCmd_PR.m_osaCpnts.Add( wxT("C1") );
   oCmd_PR.m_osaCpnts.Add( wxT("R1") );
@@ -434,7 +438,6 @@ int  main( int argc, char * argv[ ] )
   cout << "\noCmdPR Contents : " << oCmd_PR.mb_str( ) << '\n';
 
   // Set things up for a parser test
-  oCmd_PR.bClear( );
   oCmd_PR.bSetString( osCmd );
   cout << "\nRun Parser      : " << ( oCmd_PR.bParse( ) ? "OK" : "FAULT" );
   oCmd_PR.bFormat( );
