@@ -315,7 +315,7 @@ void  DlgGcpCfgGEN::GetValues( CmdGnuCapGEN & roCmdGEN )
 
 bool  DlgGcpCfgGEN::bClear( void )
 {
-  m_oCmdGEN.bClear( );
+  m_oCmdGEN.bSetDefaults( );
 
   SetValues( m_oCmdGEN );
 
@@ -383,7 +383,7 @@ void  DlgGcpCfgGEN::OnBtnClear( wxCommandEvent & roEvtCmd )
 {
   CmdGnuCapGEN  oCmdGEN;
 
-  oCmdGEN.bClear( );
+  oCmdGEN.bSetDefaults( );
   SetValues( oCmdGEN );
 }
 
