@@ -2,7 +2,7 @@
 //                              DlgGcpCfgOPT.cpp                              *
 //                             ------------------                             *
 //  Started     : 14/09/2006                                                  *
-//  Last Update : 23/02/2010                                                  *
+//  Last Update : 11/04/2011                                                  *
 //  Copyright   : (C) 2006 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -32,7 +32,7 @@ END_EVENT_TABLE( )
 //*****************************************************************************
 // Constructor.
 //
-// Argument List:
+// Argument List :
 //   poWin - A pointer to the dialog parent window
 
 DlgGcpCfgOPT::DlgGcpCfgOPT( wxWindow * poWin ) :
@@ -160,31 +160,29 @@ void  DlgGcpCfgOPT::Create( void )
   m_oPnlVMAX    .bSetUnitsType( eUNITS_VOLT );
   m_oPnlVNTOL   .bSetUnitsType( eUNITS_VOLT );
 
-  m_oPnlVNTOL   .bSetDefUnits( wxT("uV") );
-
-  m_oPnlABSTOL  .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlCHGTOL  .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlDAMPST  .bSetVarType( SpinCtrl::eVAR_INT );
-  m_oPnlDEFAD   .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlDEFAS   .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlDEFL    .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlDEFW    .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlDTMIN   .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlDTRATIO .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlFLOOR   .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlGMIN    .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlHARMS   .bSetVarType( SpinCtrl::eVAR_INT );
-  m_oPnlITL1    .bSetVarType( SpinCtrl::eVAR_INT );
-  m_oPnlITL2    .bSetVarType( SpinCtrl::eVAR_INT );
-  m_oPnlITL4    .bSetVarType( SpinCtrl::eVAR_INT );
-  m_oPnlITL7    .bSetVarType( SpinCtrl::eVAR_INT );
-  m_oPnlITL8    .bSetVarType( SpinCtrl::eVAR_INT );
-  m_oPnlLIMIT   .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlNUMDGT  .bSetVarType( SpinCtrl::eVAR_INT );
-  m_oPnlSHORT   .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlTRANSITS.bSetVarType( SpinCtrl::eVAR_INT );
-  m_oPnlVFLOOR  .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlWCZERO  .bSetVarType( SpinCtrl::eVAR_SCI );
+  m_oPnlABSTOL  .bSetVarType( eVAR_SCI );
+  m_oPnlCHGTOL  .bSetVarType( eVAR_SCI );
+  m_oPnlDAMPST  .bSetVarType( eVAR_INT );
+  m_oPnlDEFAD   .bSetVarType( eVAR_SCI );
+  m_oPnlDEFAS   .bSetVarType( eVAR_SCI );
+  m_oPnlDEFL    .bSetVarType( eVAR_SCI );
+  m_oPnlDEFW    .bSetVarType( eVAR_SCI );
+  m_oPnlDTMIN   .bSetVarType( eVAR_SCI );
+  m_oPnlDTRATIO .bSetVarType( eVAR_SCI );
+  m_oPnlFLOOR   .bSetVarType( eVAR_SCI );
+  m_oPnlGMIN    .bSetVarType( eVAR_SCI );
+  m_oPnlHARMS   .bSetVarType( eVAR_INT );
+  m_oPnlITL1    .bSetVarType( eVAR_INT );
+  m_oPnlITL2    .bSetVarType( eVAR_INT );
+  m_oPnlITL4    .bSetVarType( eVAR_INT );
+  m_oPnlITL7    .bSetVarType( eVAR_INT );
+  m_oPnlITL8    .bSetVarType( eVAR_INT );
+  m_oPnlLIMIT   .bSetVarType( eVAR_SCI );
+  m_oPnlNUMDGT  .bSetVarType( eVAR_INT );
+  m_oPnlSHORT   .bSetVarType( eVAR_SCI );
+  m_oPnlTRANSITS.bSetVarType( eVAR_INT );
+  m_oPnlVFLOOR  .bSetVarType( eVAR_SCI );
+  m_oPnlWCZERO  .bSetVarType( eVAR_SCI );
 
   m_oPnlABSTOL  .bShowUnits( FALSE );
   m_oPnlCHGTOL  .bShowUnits( FALSE );
@@ -332,7 +330,7 @@ void  DlgGcpCfgOPT::Create( void )
   m_oCbxTRACEL  .Create( poPnl1, ID_CBX_TRACEL,   wxT("TRACEL   \t\t  "),
                          wxDefaultPosition, wxSize( -1, PNLVALUE_HT ),
                          wxALIGN_RIGHT );
-  m_oCbxVBYPASS .Create( poPnl1, ID_CBX_VBYPASS,  wxT("VBYPASS  \t\t  "),
+  m_oCbxVBYPASS .Create( poPnl1, ID_CBX_VBYPASS,  wxT("VBYPASS  \t  "),
                          wxDefaultPosition, wxSize( -1, PNLVALUE_HT ),
                          wxALIGN_RIGHT );
 
@@ -340,19 +338,6 @@ void  DlgGcpCfgOPT::Create( void )
   m_oBtnOk      .Create( poPnlBtns, ID_BTN_OK,       wxT("OK") );
   m_oBtnDefaults.Create( poPnlBtns, ID_BTN_DEFAULTS, wxT("Defaults") );
   m_oBtnCancel  .Create( poPnlBtns, ID_BTN_CANCEL,   wxT("Cancel") );
-
-// (15/10/2008) I suspect that the following just fixes a bug in wxWidgets, the
-// back-ground of the parent window isn't inherited by it's children
-m_oChoMETHOD  .GetParent()->SetBackgroundColour( this->GetBackgroundColour() ); // ???
-m_oChoMODE    .GetParent()->SetBackgroundColour( this->GetBackgroundColour() ); // ???
-m_oChoORDER   .GetParent()->SetBackgroundColour( this->GetBackgroundColour() ); // ???
-m_oCbxBYPASS  .GetParent()->SetBackgroundColour( this->GetBackgroundColour() ); // ???
-m_oCbxCSTRAY  .GetParent()->SetBackgroundColour( this->GetBackgroundColour() ); // ???
-m_oCbxINCMODE .GetParent()->SetBackgroundColour( this->GetBackgroundColour() ); // ???
-m_oCbxLUBYPASS.GetParent()->SetBackgroundColour( this->GetBackgroundColour() ); // ???
-m_oCbxRSTRAY  .GetParent()->SetBackgroundColour( this->GetBackgroundColour() ); // ???
-m_oCbxTRACEL  .GetParent()->SetBackgroundColour( this->GetBackgroundColour() ); // ???
-m_oCbxVBYPASS .GetParent()->SetBackgroundColour( this->GetBackgroundColour() ); // ???
 }
 
 //*****************************************************************************
@@ -580,10 +565,10 @@ void  DlgGcpCfgOPT::DoLayout( void )
 //*****************************************************************************
 // Get a pointer to a value panel associated with a control ID number.
 //
-// Argument List:
+// Argument List :
 //   iPnlID - The control ID number
 //
-// Return Values:
+// Return Values :
 //   Success - A pointer to the value panel
 //   Failure - NULL
 
@@ -809,13 +794,13 @@ bool  DlgGcpCfgOPT::bGetValues( CmdGnuCapOPT & roCmdOPT )
 //*****************************************************************************
 // Reset all dialog settings to defaults.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
 bool  DlgGcpCfgOPT::bClear( void )
 {
-  m_oCmdOPT.bClear( );
+  m_oCmdOPT.bSetDefaults( );
 
   SetValues( m_oCmdOPT );
 
@@ -825,11 +810,11 @@ bool  DlgGcpCfgOPT::bClear( void )
 //*****************************************************************************
 // Set a value panel control's value.
 //
-// Argument List:
+// Argument List :
 //   iPnlID   - Value panel control identifier
 //   rosValue - The value to set
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -853,10 +838,10 @@ bool  DlgGcpCfgOPT::bSetValue( int iPnlID, const wxString & rosValue )
 //*****************************************************************************
 // Get a value panel control's value.
 //
-// Argument List:
+// Argument List :
 //   iPnlID - Value panel control identifier
 //
-// Return Values:
+// Return Values :
 //   Success - The panel value
 //   Failure - 0.0
 
@@ -878,7 +863,7 @@ const wxString & DlgGcpCfgOPT::rosGetValue( int iPnlID )
 //*****************************************************************************
 // Ok button event handler.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - An object holding information about the event (not used)
 
 void  DlgGcpCfgOPT::OnBtnOk( wxCommandEvent & roEvtCmd )
@@ -890,21 +875,21 @@ void  DlgGcpCfgOPT::OnBtnOk( wxCommandEvent & roEvtCmd )
 //*****************************************************************************
 // Defaults button event handler.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - An object holding information about the event (not used)
 
 void  DlgGcpCfgOPT::OnBtnDefaults( wxCommandEvent & roEvtCmd )
 {
   CmdGnuCapOPT  oCmdOPT;
 
-  oCmdOPT.bClear( );
+  oCmdOPT.bSetDefaults( );
   SetValues( oCmdOPT );
 }
 
 //*****************************************************************************
 // Cancel button event handler.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - An object holding information about the event (not used)
 
 void  DlgGcpCfgOPT::OnBtnCancel( wxCommandEvent & roEvtCmd )
