@@ -2,7 +2,7 @@
 //                              PnlGnuCapAC.cpp                               *
 //                             -----------------                              *
 // Started     : 18/08/2003                                                   *
-// Last Update : 13/04/2010                                                   *
+// Last Update : 16/05/2011                                                   *
 // Copyright   : (C) 2003 by MSWaters                                         *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -52,12 +52,14 @@ PnlGnuCapAC::~PnlGnuCapAC( )
 
 void  PnlGnuCapAC::Create( void )
 {
+#ifndef LAYOUT_MNGR
   int  ix, iy;
 
   // Set the frequency sweep parameter labels
   m_oSbxSwpPars.GetSize( &ix, &iy );
   m_oSbxSwpPars.SetSize(  ix, 167 );
   m_oSbxSwpPars.SetLabel( wxT(" AC Sweep ") );
+#endif // LAYOUT_MNGR
   m_oPnlStart  .bSetName( wxT("Start Frequency") );
   m_oPnlStop   .bSetName( wxT("Stop Frequency") );
 
@@ -70,6 +72,12 @@ void  PnlGnuCapAC::Create( void )
   PnlAnaBase::CreateCpxPrt( ); // Create the parameter complex part check boxes
   PnlAnaBase::CreateSrc( );    // Create the input source controls
   PnlAnaBase::CreateTemp( );   // Create the analysis temperature controls
+
+  PnlAnaBase::DoLayout( );     // Layout the panel's GUI objects
+
+#ifdef LAYOUT_MNGR
+  SetSwpPnlLbl( wxT(" AC Sweep ") );
+#endif // LAYOUT_MNGR
 }
 
 //*****************************************************************************
@@ -81,28 +89,28 @@ void  PnlGnuCapAC::InitScale( void )
   {
     case eSCALE_LIN :
       m_oPnlStep.bSetName( wxT("Step Increment") );
-      m_oPnlStep.bSetVarType( SpinCtrl::eVAR_FLT );
+      m_oPnlStep.bSetVarType( eVAR_FLT );
       m_oPnlStep.bSetUnitsType( eUNITS_FREQ );
       m_oPnlStep.bShowUnits( TRUE );
       break;
 
     case eSCALE_LOG :
       m_oPnlStep.bSetName( wxT("Step Multiplier") );
-      m_oPnlStep.bSetVarType( SpinCtrl::eVAR_FLT );
+      m_oPnlStep.bSetVarType( eVAR_FLT );
       m_oPnlStep.bSetParms( 1.1, 0.01, 10.0, 1.0, 10.0 );
       m_oPnlStep.bShowUnits( FALSE );
       break;
 
     case eSCALE_DEC :
       m_oPnlStep.bSetName( wxT("Steps / Decade") );
-      m_oPnlStep.bSetVarType( SpinCtrl::eVAR_INT );
+      m_oPnlStep.bSetVarType( eVAR_INT );
       m_oPnlStep.bSetParms( 10, 1, 10000, 1, 100 );
       m_oPnlStep.bShowUnits( FALSE );
       break;
 
     case eSCALE_OCT :
       m_oPnlStep.bSetName( wxT("Steps / Octave") );
-      m_oPnlStep.bSetVarType( SpinCtrl::eVAR_INT );
+      m_oPnlStep.bSetVarType( eVAR_INT );
       m_oPnlStep.bSetParms( 10, 1, 10000, 1, 100 );
       m_oPnlStep.bShowUnits( FALSE );
       break;
@@ -165,6 +173,9 @@ bool  PnlGnuCapAC::bLoad( SimnGnuCap & roSimn )
   // Load the components into the signal source choice box
   PnlAnaBase::LoadSrcNames( roSimn.m_oaCpnts, wxT("VI") );
 
+  // Go no further if the AC command isn't valid
+  if( ! roSimn.m_oCmdAC.bIsValid( ) )                        return( FALSE );
+
   // Set the source component
   if( ! PnlAnaBase::bSetSrcCpnt( roSimn.m_oCpntSwpSrc ) )    bRtn = FALSE;
 
