@@ -5,7 +5,7 @@
 //                provides a GUI for a user to configure a DC Analysis for    *
 //                GNU-Cap electronic circuit simulator.                       *
 //  Started     : 18/08/2003                                                  *
-//  Last Update : 30/06/2009                                                  *
+//  Last Update : 18/03/2011                                                  *
 //  Copyright   : (C) 2003 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -25,7 +25,7 @@
 // System Includes
 
 
-// wxWindows Library Includes
+// wxWidgets Library Includes
 
 
 // Application Includes
@@ -40,14 +40,21 @@
 
 class PnlGnuCapDC : public PnlAnaBase
 {
-  private:
+  private :
 
-    void  Create( void );
+    // Display objects
+    wxLabel   m_oLblSrcName;
+
+    // Functions to create the display objects
+    void  CreateSrc( void );
+    void  Create   ( void );
+
+    void  DoLayout( void );
 
              void  InitSwpUnits( void );
     virtual  void  InitScale( void );
 
-  public:
+  public :
 
     PnlGnuCapDC( wxWindow * poWin );
    ~PnlGnuCapDC( );
