@@ -2,7 +2,7 @@
 //                              PnlGnuCapFO.cpp                               *
 //                             -----------------                              *
 // Started     : 26/04/2004                                                   *
-// Last Update : 21/08/2009                                                   *
+// Last Update : 16/05/2011                                                   *
 // Copyright   : (C) 2004 by MSWaters                                         *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -53,12 +53,14 @@ PnlGnuCapFO::~PnlGnuCapFO( )
 void  PnlGnuCapFO::Create( void )
 {
   wxStaticBox * poSbxSigSrc;
+#ifndef LAYOUT_MNGR
   int           ix, iy;
 
   // Set the frequency sweep parameter labels
   m_oSbxSwpPars.GetSize( &ix, &iy );
   m_oSbxSwpPars.SetSize(  ix, 167 );
   m_oSbxSwpPars.SetLabel( wxT(" Frequency Sweep ") );
+#endif // LAYOUT_MNGR
   m_oPnlStart  .bSetName( wxT("Start Frequency") );
   m_oPnlStop   .bSetName( wxT("Stop Frequency") );
   m_oPnlStep   .bSetName( wxT("Step Increment") );
@@ -80,6 +82,12 @@ void  PnlGnuCapFO::Create( void )
   CreateOutputs( );           // Create and add output parameters
   PnlAnaBase::CreateInitC( ); // Create and add the initial conditions controls
   PnlAnaBase::CreateTemp( );  // Create and add the analysis temp. controls
+
+//  PnlAnaBase::DoLayout( );    // Layout the panel's GUI objects
+
+#ifdef LAYOUT_MNGR
+  SetSwpPnlLbl( wxT(" Frequency Sweep ") );
+#endif // LAYOUT_MNGR
 }
 
 //*****************************************************************************
@@ -201,6 +209,9 @@ bool  PnlGnuCapFO::bLoad( SimnGnuCap & roSimn )
   // Load the components into the signal source choice box
   PnlAnaBase::LoadSrcNames( roSimn.m_oaCpnts, wxT("VI") );
 
+  // Go no further if the FO command isn't valid
+  if( ! roSimn.m_oCmdFO.bIsValid( ) )                        return( FALSE );
+
   // Set the sweep source
   if( ! PnlAnaBase::bSetSrcCpnt( roSimn.m_oCpntSwpSrc ) )    bRtn = FALSE;
 
@@ -279,7 +290,7 @@ bool  PnlGnuCapFO::bSave( SimnGnuCap & roSimn )
   else
   {
     roSimn.m_oCpntSwpSrc.bClear( );
-    roSimn.m_oCmdGEN    .bClear( );
+    roSimn.m_oCmdGEN    .bSetDefaults( );
   }
 
   // Set the analysis type
