@@ -25,7 +25,7 @@
 // System Includes
 
 
-// wxWindows Library Includes
+// wxWidgets Library Includes
 
 
 // Application Includes
@@ -43,6 +43,8 @@ class PnlGnuCapOP : public PnlAnaBase
 
     void  Create( void );
 
+    void  DoLayout( void );
+
     virtual  void  InitScale( void );
 
   public :
