@@ -2,7 +2,7 @@
 //                              PnlGnuCapTR.cpp                               *
 //                             -----------------                              *
 // Started     : 22/02/2004                                                   *
-// Last Update : 21/08/2009                                                   *
+// Last Update : 16/05/2011                                                   *
 // Copyright   : (C) 2004 by MSWaters                                         *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -53,12 +53,14 @@ PnlGnuCapTR::~PnlGnuCapTR( )
 void  PnlGnuCapTR::Create( void )
 {
   wxStaticBox * poSbxSigSrc;
+#ifndef LAYOUT_MNGR
   int           ix, iy;
 
   // Set the frequency sweep parameter labels
   m_oSbxSwpPars.GetSize( &ix, &iy );
   m_oSbxSwpPars.SetSize(  ix, 167 );
-  m_oSbxSwpPars.SetLabel( wxT(" Transient Sweep ") );
+  m_oSbxSwpPars.SetLabel( wxT(" Time Sweep ") );
+#endif // LAYOUT_MNGR
   m_oPnlStart  .bSetName( wxT("Start Time") );
   m_oPnlStop   .bSetName( wxT("Stop Time") );
   m_oPnlStep   .bSetName( wxT("Step Increment") );
@@ -79,6 +81,12 @@ void  PnlGnuCapTR::Create( void )
 
   PnlAnaBase::CreateInitC( ); // Create and add the initial conditions controls
   PnlAnaBase::CreateTemp( );  // Create and add the analysis temp. controls
+
+//  PnlAnaBase::DoLayout( );    // Layout the panel's GUI objects
+
+#ifdef LAYOUT_MNGR
+  SetSwpPnlLbl( wxT(" Time Sweep ") );
+#endif // LAYOUT_MNGR
 }
 
 //*****************************************************************************
@@ -129,6 +137,9 @@ bool  PnlGnuCapTR::bLoad( SimnGnuCap & roSimn )
   // Load the components into the signal source choice box
   PnlAnaBase::LoadSrcNames( roSimn.m_oaCpnts, wxT("VI") );
 
+  // Go no further if the TR command isn't valid
+  if( ! roSimn.m_oCmdTR.bIsValid( ) )                        return( FALSE );
+
   // Set the sweep source
   if( ! PnlAnaBase::bSetSrcCpnt( roSimn.m_oCpntSwpSrc ) )    bRtn = FALSE;
 
@@ -204,7 +215,7 @@ bool  PnlGnuCapTR::bSave( SimnGnuCap & roSimn )
   else
   {
     roSimn.m_oCpntSwpSrc.bClear( );
-    roSimn.m_oCmdGEN    .bClear( );
+    roSimn.m_oCmdGEN    .bSetDefaults( );
   }
 
   // Set the analysis type
