@@ -2,7 +2,7 @@
 //                                FileTasks.cpp                               *
 //                               ---------------                              *
 // Started     : 28/05/2005                                                   *
-// Last Update : 19/03/2010                                                   *
+// Last Update : 29/08/2011                                                   *
 // Copyright   : (C) 2005 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -82,7 +82,7 @@ void  FileTasks::InitGuileProc( void )
   wxString  os1;
 
   // Set the Guile procedure name
-  m_poCfg->SetPath( wxT("/gNetList") );
+  m_poCfg->SetPath( wxT("/gnetlist") );
   os1 = m_poCfg->Read( wxT("GuileProc"), wxT("spice-sdb") );
   bSetGuileProc( os1 );
 }
@@ -150,20 +150,24 @@ void  FileTasks::InitNetLstFile( void )
 
 void  FileTasks::DlgErrSchems( void )
 {
-  wxString  os1, os2;
-  size_t    szt1;
+  wxString  os1, os2, os3;
+  size_t    sz1;
 
-  for( szt1=0; szt1<m_oPrcGNetList.rofnaGetSchemFiles( ).GetCount( ); szt1++ )
-    os2 << wxT("     ") << m_oPrcGNetList.rofnGetSchemFile( szt1 ).GetFullPath( )
+  for( sz1=0; sz1<m_oPrcGNetList.roaGetSchemFiles( ).GetCount( ); sz1++ )
+    os2 << wxT("     ") << m_oPrcGNetList.roGetSchemFile( sz1 ).GetFullPath( )
         << wxT("\n");
 
-  os1 << wxT("The schematic file/s couldn't be converted to a netlist file :\n")
+  if( sz1 > 1 ) os3 = wxT("s were");
+  else          os3 = wxT(" was");
+
+  os1 << wxT("The schematic file") << os3
+                             << wxT("n't converted to a netlist correctly :\n")
       << wxT("\n")
       << os2
       << wxT("\n")
-      << wxT("(This is usually because gnetlist encountered error/s while\n")
+      << wxT("(This is usually because gnetlist encountered problems/s while\n")
       << wxT("attempting to convert the schematic file/s to a netlist. Try\n")
-      << wxT("examining the console output to determine where the problem\n")
+      << wxT("examining the Console output to determine where the problem/s\n")
       << wxT("occurred.)\n");
 
   m_poFrmMain->DlgErrMsg( wxT("Import Schematic/s Error"), os1 );
@@ -176,9 +180,9 @@ void  FileTasks::DlgErrNetLst( void )
 {
   wxString  os1;
 
-  os1 << wxT("The netlist file couldn't be loaded :\n")
+  os1 << wxT("The netlist file wasn't loaded correctly :\n")
       << wxT("\n")
-      << wxT("     ") << m_oPrcGNetList.rofnGetNetLstFile( ).GetFullPath( ) << wxT('\n')
+      << wxT("     ") << m_oPrcGNetList.roGetNetLstFile().GetFullPath() << wxT('\n')
       << wxT("\n")
       << wxT("(This is often because the file is in-complete, empty or\n")
       << wxT("doesn't exist.)\n");
@@ -186,79 +190,6 @@ void  FileTasks::DlgErrNetLst( void )
   m_poFrmMain->DlgErrMsg( wxT("Load Netlist Error"), os1 );
 }
 
-//*****************************************************************************
-// Delete temporary files which may have been generated by this application.
-// Ie. given the circuit description file "<netlist>.ckt" delete files of the
-//     following form :
-//       <netlist>.ngspice.dc, <netlist>.ngspice.ac, ... etc.
-//       <netlist>.gnucap.op,  <netlist>.gnucap.dc, .... etc.
-//       gnetlist.log
-
-bool  FileTasks::bDelTmpFiles( void )
-{
-  wxArrayString  osa1;
-  wxFileName     ofn1;
-  wxString       os1, os2;
-  long           liTmpFileMgt;
-  int            i1;
-
-  // Determine the current temporary file management strategy
-  m_poCfg->SetPath( wxT("/Main") );
-  m_poCfg->Read( wxT("TmpFileMgt"), &liTmpFileMgt, (long) eTFMS_DELETE );
-
-  // Return if nothing needs to be done
-  if( liTmpFileMgt == (long) eTFMS_KEEP ) return( TRUE );
-
-  // Get the path to the schematic or circuit description file
-  ofn1 = m_oPrcGNetList.rofnGetNetLstFile( );
-  ofn1.Normalize( );
-  if( !ofn1.IsOk( ) || !ofn1.FileExists( ) ) return( FALSE );
-
-  // Look for the gnetlist log file
-  os1 = ofn1.GetPath( ) + wxT("/gnetlist.log");
-  if( wxFileExists( os1 ) ) osa1.Add( os1 );
-
-  os1 = ofn1.GetName( );
-  i1 = os1.Find( wxT(".gspiceui") );
-  if( i1 > 0 ) os1 = os1.Truncate( (size_t) i1 );
-  ofn1.SetFullName( os1 );
-
-  // Look for any GNU-Cap results file
-  os1 = ofn1.GetFullPath( ) + wxT(".gnucap.??");
-  for( os2=wxFindFirstFile( os1 ); !os2.IsEmpty( ); os2=wxFindNextFile( ) )
-    osa1.Add( os2 );
-
-  // Look for any Ng-Spice results files
-  os1 = ofn1.GetFullPath( ) + wxT(".ngspice.??");
-  for( os2=wxFindFirstFile( os1 ); !os2.IsEmpty( ); os2=wxFindNextFile( ) )
-    osa1.Add( os2 );
-
-  // If necessary prompt the user for permission to delete temporary files
-  if( osa1.GetCount( ) > 0 )
-  {
-    if( m_poFrmMain!=NULL && m_poFrmMain->IsShown( ) )
-    {
-      // Prompt the user
-      if( liTmpFileMgt == (long) eTFMS_PROMPT )
-      {
-        os1 = wxT("Delete Temporary Files");
-        os2 = wxT("\nDelete the following temporary files :\n\n");
-        for( i1=0; i1<(int)osa1.GetCount( ); i1++ )
-          os2 << wxT("  ") << osa1.Item( i1 ) << wxT("   \n");
-        i1 = wxMessageBox( os2, os1, wxYES_NO|wxICON_QUESTION, m_poFrmMain );
-      }
-      else i1 = wxYES;
-
-      // Delete the temporary files
-      if( i1 == wxYES )
-        for( i1=0; i1<(int)osa1.GetCount( ); i1++ )
-          wxRemoveFile( osa1.Item( i1 ) );
-    }
-  }
-
-  return( TRUE );
-}
-
 //*****************************************************************************
 // Do initialization tasks.
 
@@ -270,14 +201,14 @@ void  FileTasks::Initialize( void )
 }
 
 //*****************************************************************************
-// Check that the gNetList binary can be found, if not display an error
+// Check that the gnetlist binary can be found, if not display an error
 // message.
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  FileTasks::bIsOkGNetList( void )
+bool  FileTasks::bIsOk_gnetlist( void )
 {
   wxString  os1;
 
@@ -286,9 +217,9 @@ bool  FileTasks::bIsOkGNetList( void )
   {
     if( m_poFrmMain != NULL )
     {
-      os1 << wxT("\nCan't find ") << m_oPrcGNetList.rofnGetBinary( ).GetFullName( )
-          << wxT(" which is required to import a schematic\nfile. ")
-          << wxT("There is no path to it or it has not been installed.\n\n");
+      os1 << wxT("Can't find ") << m_oPrcGNetList.roGetBinary( ).GetFullName( )
+          << wxT(" which is required to import schematic\nfile/s. ")
+          << wxT("The path is unknown or it hasn't been installed.\n");
       m_poFrmMain->DlgErrMsg( wxT("Configuration Fault"), os1 );
     }
     return( FALSE );
@@ -312,7 +243,7 @@ bool  FileTasks::bSetTitle( void )
   if( m_poFrmMain == NULL ) return( FALSE );
 
   // Create the title line
-  os1 << wxT(" ") << APP_NAME << wxT(",  ") << APP_VERSION;
+  os1 << wxT(" ") << APP_NAME;
   if( ! rosGetNetLstFile( ).IsEmpty( ) )
   {
     ofn1 = rosGetNetLstFile( );
@@ -435,9 +366,9 @@ const wxArrayString & FileTasks::rosaGetSchemFiles( void )
 
   osa1.Clear( );
 
-  for( szt1=0; szt1<m_oPrcGNetList.rofnaGetSchemFiles( ).GetCount( ); szt1++ )
+  for( szt1=0; szt1<m_oPrcGNetList.roaGetSchemFiles( ).GetCount( ); szt1++ )
   {
-    os1 = m_oPrcGNetList.rofnGetSchemFile( szt1 ).GetFullPath( );
+    os1 = m_oPrcGNetList.roGetSchemFile( szt1 ).GetFullPath( );
     if( ! os1.IsEmpty( ) ) osa1.Add( os1 );
   }
 
@@ -454,7 +385,7 @@ const wxString & FileTasks::rosGetNetLstFile( void )
 {
   static  wxString  osNetLstFile;
 
-  osNetLstFile = m_oPrcGNetList.rofnGetNetLstFile( ).GetFullPath( );
+  osNetLstFile = m_oPrcGNetList.roGetNetLstFile( ).GetFullPath( );
 
   return( osNetLstFile );
 }
@@ -481,7 +412,7 @@ bool  FileTasks::bDlgOpen( void )
       << wxT("Circuit files (*.cir)|*.cir|")
       << wxT("Netlist files (*.net)|*.net");
 
-  // Get the netlist file path from the global configuration object
+  // Get the file path from the global configuration object
   m_poCfg->SetPath( wxT("/Directories") );
   os2 = m_poCfg->Read( wxT("LastAccess"), wxGetHomeDir( ) );
 
@@ -503,8 +434,10 @@ bool  FileTasks::bDlgOpen( void )
   // Display file open dialog
   if( poDlgOpen->ShowModal( ) != wxID_OK ) return( FALSE );
 
+  // Delete temporary files
+  bDelTmpFiles( );
+
   // Set the netlist file name
-  m_oPrcGNetList.bClear( );
   os1 = poDlgOpen->GetPath( );
   if( ! bSetNetLstFile( os1 ) )            return( FALSE );
 
@@ -538,7 +471,7 @@ bool  FileTasks::bDlgImport( void )
   os1 << wxT("gSchem files (*.sch)|*.sch|")
       << wxT("Protel II files (*.\?\?\?)|*.\?\?\?");
 
-  // Get the netlist file path from the global configuration object
+  // Get the file path from the global configuration object
   m_poCfg->SetPath( wxT("/Directories") );
   os2 = m_poCfg->Read( wxT("LastAccess"), wxGetHomeDir( ) );
 
@@ -560,15 +493,22 @@ bool  FileTasks::bDlgImport( void )
   // Display file import dialog
   if( poDlgImport->ShowModal( ) != wxID_OK ) return( FALSE );
 
-  // Set the guile procedure and schematic file name/s
-  m_oPrcGNetList.bClear( );
+  // Delete temporary files
+  bDelTmpFiles( );
+
+  // Set the guile procedure name
   bSetGuileProc( wxT("spice-sdb") );
+
+  // Set the schematic file name/s
   poDlgImport->GetPaths( osa1 );
   os1 = osa1.Item( 0 );
   for( sz1=1; sz1<osa1.GetCount( ); sz1++ )
     os1 << osa1.Item( sz1 ) << wxT(' ');
   if( ! bSetSchemFiles( os1 ) )              return( FALSE );
 
+  // Set the netlist file name (derive it from the schematic file name)
+  bSetNetLstFile( );
+
   // Set the path last accessed in the global configuration object
   m_poCfg->SetPath( wxT("/Directories") );
   m_poCfg->Write( wxT("LastAccess"), poDlgImport->GetDirectory( ) );
@@ -578,8 +518,82 @@ bool  FileTasks::bDlgImport( void )
 }
 
 //*****************************************************************************
-// Open and load a circuit description (netlist) file into the FrmMain
-// attribute simulation objects.
+// Delete temporary files which may have been generated by this application.
+// Ie. given the circuit description file "<netlist>.ckt" delete files of the
+//     following form :
+//       <netlist>.ngspice.dc, <netlist>.ngspice.ac, ... etc.
+//       <netlist>.gnucap.op,  <netlist>.gnucap.dc, .... etc.
+//       gnetlist.log
+
+bool  FileTasks::bDelTmpFiles( void )
+{
+  wxArrayString  osa1;
+  wxFileName     ofn1;
+  wxString       os1, os2;
+  long           liTmpFileMgt;
+  int            i1;
+
+  // Determine the current temporary file management strategy
+  m_poCfg->SetPath( wxT("/Main") );
+  m_poCfg->Read( wxT("TmpFileMgt"), &liTmpFileMgt, (long) eTFMS_DELETE );
+
+  // Return if nothing needs to be done
+  if( liTmpFileMgt == (long) eTFMS_KEEP )    return( TRUE );
+
+  // Get the path to the schematic or circuit description file
+  ofn1 = m_oPrcGNetList.roGetNetLstFile( );
+  ofn1.Normalize( );
+  if( !ofn1.IsOk( ) || !ofn1.FileExists( ) ) return( FALSE );
+
+  // Look for the gnetlist log file
+  os1 = ofn1.GetPath( ) + wxT("/gnetlist.log");
+  if( wxFileExists( os1 ) ) osa1.Add( os1 );
+
+  // Look for files containing simulation results
+  os1 = ofn1.GetName( );
+  i1 = os1.Find( wxT(".gspiceui") );
+  if( i1 > 0 ) os1 = os1.Truncate( (size_t) i1 );
+  ofn1.SetFullName( os1 );
+
+  // Look for any GNU-Cap results file
+  os1 = ofn1.GetFullPath( ) + wxT(".gnucap.??");
+  for( os2=wxFindFirstFile( os1 ); !os2.IsEmpty( ); os2=wxFindNextFile( ) )
+    osa1.Add( os2 );
+
+  // Look for any NG-Spice results files
+  os1 = ofn1.GetFullPath( ) + wxT(".ngspice.??");
+  for( os2=wxFindFirstFile( os1 ); !os2.IsEmpty( ); os2=wxFindNextFile( ) )
+    osa1.Add( os2 );
+
+  // If necessary prompt the user for permission to delete temporary files
+  if( osa1.GetCount( ) > 0 )
+  {
+    if( m_poFrmMain!=NULL && m_poFrmMain->IsShown( ) )
+    {
+      // Prompt the user
+      if( liTmpFileMgt == (long) eTFMS_PROMPT )
+      {
+        os1 = wxT("Delete Temporary Files");
+        os2 = wxT("\nDelete the following temporary files :\n\n");
+        for( i1=0; i1<(int)osa1.GetCount( ); i1++ )
+          os2 << wxT("  ") << osa1.Item( i1 ) << wxT("   \n");
+        i1 = wxMessageBox( os2, os1, wxYES_NO|wxICON_QUESTION, m_poFrmMain );
+      }
+      else i1 = wxYES;
+
+      // Delete the temporary files
+      if( i1 == wxYES )
+        for( i1=0; i1<(int)osa1.GetCount( ); i1++ )
+          wxRemoveFile( osa1.Item( i1 ) );
+    }
+  }
+
+  return( TRUE );
+}
+
+//*****************************************************************************
+// Open and load a circuit description (netlist) file into the m_poFrmMain
+// attribute's simulation objects.
 //
 // Return Values :
 //   TRUE  - Success
@@ -589,31 +603,27 @@ bool  FileTasks::bOpen( void )
 {
   bool  bRtn=TRUE;
 
-  // Change the cursor to the wait symbol
-  ::wxBeginBusyCursor( );
-
-  // Clear the main frame object attributes
-  m_poFrmMain->bClear( );
-
   // Attempt to load the circuit description file
-  m_poFrmMain->m_oSimnNgs.bLoadFile( );
-  m_poFrmMain->m_oSimnGcp.bLoadFile( );
-  if( m_poFrmMain->m_oNetLst.bIsValid( ) )
-    m_poFrmMain->SetStatusText( wxT(" Netlist file opened successfully"), 1 );
-  else
+  if(      m_poFrmMain->m_oSimnNgs.bLoadFile( ) )
+    m_poFrmMain->m_oSimnGcp = m_poFrmMain->m_oSimnNgs;
+  else if( m_poFrmMain->m_oSimnGcp.bLoadFile( ) )
+    m_poFrmMain->m_oSimnNgs = m_poFrmMain->m_oSimnGcp;
+
+  // Check for problems
+  if( ! m_poFrmMain->m_oNetLst.bIsValid( ) )
   {
     DlgErrNetLst( );
     m_poFrmMain->m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_NETLIST );
     bRtn = FALSE;
   }
+  else
+    m_poFrmMain->SetStatusText( wxT(" Netlist file opened successfully"),
+                                FrmMain::ePANE_MESG );
 
   // Set the main frame title and the schematic file name/s if supplied
   bSetTitle( );
   bSetSchemFiles( m_poFrmMain->m_oNetLst.rosGetSchemFiles( ) );
 
-  // Change the cursor to the default
-  ::wxEndBusyCursor( );
-
   return( bRtn );
 }
 
@@ -630,22 +640,17 @@ bool  FileTasks::bImport( void )
   bool  bRtn=TRUE;
 
   // Check that gNetList binary exists and is accessible
-  if( ! bIsOkGNetList( ) ) return( FALSE );
-
-  // Change the cursor to the wait symbol
-  ::wxBeginBusyCursor( );
-
-  // Clear the main frame object attributes
-  m_poFrmMain->bClear( );
+  if( ! bIsOk_gnetlist( ) ) return( FALSE );
 
   // Convert the schematic file/s to a netlist file and load it
   if( bExecImport( ) )
   {
-    bSetNetLstFile( m_oPrcGNetList.rofnGetNetLstFile( ).GetFullPath( ) );
+    bSetNetLstFile( m_oPrcGNetList.roGetNetLstFile( ).GetFullPath( ) );
     m_poFrmMain->m_oSimnNgs.bLoadFile( );
     m_poFrmMain->m_oSimnGcp.bLoadFile( );
     if( m_poFrmMain->m_oNetLst.bIsValid( ) )
-      m_poFrmMain->SetStatusText( wxT(" Schematic file/s imported successfully"), 1 );
+      m_poFrmMain->SetStatusText( wxT(" Schematic file/s imported successfully"),
+                                  FrmMain::ePANE_MESG );
     else
     {
       DlgErrNetLst( );
@@ -664,9 +669,6 @@ bool  FileTasks::bImport( void )
   // Set the main frame title
   bSetTitle( );
 
-  // Change the cursor to the default
-  ::wxEndBusyCursor( );
-
   return( bRtn );
 }
 
@@ -679,40 +681,34 @@ bool  FileTasks::bImport( void )
 
 bool  FileTasks::bReload( void )
 {
-  bool  bRtn=TRUE;
-
-  // Change the cursor to the wait symbol
-  ::wxBeginBusyCursor( );
+  bool  bRtn;
 
   // Re-initialize the text control notebook
   m_poFrmMain->m_oNbkTxtCtls.bInitialize( );
 
-  // If schematic file/s have been specified perform an import operation
-  if( ! m_oPrcGNetList.rofnaGetSchemFiles( ).IsEmpty( ) )
-  {
-    if( bImport( ) )
-      m_poFrmMain->SetStatusText( wxT(" Schematic file/s re-imported successfully"), 1 );
-    else
-      bRtn = FALSE;
+  // Attempt to perform the reload operation
+  if( ! m_oPrcGNetList.roaGetSchemFiles( ).IsEmpty( ) )
+  { // Reload schematic file/s
+    bRtn = bImport( );
+    if( bRtn )
+      m_poFrmMain->SetStatusText( wxT(" Schematic file/s re-imported successfully"),
+                                  FrmMain::ePANE_MESG );
   }
-  else if( m_oPrcGNetList.rofnGetNetLstFile( ).IsOk( ) )
-  {
-    if( bOpen( ) )
-      m_poFrmMain->SetStatusText( wxT(" Netlist file reloaded successfully"), 1 );
-    else
-      bRtn = FALSE;
+  else if( m_oPrcGNetList.roGetNetLstFile( ).IsOk( ) )
+  { // Reload a netlist file
+    bRtn = bOpen( );
+    if( bRtn )
+      m_poFrmMain->SetStatusText( wxT(" Netlist file reloaded successfully"),
+                                  FrmMain::ePANE_MESG );
   }
   else
   {
-    // There was no schematic or netlist to load, display an error message
-    bRtn = FALSE;
+    // There's no open schematic or netlist to reload, display an error message
     m_poFrmMain->DlgErrMsg( wxT("Reload Operation Error"),
                             wxT("No file is currently open.") );
+    bRtn = FALSE;
   }
 
-  // Change the cursor to the default
-  ::wxEndBusyCursor( );
-
   return( bRtn );
 }
 
@@ -725,6 +721,16 @@ bool  FileTasks::bReload( void )
 
 bool  FileTasks::bClose( void )
 {
+  // Is there a file currently open?
+  if( m_oPrcGNetList.roaGetSchemFiles( ).IsEmpty( ) &&
+      ! m_oPrcGNetList.roGetNetLstFile( ).IsOk( ) )
+  {
+    // There's no open schematic or netlist to close, display an error message
+    m_poFrmMain->DlgErrMsg( wxT("Close Operation Error"),
+                            wxT("No file is currently open.") );
+    return( FALSE );
+  }
+
   // Delete temporary files
   bDelTmpFiles( );
 
@@ -733,6 +739,13 @@ bool  FileTasks::bClose( void )
   bSetNetLstFile( wxT("") );
   bSetSchemFiles( wxT("") );
 
+  // Set the status bar message
+  m_poFrmMain->SetStatusText( wxT(" Netlist file closed successfully"),
+                              FrmMain::ePANE_MESG );
+
+  // Set the text control notebook page
+  m_poFrmMain->m_oNbkTxtCtls.bSetPage( NbkTxtCtls::ePAGE_CONSOLE );
+
   return( TRUE );
 }
 
