@@ -4,7 +4,7 @@
 // Description : This is a helper class for FrmMain, it handles most of the   *
 //               file operations.                                             *
 // Started     : 28/05/2005                                                   *
-// Last Update : 19/03/2010                                                   *
+// Last Update : 29/08/2011                                                   *
 // Copyright   : (C) 2005 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -25,7 +25,7 @@
 
 #include <iostream>
 
-// wxWindows includes
+// wxWidgets includes
 
 #include <wx/wx.h>
 #include <wx/config.h>
@@ -34,7 +34,6 @@
 
 class FrmMain;
 
-#include "Version.hpp"
 #include "TypeDefs.hpp"
 #include "base/SimnBase.hpp"
 #include "process/PrcGSchem.hpp"
@@ -48,7 +47,7 @@ class FileTasks
 
     FrmMain    * m_poFrmMain;     // Pointer to application main frame
     wxConfig   * m_poCfg;         // Pointer to global configuration object
-    PrcGNetList  m_oPrcGNetList;  // gNetList file conversion utility
+    PrcGNetList  m_oPrcGNetList;  // gnetlist file conversion utility
 
     // Object initialization functions
     void  InitGuileProc ( void );
@@ -59,7 +58,6 @@ class FileTasks
     void  DlgErrNetLst  ( void );
 
     bool  bExecImport   ( void );
-    bool  bDelTmpFiles  ( void );
 
   public :
 
@@ -68,12 +66,12 @@ class FileTasks
 
     void  Initialize( void ); // This function calls all the initialization fns
 
-    bool  bIsOkGNetList( void );
+    bool  bIsOk_gnetlist( void );
 
     bool  bSetTitle     ( void );
     bool  bSetGuileProc ( const wxString & rosPName  );
     bool  bSetSchemFiles( const wxString & rosFNames );
-    bool  bSetNetLstFile( const wxString & rosFName  );
+    bool  bSetNetLstFile( const wxString & rosFName=GNETLST_USE_SCHEM );
     bool  bSetLogFile   ( const wxString & rosFName  )
                           { return( m_oPrcGNetList.bSetLogFile( rosFName ) ); }
 
@@ -81,8 +79,9 @@ class FileTasks
     const wxArrayString & rosaGetSchemFiles( void );
     const wxString      &  rosGetNetLstFile( void );
 
-    bool  bDlgOpen  ( void );
-    bool  bDlgImport( void );
+    bool  bDlgOpen    ( void );
+    bool  bDlgImport  ( void );
+    bool  bDelTmpFiles( void );
 
     bool  bOpen  ( void );
     bool  bImport( void );
