@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                                FrmMain.hpp                                 *
 //                               -------------                                *
-//  Description : The main frame used to contain the applications display     *
-//                objects.                                                    *
-//  Started     : 18/08/2003                                                  *
-//  Last Update : 18/09/2009                                                  *
-//  Copyright   : (C) 2003 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : The main frame used to contain the applications display      *
+//               objects.                                                     *
+// Started     : 18/08/2003                                                   *
+// Last Update : 23/05/2011                                                   *
+// Copyright   : (C) 2003 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -27,7 +27,7 @@ using  namespace  std;
 
 #include <iostream>
 
-// wxWindows Includes
+// wxWidgets Includes
 
 #include <wx/wx.h>
 #include <wx/config.h>
@@ -58,15 +58,22 @@ using  namespace  std;
 #include "gnucap/NbkGnuCap.hpp"
 #include "ngspice/NbkNgSpice.hpp"
 
-// Local Constant Declarations
-
-
 //*****************************************************************************
 
 class FrmMain : public wxFrame
 {
   private :
 
+    // Define an enumerated type for the different status bar panes
+    enum ePaneType
+    {
+      ePANE_MESG = 0,
+      ePANE_SIMR = 1,
+      ePANE_VIEW = 2,
+
+      ePANE_LAST = ePANE_VIEW
+    };
+
     // Object attributes
     bool          m_bIsOpen;      // Flag indicating when the frame has closed
 
@@ -79,18 +86,18 @@ class FrmMain : public wxFrame
     NetList       m_oNetLst;      // The netlist object
     SimnNgSpice   m_oSimnNgs;     // NG-Spice simulation object
     SimnGnuCap    m_oSimnGcp;     // GNU-Cap  simulation object
-    SimnBase    * m_poSimultn;    // A pointer to the simulation object
+    SimnBase    * m_poSimn;       // A pointer to the simulation object
 
     PrcSimrBase * m_poPrcSimEng;  // Pointer to the simulator engine process
-    PrcGSchem     m_oPrcGSchem;   // Process object to schematic capture
-    PrcGaw        m_oPrcGaw;      // Process object to view simulation results
-    PrcGWave      m_oPrcGWave;    // Process object to view simulation results
+    PrcGSchem     m_oPrc_gschem;  // Process object to schematic capture
+    PrcGaw        m_oPrc_gaw;     // Process object to view simulation results
+    PrcGWave      m_oPrc_gwave;   // Process object to view simulation results
 
     // Display control objects
     NbkSimrBase * m_poNbkSimEng;  // Pointer to the simulation engine notebook
-    wxStaticText  m_oLblNodes;    // Label above the test nodes list
+    wxLabel       m_oLblNodes;    // Label above the test nodes list
     wxListBox     m_oLbxNodes;    // List of possible test nodes
-    wxStaticText  m_oLblCpnts;    // Label above the test components list
+    wxLabel       m_oLblCpnts;    // Label above the test components list
     wxListBox     m_oLbxCpnts;    // List of possible test components
     NbkTxtCtls    m_oNbkTxtCtls;  // Notebook containing the text controls
 
@@ -105,13 +112,11 @@ class FrmMain : public wxFrame
     void  InitSimEng  ( void );
     void  InitLogFiles( void );
     void  InitPosnSize( void );
-    void  DoLayout( void );
+    void  DoLayout    ( void );
 
-    bool  bSimLoad  ( void );
-    bool  bSimReload( void );
-    bool  bSimSave  ( void );
-
-    void  DlgErrMsg( const wxString & rosTitle, const wxString & rosMsg );
+    bool  bSimnLoad  ( void );
+    bool  bSimnReload( void );
+    bool  bSimnSave  ( void );
 
     // Check that helper utilities are present & accounted for
     bool  bIsOkSimEng( PrcBase * poPrcSimEng );
@@ -126,23 +131,28 @@ class FrmMain : public wxFrame
 
     bool  bClear( void );  // Clear the object attributes
 
+    void  DlgErrMsg( const wxString & rosTitle=wxT(""),
+                     const wxString & rosMsg=wxT("") );
+
     // Event handlers
-    void  OnOpen     ( wxCommandEvent & roEvtCmd   );
-    void  OnImport   ( wxCommandEvent & roEvtCmd   );
-    void  OnReload   ( wxCommandEvent & roEvtCmd   );
-    void  OnClose    ( wxCommandEvent & roEvtCmd   );
-    void  OnAppExit  ( wxCommandEvent & roEvtCmd   );
-    void  OnSimCreate( wxCommandEvent & roEvtCmd   );
-    void  OnSimRun   ( wxCommandEvent & roEvtCmd   );
-    void  OnSimStop  ( wxCommandEvent & roEvtCmd   );
-    void  OnEditSchem( wxCommandEvent & roEvtCmd   );
-    void  OnViewData ( wxCommandEvent & roEvtCmd   );
-    void  OnSelSimEng( wxCommandEvent & roEvtCmd   );
-    void  OnPrefs    ( wxCommandEvent & roEvtCmd   );
-    void  OnManual   ( wxCommandEvent & roEvtCmd   );
-    void  OnAbout    ( wxCommandEvent & roEvtCmd   );
-    void  OnTbrEnter ( wxCommandEvent & roEvtCmd   );
-    void  OnSysExit  ( wxCloseEvent   & roEvtClose );
+    void  OnOpen      ( wxCommandEvent & roEvtCmd   );
+    void  OnImport    ( wxCommandEvent & roEvtCmd   );
+    void  OnReload    ( wxCommandEvent & roEvtCmd   );
+    void  OnClose     ( wxCommandEvent & roEvtCmd   );
+    void  OnAppExit   ( wxCommandEvent & roEvtCmd   );
+    void  OnSimCreate ( wxCommandEvent & roEvtCmd   );
+    void  OnSimRun    ( wxCommandEvent & roEvtCmd   );
+    void  OnSimStop   ( wxCommandEvent & roEvtCmd   );
+    void  OnSchematic ( wxCommandEvent & roEvtCmd   );
+    void  OnViewData  ( wxCommandEvent & roEvtCmd   );
+    void  OnSelSimEng ( wxCommandEvent & roEvtCmd   );
+    void  OnPrefs     ( wxCommandEvent & roEvtCmd   );
+    void  OnManUser   ( wxCommandEvent & roEvtCmd   );
+    void  OnManNgSpice( wxCommandEvent & roEvtCmd   ) {}
+    void  OnManGnuCap ( wxCommandEvent & roEvtCmd   ) {}
+    void  OnAbout     ( wxCommandEvent & roEvtCmd   );
+    void  OnToolEnter ( wxCommandEvent & roEvtCmd   );
+    void  OnSysExit   ( wxCloseEvent   & roEvtClose );
 
     friend  class  FileTasks;
 
@@ -158,12 +168,14 @@ class FrmMain : public wxFrame
       ID_MNU_CREATE,
       ID_MNU_RUN,
       ID_MNU_STOP,
-      ID_MNU_EDIT,
-      ID_MNU_PLOT,
+      ID_MNU_SCHEM,
+      ID_MNU_VIEWER,
       ID_MNU_GNUCAP,
       ID_MNU_NGSPICE,
       ID_MNU_PREFS,
-      ID_MNU_MANUAL,
+      ID_MNU_MAN_USR,
+      ID_MNU_MAN_NGS,
+      ID_MNU_MAN_GCP,
       ID_MNU_ABOUT,
 
       ID_TOOLBAR,
@@ -174,20 +186,20 @@ class FrmMain : public wxFrame
       ID_TBR_CREATE,
       ID_TBR_RUN,
       ID_TBR_STOP,
-      ID_TBR_EDIT,
-      ID_TBR_PLOT,
+      ID_TBR_SCHEM,
+      ID_TBR_VIEWER,
       ID_TBR_HELP,
 
       ID_LBX_NODES,
       ID_LBX_CPNTS,
 
-      ID_NBK_ANALYS,
-      ID_NBK_TXTCTLS,
+      ID_NBK_ANALYSIS,
+      ID_NBK_TXTCTRLS,
 
       ID_UNUSED,      // Assigned to controls for which events are not used
 
       ID_FST = ID_MNU_OPEN,
-      ID_LST = ID_NBK_TXTCTLS
+      ID_LST = ID_NBK_TXTCTRLS
     };
 
     // Leave this as the last line as private access is envoked by this macro
