@@ -2,7 +2,7 @@
 //                                HelpTasks.cpp                               *
 //                               ---------------                              *
 //  Started     : 03/06/2005                                                  *
-//  Last Update : 24/02/2010                                                  *
+//  Last Update : 23/09/2011                                                  *
 //  Copyright   : (C) 2005 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -19,13 +19,11 @@
 #include "main/HelpTasks.hpp"
 #include "main/FrmMain.hpp"
 
-// The application icon
-#if defined( __WXGTK__ ) || defined( __WXMOTIF__ ) || defined( __WXMAC__ ) || \
-    defined( __WXMGL__ ) || defined( __WXX11__ )
-    #include "icons/gspiceui-32x32.xpm"
-    #include "icons/html-close.xpm"
-    #include "icons/html-back.xpm"
-#endif
+// The application icons
+#include "icons/gspiceui-32x32.xpm"
+#include "icons/html-forward.xpm"
+#include "icons/html-back.xpm"
+#include "icons/html-close.xpm"
 
 //*****************************************************************************
 // Implement an event table in which the events are routed to their respective
@@ -34,8 +32,11 @@
 
 BEGIN_EVENT_TABLE( HelpTasks, wxFrame )
 
-  EVT_TOOL( ID_TBR_BACK,  HelpTasks::OnBack  )
-  EVT_TOOL( ID_TBR_CLOSE, HelpTasks::OnClose )
+  EVT_TOOL( ID_TBR_FORWARD, HelpTasks::OnForward )
+  EVT_TOOL( ID_TBR_BACK,    HelpTasks::OnBack    )
+  EVT_TOOL( ID_TBR_CLOSE,   HelpTasks::OnClose   )
+
+  EVT_CLOSE(                HelpTasks::OnClose   )
 
 END_EVENT_TABLE( )
 
@@ -47,7 +48,7 @@ END_EVENT_TABLE( )
 
 HelpTasks::HelpTasks( FrmMain * poFrmMain ) :
                   wxFrame( poFrmMain, -1, wxT(""), wxDefaultPosition,
-                           wxDefaultSize, wxDEFAULT_FRAME_STYLE&~wxCLOSE_BOX ),
+                           wxDefaultSize, wxDEFAULT_FRAME_STYLE ),
                   m_oHtmlWin( this )
 {
   // Set the pointer to the parent frame
@@ -72,10 +73,6 @@ HelpTasks::~HelpTasks( )
 
 void  HelpTasks::Initialize( void )
 {
-  // The next line just suppresses the following compiler warning :
-  //   ./icons/gspiceui-32x32.xpm:3: warning: gspiceui_xpm defined but not used
-  char  c1; c1 = gspiceui_xpm[ 0 ][ 0 ];
-
   // Set the frame icon
   SetIcon( wxICON( gspiceui ) );
 
@@ -84,7 +81,6 @@ void  HelpTasks::Initialize( void )
 
   // Call all the initialization functions
   InitToolBar( );
-  InitStatBar( );
   InitHtmlWin( );
   InitPosnSize( );
 }
@@ -94,39 +90,30 @@ void  HelpTasks::Initialize( void )
 
 void  HelpTasks::InitToolBar( void )
 {
-  wxBitmap  * poPixMap[ 2 ];
+  wxBitmap  * poPixMap[ 3 ];
   wxToolBar * poToolBar;
 
   // Create the tool bar
   poToolBar = CreateToolBar( wxHORIZONTAL | wxTB_FLAT );
 
   // Create the bitmaps for the tools
-  poPixMap[ 0 ] = new wxBitmap( html_close_xpm );
-  poPixMap[ 1 ] = new wxBitmap( html_back_xpm );
+  poPixMap[ 0 ] = new wxBitmap( html_back_xpm    );
+  poPixMap[ 1 ] = new wxBitmap( html_forward_xpm );
+  poPixMap[ 2 ] = new wxBitmap( html_close_xpm   );
 
   // Add the tools to the toolbar
-  poToolBar->AddTool( ID_TBR_CLOSE, wxT(""), *(poPixMap[ 0 ]),
-                      wxT("Close") );
-  poToolBar->AddTool( ID_TBR_BACK,  wxT(""), *(poPixMap[ 1 ]),
+  poToolBar->AddTool( ID_TBR_BACK   , wxT(""), *(poPixMap[ 0 ]),
                       wxT("Back") );
+  poToolBar->AddTool( ID_TBR_FORWARD, wxT(""), *(poPixMap[ 1 ]),
+                      wxT("Forward") );
+  poToolBar->AddTool( ID_TBR_CLOSE  , wxT(""), *(poPixMap[ 2 ]),
+                      wxT("Close") );
 
   // Realize the toolbar
   poToolBar->Realize( );
 
   // Can delete the bitmaps since they're reference counted
-  for( int i1=0; i1<2; i1++ ) delete poPixMap[ i1 ];
-}
-
-//*****************************************************************************
-// Initialize the status bar.
-
-void  HelpTasks::InitStatBar( void )
-{
-  // Create the status bar
-  CreateStatusBar( 1 );
-
-  // Set status bar text
-  SetStatusText( wxT(" Welcome to the GNU Spice GUI Manual") );
+  for( int i1=0; i1<3; i1++ ) delete poPixMap[ i1 ];
 }
 
 //*****************************************************************************
@@ -213,9 +200,9 @@ void  HelpTasks::SetTitle( void )
 }
 
 //*****************************************************************************
-// Display the gSpiceUI manual.
+// Display the gSpiceUI User Manual.
 
-void  HelpTasks::Manual( void )
+void  HelpTasks::ManUser( void )
 {
   wxFileName  ofn1, ofn2;
   wxString    os1;
@@ -261,9 +248,10 @@ void  HelpTasks::About( void )
   wxString  os1;
   long      lStyle;
 
-  os1 << wxT("\n                               " ) << APP_NAME
-      << wxT("\n                ")                 << APP_VERSION
-      << wxT("\n                    ")             << APP_COPYRIGHT
+  os1 << wxT("\n                                     " ) << APP_NAME
+      << wxT("\n                     Version ")          << APP_VERSION
+                                            << wxT(" (") << APP_DATE << wxT(")")
+      << wxT("\n                    ")                   << APP_COPYRIGHT
       << wxT("\n\n")
 
       << wxT("\nThis application is intended to provide a GUI for various")
@@ -278,15 +266,15 @@ void  HelpTasks::About( void )
       << wxT("\nThis application is written in C++ and is based on the free")
       << wxT("\nsoftware C++ library ") << wxVERSION_STRING << wxT(".\n")
 
-      << wxT("\n") << APP_NAME << wxT(" is free software; you can redistribute it")
-      << wxT("\nand/or modify it under the terms of the GNU Library")
-      << wxT("\nGeneral Public Licence as published by the Free Software")
+      << wxT("\n") << APP_NAME << wxT(" is free software; you can redistribute it and/or")
+      << wxT("\nmodify it under the terms of the GNU Library General")
+      << wxT("\nPublic Licence as published by the Free Software")
       << wxT("\nFoundation; either version 2 of the Licence, or (at your")
       << wxT("\noption) any later version.\n")
 
-      << wxT("\n") << APP_NAME << wxT(" is distributed in the hope that it will be")
-      << wxT("\nuseful, but WITHOUT ANY WARRANTY; without even the")
-      << wxT("\nimplied warranty of MERCHANTABILITY or FITNESS FOR A")
+      << wxT("\n") << APP_NAME << wxT(" is distributed in the hope that it will be useful,")
+      << wxT("\nbut WITHOUT ANY WARRANTY; without even the implied")
+      << wxT("\nwarranty of MERCHANTABILITY or FITNESS FOR A")
       << wxT("\nPARTICULAR PURPOSE.");
 
   lStyle = wxOK | wxICON_INFORMATION;
@@ -294,6 +282,18 @@ void  HelpTasks::About( void )
   wxMessageBox( os1, wxT("About gSpiceUI"), lStyle, m_poFrmMain );
 }
 
+//*****************************************************************************
+// Go to the next page in the history store.
+//
+// Argument List:
+//   roEvtCmd - The event to be processed
+
+void  HelpTasks::OnForward( wxCommandEvent & roEvtCmd )
+{
+  if( m_oHtmlWin.HistoryCanForward( ) )
+    m_oHtmlWin.HistoryForward( );
+}
+
 //*****************************************************************************
 // Go to the previous page in the history store.
 //
@@ -336,3 +336,16 @@ void  HelpTasks::OnClose( wxCommandEvent & roEvtCmd )
 }
 
 //*****************************************************************************
+// Close the help viewer frame.
+//
+// Argument List:
+//   roEvtClose - The event to be processed
+
+void  HelpTasks::OnClose( wxCloseEvent & roEvtClose )
+{
+  wxCommandEvent  oEvtCmd;
+
+  OnClose( oEvtCmd );
+}
+
+//*****************************************************************************
