@@ -1,12 +1,12 @@
 //*****************************************************************************
 //                                NbkTxtCtls.hpp                              *
 //                               ----------------                             *
-//  Description : This class extends wxNotebook, it contains all text control *
-//                objects which appear at the bottom of the GUI.              *
-//  Started     : 14/06/2005                                                  *
-//  Last Update : 28/10/2008                                                  *
-//  Copyright   : (C) 2005 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : This class extends wxNotebook, it contains all text control  *
+//               objects which appear at the bottom of the GUI.               *
+// Started     : 14/06/2005                                                   *
+// Last Update : 28/10/2008                                                   *
+// Copyright   : (C) 2005 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -21,7 +21,7 @@
 #ifndef NBKTXTCTLS_HPP
 #define NBKTXTCTLS_HPP
 
-// wxWindows Includes
+// wxWidgets Includes
 
 #include <wx/wx.h>
 #include <wx/notebook.h>
@@ -52,8 +52,8 @@ class NbkTxtCtls : public wxNotebook
       ePAGE_NGSPICE,
 
       ePAGE_ALL,
-      ePAGE_NONE,
       ePAGE_CURRENT,
+      ePAGE_NONE,
 
       ePAGE_FST = ePAGE_CONSOLE,
       ePAGE_LST = ePAGE_NGSPICE
@@ -67,7 +67,6 @@ class NbkTxtCtls : public wxNotebook
 
     bool  bClear     ( ePageType ePage=ePAGE_ALL );
     bool  bInitialize( ePageType ePage=ePAGE_ALL );
-    bool  bIsEmpty   ( ePageType ePage=ePAGE_ALL );
 
     bool  bSetPage( ePageType ePage );
     bool  bSetPosn( long liPosn );
