@@ -2,7 +2,7 @@
 //                                Component.cpp                               *
 //                               ---------------                              *
 // Started     : 14/05/2004                                                   *
-// Last Update : 15/04/2010                                                   *
+// Last Update : 19/08/2011                                                   *
 // Copyright   : (C) 2004 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -107,7 +107,11 @@ bool  Component::bSetErrMsg( const wxString & rosErrMsg )
 
 int  Component::iCompare( Component ** ppo1, Component ** ppo2 )
 {
-  return( iStrCmp( (const wxString &) **ppo1, (const wxString &) **ppo2 ) );
+  const wxString & ros1 = (const wxString &) **ppo1;
+  const wxString & ros2 = (const wxString &) **ppo2;
+
+  return( ros1.CompareTo( ros2 ) );
+//  return( iStrCmp( ros1, ros2 ) );
 }
 
 //*****************************************************************************
@@ -666,12 +670,6 @@ void  Component::Print( const wxString & rosPrefix )
 
 #ifdef TEST_COMPONENT
 
-// System include files
-
-
-// Application includes
-
-
 // Function prototypes
 
 void  Usage( char * psAppName );
@@ -698,8 +696,8 @@ int  main( int argc, char * argv[ ] )
   }
 
   // Display the utility banner
-  cout << "\n  Component Structure Test Utility"
-       << "\n     Version 1.07 (08/05/2009)\n";
+  cout << "\n  Component Class Test Utility"
+       << "\n   Version 1.07 (19/08/2011)\n";
 
   // Create a GNU-CAP OP command object
   Component  tCpnt;
