@@ -2,7 +2,7 @@
 //                             CpntNgsIndSrc.cpp                              *
 //                            -------------------                             *
 // Started     : 12/06/2008                                                   *
-// Last Update : 02/09/2009                                                   *
+// Last Update : 27/05/2011                                                   *
 // Copyright   : (C) 2008 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -267,6 +267,26 @@ bool  CpntNgsIndSrc::bClear( void )
   return( TRUE );
 }
 
+//*****************************************************************************
+// Copy and digest the contents of a Component object.
+//
+// Argument List :
+//   roCpnt - A reference to a Component object
+//
+// Return Values :
+//   A reference to this object
+
+CpntNgsIndSrc & CpntNgsIndSrc::operator = ( const Component & roCpnt )
+{
+  // Copy the component contents
+  (Component &) *this = roCpnt;
+
+  // Parse the value part of the component definition
+  bParseValue( );
+
+  return( *this );
+}
+
 //*****************************************************************************
 // Copy the contents of an CmdGnuCapGEN object.
 //
