@@ -2,7 +2,7 @@
 //                                NetList.cpp                                 *
 //                               -------------                                *
 // Started     : 01/09/2003                                                   *
-// Last Update : 15/04/2010                                                   *
+// Last Update : 04/07/2011                                                   *
 // Copyright   : (C) 2003 by MSWaters                                         *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -23,7 +23,7 @@
 
 wxFileName      NetList::m_ofnLoadFile;
 wxFileName      NetList::m_ofnSaveFile;
-ArrayFileName   NetList::m_ofnaSchemFiles;
+ArrayFileName   NetList::m_oaSchemFiles;
 
 wxArrayString   NetList::m_osaNetLst;
 wxArrayString   NetList::m_osaTitle;
@@ -34,14 +34,13 @@ wxArrayString   NetList::m_osaSubCcts;
 
 wxArrayString   NetList::m_osaNodeLbls;
 
-bool            NetList::m_bIsValid = FALSE;
+bool            NetList::m_bIsValid=FALSE;
 
 //*****************************************************************************
 // Constructor.
 
 NetList::NetList( void )
 {
-  m_bIsValid = FALSE;
 }
 
 //*****************************************************************************
@@ -51,43 +50,19 @@ NetList::~NetList( )
 {
 }
 
-//*****************************************************************************
-// Extract the data that has been loaded into the string array this class is
-// derived from.
-//
-// Return Values :
-//   TRUE  - Success
-//   FALSE - Failure
-
-bool  NetList::bExtract( void )
-{
-  if( ! m_osaNetLst.IsEmpty( ) )
-  {
-    m_bIsValid = TRUE;
-
-    if( ! bExtractTitle     ( ) ) m_bIsValid = FALSE;
-    if( ! bExtractIncludes  ( ) ) m_bIsValid = FALSE;
-    if( ! bExtractCpnts     ( ) ) m_bIsValid = FALSE;
-    if( ! bExtractModels    ( ) ) m_bIsValid = FALSE;
-    if( ! bExtractSubCcts   ( ) ) m_bIsValid = FALSE;
-    if( ! bExtractNodeLbls  ( ) ) m_bIsValid = FALSE;
-    if( ! bExtractSchemFiles( ) ) ;
-  }
-  else return( FALSE );
-
-  return( m_bIsValid );
-}
-
 //*****************************************************************************
 // Extract the title for the netlist.
-// Traditionally the first line in the netlist is the title.
-// An '*' at the start of a line seems to be used as a comment designator.
+//
+// Noyes : - Traditionally the first line in the netlist is the title.
+//         - An '*' at the start of a line seems to be used as a comment
+//           designator.
+//         - If the file was created by gnetlist or gSpiceUI throw it away.
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NetList::bExtractTitle( void )
+bool  NetList::bLoadTitle( void )
 {
   // Check that the circuit isn't empty
   if( m_osaNetLst.IsEmpty( ) )          return( FALSE );
@@ -113,10 +88,10 @@ bool  NetList::bExtractTitle( void )
   // something like the following :
   //   **************************************************************
   //   *  Electronic circuit simulation file generated by gSpiceUI  *
-  //   *             Version 0.9.93 Alpha (28/12/2008)              *
+  //   *                 Version 0.9.93 (28/12/2008)                *
   //   **************************************************************
   if(       m_osaNetLst.Item(0).find_first_not_of(wxT('*'))!=wxString::npos ) ;
-  else if( !m_osaNetLst.Item(1).Contains( wxT("gSpiceUI") )                 ) ;
+  else if( !m_osaNetLst.Item(1).Contains( APP_NAME )                        ) ;
   else if( !m_osaNetLst.Item(2).Contains( wxT("Version") )                  ) ;
   else if(  m_osaNetLst.Item(3).find_first_not_of(wxT('*'))!=wxString::npos ) ;
   else                                  return( TRUE );
@@ -139,7 +114,7 @@ bool  NetList::bExtractTitle( void )
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NetList::bExtractIncludes( void )
+bool  NetList::bLoadIncludes( void )
 {
   wxString  os1, os2;
   size_t    sz1;
@@ -177,7 +152,7 @@ bool  NetList::bExtractIncludes( void )
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NetList::bExtractCpnts( void )
+bool  NetList::bLoadCpnts( void )
 {
   wxString   os1, os2;
   size_t     sz1;
@@ -230,7 +205,7 @@ bool  NetList::bExtractCpnts( void )
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NetList::bExtractModels( void )
+bool  NetList::bLoadModels( void )
 {
   wxString  osModel;
   wxString  os1, os2;
@@ -289,7 +264,7 @@ bool  NetList::bExtractModels( void )
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NetList::bExtractSubCcts( void )
+bool  NetList::bLoadSubCcts( void )
 {
   wxString  osSubCct;
   wxString  os1, os2;
@@ -332,13 +307,13 @@ bool  NetList::bExtractSubCcts( void )
 }
 
 //*****************************************************************************
-// Extract all nodes labels from the component line string array.
+// Extract all nodes labels from the component array.
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NetList::bExtractNodeLbls( void )
+bool  NetList::bLoadNodeLbls( void )
 {
   wxString  os1;
   size_t    sz1, sz2;
@@ -355,19 +330,22 @@ bool  NetList::bExtractNodeLbls( void )
     for( sz2=0; sz2<roCpnt.m_osaNodes.GetCount( ); sz2++ )
     {
       os1 = roCpnt.m_osaNodes.Item( sz2 );
-      if( m_osaNodeLbls.Index( os1 ) == wxNOT_FOUND ) m_osaNodeLbls.Add( os1 );
+      if( m_osaNodeLbls.Index( os1 ) == wxNOT_FOUND )
+        m_osaNodeLbls.Add( os1 );
     }
   }
 
+  // Check that some node labels were collected
   if( m_osaNodeLbls.IsEmpty( ) ) return( FALSE );
 
-  // Remove the earth/ground nodes if present
+  // Remove the earth / ground nodes if present
   if( ( i1=m_osaNodeLbls.Index( wxT("0") ) ) != wxNOT_FOUND )
     m_osaNodeLbls.RemoveAt( i1 );
   if( ( i1=m_osaNodeLbls.Index( wxT("GND") ) ) != wxNOT_FOUND )
     m_osaNodeLbls.RemoveAt( i1 );
 
-  m_osaNodeLbls.Sort( &iStrCmp );
+  // Sort the list of node labels
+  m_osaNodeLbls.Sort( &iStrCmpNode );
 
   return( TRUE );
 }
@@ -383,7 +361,7 @@ bool  NetList::bExtractNodeLbls( void )
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  NetList::bExtractSchemFiles( void )
+bool  NetList::bLoadSchemFiles( void )
 {
   wxString  os1, os2;
   size_t    sz1;
@@ -497,26 +475,36 @@ bool  NetList::bLoadFile( const wxString & rosFName )
 
   bClear( );  // Clear the object attributes
 
-  // Open the file
+  // Open the netlist file
   wxTextFile  oFileCct( m_ofnLoadFile.GetFullPath( ) );
   oFileCct.Open( );
   if( ! oFileCct.IsOpened( )       ) { oFileCct.Close( ); return( FALSE ); }
   if( oFileCct.GetLineCount( ) < 3 ) { oFileCct.Close( ); return( FALSE ); }
 
-  // Load the file contents
+  // Load the netlist file contents
   for( os1=oFileCct.GetFirstLine(); !oFileCct.Eof(); os1=oFileCct.GetNextLine() )
     m_osaNetLst.Add( os1 );
 
-  // Need the following line in case the last line in the file is not empty
-  // but has no line termination character
+  // The following line picks up the last line in the file if it has no line
+  // termination character
   if( os1.Length( ) > 0 ) m_osaNetLst.Add( os1 );
 
-  oFileCct.Close( ); // Close the file
+  oFileCct.Close( ); // Close the netlist file
 
-  // Attempt to extract the circuit description from file
-  if( ! bExtract( ) )                                     return( FALSE );
+  // Was anything loaded?
+  if( m_osaNetLst.IsEmpty( ) )                            return( FALSE );
 
-  return( TRUE );
+  // Attempt to extract the circuit description information
+  m_bIsValid = TRUE;
+  if( ! bLoadTitle     ( ) ) m_bIsValid = FALSE;
+  if( ! bLoadIncludes  ( ) ) m_bIsValid = FALSE;
+  if( ! bLoadCpnts     ( ) ) m_bIsValid = FALSE;
+  if( ! bLoadModels    ( ) ) m_bIsValid = FALSE;
+  if( ! bLoadSubCcts   ( ) ) m_bIsValid = FALSE;
+  if( ! bLoadNodeLbls  ( ) ) m_bIsValid = FALSE;
+  if( ! bLoadSchemFiles( ) ) ;
+
+  return( m_bIsValid );
 }
 
 //*****************************************************************************
@@ -550,19 +538,25 @@ bool  NetList::bSaveFile( const wxString & rosFName )
   for( sz1=oFileCct.GetLineCount( ); sz1>0; sz1-- )
     oFileCct.RemoveLine( 0 );
 
-  // Save the circuit description title line/s
+  // Save the circuit description title line/s eg. :
+  // **************************************************************
+  // *  Electronic circuit simulation file generated by gSpiceUI  *
+  // *                Version 0.9.93 (28/12/2008)                 *
+  // **************************************************************
   os1 = wxT("**************************************************************");
   oFileCct.AddLine( os1 );
-  os2 = wxT("*  Electronic circuit simulation file generated by gSpiceUI  *");
+  os2 = wxT("*  Electronic circuit simulation file generated by ");
+  os2 << APP_NAME << wxT("  *");
   oFileCct.AddLine( os2 );
   os2.Empty( );
-  os2 << wxT("*             ") << APP_VERSION << wxT("              *");
+  os2 << wxT("*                Version ") << APP_VERSION << wxT(" (")
+      << APP_DATE << wxT(")                 *");
   oFileCct.AddLine( os2 );
   oFileCct.AddLine( os1 );
   oFileCct.AddLine( wxT("") );
 
   // Save the schematic file name/s if specified
-  if( ! m_ofnaSchemFiles.IsEmpty( ) )
+  if( ! m_oaSchemFiles.IsEmpty( ) )
   {
     os1 = wxT("* Schematic : ") + rosGetSchemFiles( );
     oFileCct.AddLine( os1 );
@@ -684,7 +678,7 @@ bool  NetList::bSetSchemFiles( const wxArrayString & rosaFNames )
   wxFileName  ofn1;
   size_t      sz1;
 
-  m_ofnaSchemFiles.Empty( );
+  m_oaSchemFiles.Empty( );
 
   for( sz1=0; sz1<rosaFNames.GetCount( ); sz1++ )
   {
@@ -694,7 +688,7 @@ bool  NetList::bSetSchemFiles( const wxArrayString & rosaFNames )
     if( ! ofn1.IsOk( ) )       continue;
     if( ! ofn1.FileExists( ) ) continue;
 
-    m_ofnaSchemFiles.Add( ofn1 );
+    m_oaSchemFiles.Add( ofn1 );
   }
 
   return( TRUE );
@@ -715,7 +709,7 @@ bool  NetList::bSetSchemFiles( const wxString & rosFNames )
   wxStringTokenizer  ostk1;
   wxArrayString      osa1;
 
-  m_ofnaSchemFiles.Empty( );
+  m_oaSchemFiles.Empty( );
 
   ostk1.SetString( rosFNames );
   while( ostk1.HasMoreTokens( ) )
@@ -742,11 +736,11 @@ const wxString & NetList::rosGetSchemFiles( void )
 
   osSchemFiles.Empty( );
 
-  for( sz1=0; sz1<m_ofnaSchemFiles.GetCount( ); sz1++ )
+  for( sz1=0; sz1<m_oaSchemFiles.GetCount( ); sz1++ )
   {
     if( ! osSchemFiles.IsEmpty( ) )
       osSchemFiles << wxT(' ');
-    osSchemFiles << m_ofnaSchemFiles.Item( sz1 ).GetFullPath( );
+    osSchemFiles << m_oaSchemFiles.Item( sz1 ).GetFullPath( );
   }
 
   return( osSchemFiles );
