@@ -1,10 +1,10 @@
 //*****************************************************************************
 //                               NbkNgSpice.cpp                               *
 //                              ----------------                              *
-//  Started     : 08/05/2004                                                  *
-//  Last Update : 12/04/2010                                                  *
-//  Copyright   : (C) 2004 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Started     : 08/05/2004                                                   *
+// Last Update : 06/09/2011                                                   *
+// Copyright   : (C) 2004 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -21,11 +21,11 @@
 //*****************************************************************************
 // Implement an event table.
 
-BEGIN_EVENT_TABLE( NbkNgSpice, wxNotebook )
+BEGIN_EVENT_TABLE( NbkNgSpice, NbkSimrBase )
 
-  EVT_NOTEBOOK_PAGE_CHANGED( -1,          NbkSimrBase::OnPageChanged )
+  EVT_NOTEBOOK_PAGE_CHANGED( -1,          NbkNgSpice::OnPageChangd )
 
-  EVT_BUTTON( PnlAnaBase::ID_BTN_OPTIONS, NbkNgSpice::OnBtnOptions   )
+  EVT_BUTTON( PnlAnaBase::ID_BTN_OPTIONS, NbkNgSpice::OnBtnOptions )
 
 END_EVENT_TABLE( )
 
@@ -58,16 +58,6 @@ NbkNgSpice::NbkNgSpice( wxWindow * poParent, wxWindowID oWinID ) :
   SetSelection( 0 );
 }
 
-//*****************************************************************************
-// Default constructor.
-// (Used for two stage creation ie. must call Create( ) method.
-
-NbkNgSpice::NbkNgSpice( void ) : NbkSimrBase( ), m_oDlgCfgOPT( this )
-{
-  // Set the simulator engine type specifier
-  m_eSimEng = eSIMR_NGSPICE;
-}
-
 //*****************************************************************************
 // Destructor.
 
@@ -114,6 +104,8 @@ bool  NbkNgSpice::bLoad( const SimnBase & roSimn )
 
   if( roSimn.eGetSimEng( ) != eSIMR_NGSPICE )            return( FALSE );
 
+  PnlAnaBase::m_oCpntSwpSrcs = roSimn.m_oCpntSwpSrc;
+
   SimnNgSpice & roSimnNgs = (SimnNgSpice &) roSimn;
 
   if( ! bSetPage( roSimnNgs.eGetAnaType( ) ) )           bRtn = FALSE;
@@ -167,7 +159,7 @@ bool  NbkNgSpice::bSave( SimnBase & roSimn )
         SetErrMsg( m_poPnlNgSpiceTR->rosGetErrMsg( ) );
       break;
 
-    default:                                  return( FALSE );
+    default :                                 return( FALSE );
   }
   if( ! bIsOk( ) )                            return( FALSE );
 
@@ -203,7 +195,6 @@ bool  NbkNgSpice::bSetPage( eCmdType eAnalysis )
 
   switch( eAnalysis )
   {
-    case eCMD_NONE :
     case eCMD_OP   :
     case eCMD_DC   : iPage = 0; break;
     case eCMD_AC   : iPage = 1; break;
@@ -271,7 +262,7 @@ const wxString & NbkNgSpice::rosGetPage( void )
 //
 // Return Values :
 //   Success - The enumerated analysis specifier
-//   Failure - Simulation::eANA_NONE
+//   Failure - eCMD_NONE
 
 eCmdType  NbkNgSpice::eGetPage( void )
 {
@@ -293,7 +284,46 @@ eCmdType  NbkNgSpice::eGetPage( void )
 //                             Event Handlers                                 *
 //                                                                            *
 //*****************************************************************************
-// .OPTIONS command setup button control event handler.
+// This event is generated when a notebook page has just changed.
+//
+// Argument List:
+//   roEvtNbk - An object holding information about the event
+
+void  NbkNgSpice::OnPageChangd( wxNotebookEvent & roEvtNbk )
+{
+  PnlAnaBase * poPnlAna;
+  wxString     os1;
+  int          i1;
+
+  // Transfer the ambient temperature from the previous page to OPTIONS dialog
+  i1 = roEvtNbk.GetOldSelection( );
+  if( i1 != -1 )
+  {
+    poPnlAna = (PnlAnaBase *) GetPage( (size_t) i1 );
+    if( poPnlAna->bIsCreated( PnlAnaBase::eCTLGRP_TEMP ) )
+    {
+      os1 = poPnlAna->m_oPnlTemp.rosGetValue( );
+      m_oDlgCfgOPT.bSetValue( DlgNgsCfgOPT::ID_PNL_TEMP, os1 );
+    }
+  }
+
+  // Transfer the ambient temperature from the OPTIONS dialog to current page
+  poPnlAna = (PnlAnaBase *) GetCurrentPage( );
+  if( poPnlAna != NULL )
+  {
+    if( poPnlAna->bIsCreated( PnlAnaBase::eCTLGRP_TEMP ) )
+    {
+      os1 = m_oDlgCfgOPT.rosGetValue( DlgNgsCfgOPT::ID_PNL_TEMP );
+      poPnlAna->m_oPnlTemp.bSetValue( os1 );
+    }
+  }
+
+  // Allow additional event handlers to be called
+  roEvtNbk.Skip( );
+}
+
+//*****************************************************************************
+// Setup .OPTIONS command button event handler.
 //
 // Argument List :
 //   roEvtCmd - An object holding information about the event
@@ -304,8 +334,11 @@ void  NbkNgSpice::OnBtnOptions( wxCommandEvent & roEvtCmd )
   wxString     os1;
   int          i1;
 
+  // Get a pointer to the currently displayed analysis page
+  poPnlAna = (PnlAnaBase *) GetCurrentPage( );
+  if( poPnlAna == NULL ) return;
+
   // Set the temperature in the OPTIONS dialog
-  poPnlAna = (PnlAnaBase *) GetPage( GetSelection( ) );
   if( poPnlAna->bIsCreated( PnlAnaBase::eCTLGRP_TEMP ) )
   {
     os1 = poPnlAna->m_oPnlTemp.rosGetValue( );
@@ -316,7 +349,7 @@ void  NbkNgSpice::OnBtnOptions( wxCommandEvent & roEvtCmd )
   m_oDlgCfgOPT.CenterOnParent( );
   i1 = m_oDlgCfgOPT.ShowModal( );
 
-  // Set the temperature in the analysis panel
+  // Set the temperature in the current analysis panel
   if( poPnlAna->bIsCreated( PnlAnaBase::eCTLGRP_TEMP ) && i1==wxID_OK )
   {
     os1 = m_oDlgCfgOPT.rosGetValue( DlgNgsCfgOPT::ID_PNL_TEMP );
