@@ -1,13 +1,13 @@
 //*****************************************************************************
 //                               NbkNgSpice.hpp                               *
 //                              ----------------                              *
-//  Description : Provides a container class for the analysis configuration   *
-//                panels for the different analyses provided by NG-Spice      *
-//                electronic circuit simulator.                               *
-//  Started     : 08/05/2004                                                  *
-//  Last Update : 29/03/2010                                                  *
-//  Copyright   : (C) 2004 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Description : Provides a container class for the analysis configuration    *
+//               panels for the different analyses provided by NG-Spice       *
+//               electronic circuit simulator.                                *
+// Started     : 08/05/2004                                                   *
+// Last Update : 23/05/2011                                                   *
+// Copyright   : (C) 2004 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -25,7 +25,7 @@
 // System Includes
 
 
-// wxWindows Includes
+// wxWidgets Includes
 
 #include <wx/wx.h>
 
@@ -58,7 +58,6 @@ class NbkNgSpice : public NbkSimrBase
   public :
 
     NbkNgSpice( wxWindow * poParent, wxWindowID oWinID );
-    NbkNgSpice( void );
    ~NbkNgSpice( );
 
     virtual  bool  bClear( void );
@@ -73,7 +72,8 @@ class NbkNgSpice : public NbkSimrBase
     virtual         eCmdType     eGetPage( void );
 
     // Event handlers
-    void  OnBtnOptions( wxCommandEvent & roEvtCmd );
+    void  OnPageChangd( wxNotebookEvent & roEvtNbk );
+    void  OnBtnOptions( wxCommandEvent  & roEvtCmd );
 
     // Leave this as the last line as private access is envoked by macro
     DECLARE_EVENT_TABLE( )
