@@ -2,7 +2,7 @@
 //                              CmdNgSpiceAC.cpp                              *
 //                             ------------------                             *
 // Started     : 11/10/2007                                                   *
-// Last Update : 16/04/2010                                                   *
+// Last Update : 12/08/2011                                                   *
 // Copyright   : (C) 2007 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -23,7 +23,7 @@
 
 CmdNgSpiceAC::CmdNgSpiceAC( void )
 {
-  bClear( );
+  bSetDefaults( );
 }
 
 //*****************************************************************************
@@ -44,6 +44,7 @@ bool  CmdNgSpiceAC::bValidate( void )
 {
   double  df1, df2, df3;
 
+  // Call the base class validation function first
   CmdBase::bValidate( );
 
   // Check the sweep start and stop values
@@ -76,15 +77,15 @@ bool  CmdNgSpiceAC::bValidate( void )
 }
 
 //*****************************************************************************
-// Clear the object attributes.
+// Set the object attributes to they're default values.
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  CmdNgSpiceAC::bClear( void )
+bool  CmdNgSpiceAC::bSetDefaults( void )
 {
-  CmdBase::bClear( );
+  CmdBase::bSetDefaults( );
 
   m_eSimEng  = eSIMR_NGSPICE;
   m_eCmdType = eCMD_AC;
@@ -118,7 +119,7 @@ bool  CmdNgSpiceAC::bParse( void )
 
   // Clear the object attributes
   os1 = *this;
-  bClear( );
+  bSetDefaults( );
   assign( os1 );
 
   // Tokenize the command string
@@ -277,7 +278,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdNgSpiceAC Test Utility"
-       << "\n     Version 1.01 (04/06/2009)\n";
+       << "\n     Version 1.02 (12/08/2011)\n";
 
   // Create a GNU-CAP AC command object
   CmdNgSpiceAC  oCmd_AC;
@@ -286,7 +287,6 @@ int  main( int argc, char * argv[ ] )
   osCmd = wxT(".AC DEC 30 1.00K 300.00K");
 
   // Set things up for a formatter test
-  oCmd_AC.bClear( );
   oCmd_AC.m_osStart = wxT("1.00K");
   oCmd_AC.m_osStop  = wxT("300.00K");
   oCmd_AC.m_osStep  = wxT("30");
@@ -297,7 +297,6 @@ int  main( int argc, char * argv[ ] )
   cout << "\noCmd_AC Contents : " << oCmd_AC.mb_str( ) << '\n';
 
   // Set things up for a parser test
-  oCmd_AC.bClear( );
   oCmd_AC.bSetString( osCmd );
   cout << "\nRun Parser       : " << ( oCmd_AC.bParse( ) ? "OK" : "FAULT" );
   oCmd_AC.bFormat( );
