@@ -4,7 +4,7 @@
 // Description : This class contains values associated with the NG-Spice      *
 //               AC command. It inherits from the class CmdBase.              *
 // Started     : 11/10/2007                                                   *
-// Last Update : 16/04/2010                                                   *
+// Last Update : 24/12/2010                                                   *
 // Copyright   : (C) 2007 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -59,7 +59,7 @@ struct CmdNgSpiceAC : public CmdBase
               CmdNgSpiceAC( void );
     virtual  ~CmdNgSpiceAC( );
 
-    virtual  bool  bClear   ( void );
+    virtual  bool  bSetDefaults( void );
 
     virtual  bool  bParse ( void );
     virtual  bool  bFormat( void );
