@@ -2,7 +2,7 @@
 //                              CmdNgSpiceDC.cpp                              *
 //                             ------------------                             *
 // Started     : 21/08/2007                                                   *
-// Last Update : 16/04/2010                                                   *
+// Last Update : 12/08/2011                                                   *
 // Copyright   : (C) 2007 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -23,7 +23,7 @@
 
 CmdNgSpiceDC::CmdNgSpiceDC( void )
 {
-  bClear( );
+  bSetDefaults( );
 }
 
 //*****************************************************************************
@@ -68,15 +68,15 @@ bool  CmdNgSpiceDC::bValidate( void )
 }
 
 //*****************************************************************************
-// Clear the object attributes.
+// Set the object attributes to they're default values.
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  CmdNgSpiceDC::bClear( void )
+bool  CmdNgSpiceDC::bSetDefaults( void )
 {
-  CmdBase::bClear( );
+  CmdBase::bSetDefaults( );
 
   m_eSimEng  = eSIMR_NGSPICE;
   m_eCmdType = eCMD_DC;
@@ -108,7 +108,7 @@ bool  CmdNgSpiceDC::bParse( void )
 
   // Clear the object attributes
   os1 = *this;
-  bClear( );
+  bSetDefaults( );
   assign( os1 );
 
   // Tokenize the command string
@@ -273,7 +273,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdNgSpiceDC Test Utility"
-       << "\n     Version 1.01 (04/06/2009)\n";
+       << "\n     Version 1.02 (12/08/2011)\n";
 
   // Create a NG-SPICE DC command object
   CmdNgSpiceDC  oCmd_DC;
@@ -282,7 +282,6 @@ int  main( int argc, char * argv[ ] )
   osCmd = wxT(".DC Vin 0.00 100.00m 10.00m");
 
   // Set things up for a formatter test
-  oCmd_DC.bClear( );
   oCmd_DC.m_osStart  = wxT("0.00");
   oCmd_DC.m_osStop   = wxT("100.00m");
   oCmd_DC.m_osStep   = wxT("10.00m");
@@ -293,7 +292,6 @@ int  main( int argc, char * argv[ ] )
   cout << "\noCmd_DC Contents : " << oCmd_DC.mb_str( ) << '\n';
 
   // Set things up for a parser test
-  oCmd_DC.bClear( );
   oCmd_DC.bSetString( osCmd );
   cout << "\nRun Parser       : " << ( oCmd_DC.bParse( ) ? "OK" : "FAULT" );
   oCmd_DC.bFormat( );
