@@ -4,7 +4,7 @@
 // Description : This class contains values associated with the NG-Spice      *
 //               DC command. It inherits from the class CmdBase.              *
 // Started     : 23/08/2006                                                   *
-// Last Update : 16/04/2010                                                   *
+// Last Update : 24/12/2010                                                   *
 // Copyright   : (C) 2006 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -63,7 +63,7 @@ struct CmdNgSpiceDC : public CmdBase
               CmdNgSpiceDC( void );
     virtual  ~CmdNgSpiceDC( );
 
-    virtual  bool  bClear   ( void );
+    virtual  bool  bSetDefaults( void );
 
     virtual  bool  bParse ( void );
     virtual  bool  bFormat( void );
