@@ -2,7 +2,7 @@
 //                              CmdNgSpiceOPT.cpp                             *
 //                             -------------------                            *
 // Started     : 23/08/2006                                                   *
-// Last Update : 07/10/2009                                                   *
+// Last Update : 12/08/2011                                                   *
 // Copyright   : (C) 2006 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -23,7 +23,7 @@
 
 CmdNgSpiceOPT::CmdNgSpiceOPT( void )
 {
-  bClear( );
+  bSetDefaults( );
 }
 
 //*****************************************************************************
@@ -105,15 +105,15 @@ bool  CmdNgSpiceOPT::bValidate( void )
 }
 
 //*****************************************************************************
-// Clear the object attributes.
+// Set the object attributes to they're default values.
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  CmdNgSpiceOPT::bClear( void )
+bool  CmdNgSpiceOPT::bSetDefaults( void )
 {
-  CmdBase::bClear( );
+  CmdBase::bSetDefaults( );
 
   m_eSimEng  = eSIMR_NGSPICE;
   m_eCmdType = eCMD_OPT;
@@ -168,7 +168,7 @@ bool  CmdNgSpiceOPT::bParse( void )
 
   // Clear the object attributes
   os1 = (wxString &) *this;
-  bClear( );
+  bSetDefaults( );
   assign( os1 );
 
   // Tokenize the command string
@@ -204,7 +204,6 @@ bool  CmdNgSpiceOPT::bParse( void )
     else if( os1 == wxT("ITL2")    ) m_osITL2   = os2;
     else if( os1 == wxT("ITL4")    ) m_osITL4   = os2;
     else if( os1 == wxT("METHOD")  ) m_osMETHOD = os2;
-    else if( os1 == wxT("NOPAGE")  ) ;
     else if( os1 == wxT("PIVREL")  ) m_osPIVREL = os2;
     else if( os1 == wxT("PIVTOL")  ) m_osPIVTOL = os2;
     else if( os1 == wxT("RELTOL")  ) m_osRELTOL = os2;
@@ -212,7 +211,6 @@ bool  CmdNgSpiceOPT::bParse( void )
     else if( os1 == wxT("TNOM")    ) m_osTNOM   = os2;
     else if( os1 == wxT("TRTOL")   ) m_osTRTOL  = os2;
     else if( os1 == wxT("VNTOL")   ) m_osVNTOL  = os2;
-    else                         return( bValidate( ) );
   }
 
   return( bValidate( ) );
@@ -417,7 +415,7 @@ void  CmdNgSpiceOPT::Print( const wxString & rosPrefix )
 //                                                                            *
 //*****************************************************************************
 
-#ifdef TEST_UTIL
+#ifdef TEST_CMDNGSOPT
 
 // System include files
 
@@ -449,7 +447,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdNgSpiceOPT Test Utility"
-       << "\n     Version 1.02 (04/06/2009)\n";
+       << "\n     Version 1.03 (12/08/2011)\n";
 
   // Create a NG-SPICE OPTIONS command object
   CmdNgSpiceOPT  oCmd_OPT;
@@ -462,7 +460,6 @@ int  main( int argc, char * argv[ ] )
         << wxT("TNOM=30.00 TRTOL=8.00 VNTOL=2.00u");
 
   // Set things up for a formatter test
-  oCmd_OPT.bClear( );
   oCmd_OPT.m_osABSTOL = wxT("1.10p");
   oCmd_OPT.m_bBADMOS3 = TRUE;
   oCmd_OPT.m_osCHGTOL = wxT("11.00f");
@@ -488,7 +485,6 @@ int  main( int argc, char * argv[ ] )
   cout << "\noCmd_OPT Contents : " << oCmd_OPT.mb_str( ) << '\n';
 
   // Set things up for a parser test
-  oCmd_OPT.bClear( );
   oCmd_OPT.bSetString( osCmd );
   cout << "\nRun Parser        : " << ( oCmd_OPT.bParse( ) ? "OK" : "FAULT" );
   oCmd_OPT.bFormat( );
@@ -510,6 +506,6 @@ void  Usage( char * psAppName )
        << "\n  -h : Print usage (this message)\n";
 }
 
-#endif // TEST_UTIL
+#endif // TEST_CMDNGSOPT
 
 //*****************************************************************************
