@@ -4,7 +4,7 @@
 // Description : This class contains values associated with the NG-Spice      *
 //               OPTIONS command. It inherits from the class CmdBase.         *
 // Started     : 23/08/2006                                                   *
-// Last Update : 16/04/2010                                                   *
+// Last Update : 21/04/2011                                                   *
 // Copyright   : (C) 2006 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -63,7 +63,7 @@ struct CmdGnuCapOPT;
 
 #define  NGS_WIDTH    104  // Allows for operator (eg. frequency) & 10 cols of data
 #define  NGS_NUMDGT   6
-#define  NGS_UNITS    wxT("Degress")
+#define  NGS_UNITS    wxT("Degrees")
 
 //*****************************************************************************
 
@@ -106,7 +106,7 @@ struct CmdNgSpiceOPT : public CmdBase
               CmdNgSpiceOPT( void );
     virtual  ~CmdNgSpiceOPT( );
 
-    virtual  bool  bClear( void );
+    virtual  bool  bSetDefaults( void );
 
     virtual  bool  bParse ( void );
     virtual  bool  bFormat( void );
