@@ -4,7 +4,7 @@
 // Description : This class contains values associated with the NG-Spice      *
 //               PRINT command. It inherits from the class CmdBase.           *
 // Started     : 16/10/2007                                                   *
-// Last Update : 16/09/2009                                                   *
+// Last Update : 24/12/2010                                                   *
 // Copyright   : (C) 2007 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -18,8 +18,8 @@
 //                                                                            *
 //*****************************************************************************
 
-#ifndef CMDNGSPICEPR_HPP
-#define CMDNGSPICEPR_HPP
+#ifndef CMDNGSPR_HPP
+#define CMDNGSPR_HPP
 
 // System Includes
 
@@ -62,7 +62,7 @@ struct CmdNgSpicePR : public CmdBase
              CmdNgSpicePR( void );
     virtual ~CmdNgSpicePR( );
 
-    virtual  bool  bClear( void );
+    virtual  bool  bSetDefaults( void );
 
              bool  bSetAnaType( eCmdType eAnaType );
 
@@ -79,4 +79,4 @@ struct CmdNgSpicePR : public CmdBase
 
 //*****************************************************************************
 
-#endif // CMDNGSPICEPR_HPP
+#endif // CMDNGSPR_HPP
