@@ -2,7 +2,7 @@
 //                              CmdNgSpiceTR.cpp                              *
 //                             ------------------                             *
 // Started     : 15/10/2007                                                   *
-// Last Update : 16/04/2010                                                   *
+// Last Update : 12/08/2011                                                   *
 // Copyright   : (C) 2007 by M.S.Waters                                       *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -23,7 +23,7 @@
 
 CmdNgSpiceTR::CmdNgSpiceTR( void )
 {
-  bClear( );
+  bSetDefaults( );
 }
 
 //*****************************************************************************
@@ -71,15 +71,15 @@ bool  CmdNgSpiceTR::bValidate( void )
 }
 
 //*****************************************************************************
-// Clear the object attributes.
+// Set the object attributes to they're default values.
 //
 // Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  CmdNgSpiceTR::bClear( void )
+bool  CmdNgSpiceTR::bSetDefaults( void )
 {
-  CmdBase::bClear( );
+  CmdBase::bSetDefaults( );
 
   m_eSimEng  = eSIMR_NGSPICE;
   m_eCmdType = eCMD_TR;
@@ -114,7 +114,7 @@ bool  CmdNgSpiceTR::bParse( void )
 
   // Clear the object attributes
   os1 = *this;
-  bClear( );
+  bSetDefaults( );
   assign( os1 );
 
   // Tokenize the command string
@@ -276,7 +276,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  Class CmdNgSpiceTR Test Utility"
-       << "\n     Version 1.01 (04/06/2009)\n";
+       << "\n     Version 1.02 (12/08/2011)\n";
 
   // Create a NG-SPICE TRANSIENT command object
   CmdNgSpiceTR  oCmd_TR;
@@ -285,7 +285,6 @@ int  main( int argc, char * argv[ ] )
   osCmd = wxT(".TRAN 10.00m 100.00m 0.00 UIC");
 
   // Set things up for a formatter test
-  oCmd_TR.bClear( );
   oCmd_TR.m_osStart = wxT("0.00");
   oCmd_TR.m_osStop  = wxT("100.00m");
   oCmd_TR.m_osStep  = wxT("10.00m");
@@ -296,7 +295,6 @@ int  main( int argc, char * argv[ ] )
   cout << "\noCmd_TR Contents : " << oCmd_TR.mb_str( ) << '\n';
 
   // Set things up for a parser test
-  oCmd_TR.bClear( );
   oCmd_TR.bSetString( osCmd );
   cout << "\nRun Parser       : " << ( oCmd_TR.bParse( ) ? "OK" : "FAULT" );
   oCmd_TR.bFormat( );
