@@ -2,7 +2,7 @@
 //                              DlgNgsCfgOPT.cpp                              *
 //                             ------------------                             *
 //  Started     : 03/03/2006                                                  *
-//  Last Update : 23/02/2010                                                  *
+//  Last Update : 04/03/2011                                                  *
 //  Copyright   : (C) 2006 by M.S.Waters                                      *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -119,19 +119,17 @@ void  DlgNgsCfgOPT::Create( void )
   m_oPnlTNOM  .bSetUnitsType( eUNITS_TEMP );
   m_oPnlVNTOL .bSetUnitsType( eUNITS_VOLT );
 
-  m_oPnlVNTOL .bSetDefUnits( wxT("uV") );
-
-  m_oPnlABSTOL.bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlCHGTOL.bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlDEFAD .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlDEFAS .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlDEFL  .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlDEFW  .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlGMIN  .bSetVarType( SpinCtrl::eVAR_SCI );
-  m_oPnlITL1  .bSetVarType( SpinCtrl::eVAR_INT );
-  m_oPnlITL2  .bSetVarType( SpinCtrl::eVAR_INT );
-  m_oPnlITL4  .bSetVarType( SpinCtrl::eVAR_INT );
-  m_oPnlPIVTOL.bSetVarType( SpinCtrl::eVAR_SCI );
+  m_oPnlABSTOL.bSetVarType( eVAR_SCI );
+  m_oPnlCHGTOL.bSetVarType( eVAR_SCI );
+  m_oPnlDEFAD .bSetVarType( eVAR_SCI );
+  m_oPnlDEFAS .bSetVarType( eVAR_SCI );
+  m_oPnlDEFL  .bSetVarType( eVAR_SCI );
+  m_oPnlDEFW  .bSetVarType( eVAR_SCI );
+  m_oPnlGMIN  .bSetVarType( eVAR_SCI );
+  m_oPnlITL1  .bSetVarType( eVAR_INT );
+  m_oPnlITL2  .bSetVarType( eVAR_INT );
+  m_oPnlITL4  .bSetVarType( eVAR_INT );
+  m_oPnlPIVTOL.bSetVarType( eVAR_SCI );
 
   m_oPnlABSTOL.bShowUnits( FALSE );
   m_oPnlCHGTOL.bShowUnits( FALSE );
@@ -195,11 +193,6 @@ void  DlgNgsCfgOPT::Create( void )
   m_oBtnOk      .Create( poPnlBtns, ID_BTN_OK,       wxT("OK")       );
   m_oBtnDefaults.Create( poPnlBtns, ID_BTN_DEFAULTS, wxT("Defaults") );
   m_oBtnCancel  .Create( poPnlBtns, ID_BTN_CANCEL,   wxT("Cancel")   );
-
-// (15/10/2008) I suspect that the following just fixes a bug in wxWidgets, the
-// back-ground of the parent window isn't inherited by it's children
-m_oChoMETHOD .GetParent()->SetBackgroundColour( this->GetBackgroundColour() ); // ???
-m_oCbxBADMOS3.GetParent()->SetBackgroundColour( this->GetBackgroundColour() ); // ???
 }
 
 //*****************************************************************************
@@ -507,7 +500,7 @@ bool  DlgNgsCfgOPT::bGetValues( CmdNgSpiceOPT & roCmdOPT )
 
 bool  DlgNgsCfgOPT::bClear( void )
 {
-  m_oCmdOPT.bClear( );
+  m_oCmdOPT.bSetDefaults( );
 
   SetValues( m_oCmdOPT );
 
@@ -589,7 +582,7 @@ void  DlgNgsCfgOPT::OnBtnDefaults( wxCommandEvent & roEvtCmd )
 {
   CmdNgSpiceOPT  oCmdOPT;
 
-  oCmdOPT.bClear( );
+  oCmdOPT.bSetDefaults( );
   SetValues( oCmdOPT );
 }
 
