@@ -2,7 +2,7 @@
 //                             PnlNgSpiceTR.cpp                               *
 //                            ------------------                              *
 // Started     : 05/08/2004                                                   *
-// Last Update : 13/04/2010                                                   *
+// Last Update : 21/03/2011                                                   *
 // Copyright   : (C) 2004 by MSWaters                                         *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -54,17 +54,14 @@ PnlNgSpiceTR::~PnlNgSpiceTR( )
 void  PnlNgSpiceTR::Create( void )
 {
   wxStaticBox * poSbxSigSrc;
+#ifndef LAYOUT_MNGR
   int           ix, iy;
 
-  // Disable the checkboxes for the parameters NG-Spice cannot calculate
-  m_oCbxCurrent.Disable( );
-  m_oCbxPower  .Disable( );
-  m_oCbxResist .Disable( );
-
   // Set the frequency sweep parameter labels
   m_oSbxSwpPars.GetSize( &ix, &iy );
   m_oSbxSwpPars.SetSize(  ix, 167 );
-  m_oSbxSwpPars.SetLabel( wxT(" Transient Sweep ") );
+  m_oSbxSwpPars.SetLabel( wxT(" Time Sweep ") );
+#endif // LAYOUT_MNGR
   m_oPnlStart  .bSetName( wxT("Start Time") );
   m_oPnlStop   .bSetName( wxT("Stop Time") );
   m_oPnlStep   .bSetName( wxT("Step Increment") );
@@ -85,6 +82,11 @@ void  PnlNgSpiceTR::Create( void )
 
   PnlAnaBase::CreateInitC( ); // Create and add the initial conditions controls
   PnlAnaBase::CreateTemp( );  // Create the analysis temperature controls
+
+  // Disable the checkboxes for the parameters NG-Spice cannot calculate
+  m_oCbxCurrent.Disable( );
+  m_oCbxPower  .Disable( );
+  m_oCbxResist .Disable( );
 }
 
 //*****************************************************************************
@@ -139,6 +141,9 @@ bool  PnlNgSpiceTR::bLoad( SimnNgSpice & roSimn )
   // Load the components into the signal source choice box
   PnlAnaBase::LoadSrcNames( roSimn.m_oaCpnts, wxT("VI") );
 
+  // Go no further if the TR command isn't valid
+  if( ! roSimn.m_oCmdTR.bIsValid( ) )                        return( FALSE );
+
   // Set the source component name
   if( ! PnlAnaBase::bSetSrcCpnt( roSimn.m_oCpntSwpSrc ) )    bRtn = FALSE;
 
@@ -248,14 +253,14 @@ void  PnlNgSpiceTR::OnChoSrcName( wxCommandEvent & roEvtCmd )
 {
   wxString  os1;
 
+  // Permit the base class to process this event as well
+  roEvtCmd.Skip( );
+
   if( m_oChoSrcName.GetStringSelection( ) != wxT("None") )
   {
     os1 = m_oChoSrcName.GetStringSelection( );
     m_oDlgCfgSrc.bSetName( os1 );
   }
-
-  // Permit the base class to process this event as well
-  roEvtCmd.Skip( );
 }
 
 //*****************************************************************************
