@@ -2,7 +2,7 @@
 //                                GNetList.cpp                                *
 //                               --------------                               *
 // Started     : 28/01/2004                                                   *
-// Last Update : 26/03/2010                                                   *
+// Last Update : 30/05/2011                                                   *
 // Copyright   : (C) 2004 by MSWaters                                         *
 // Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
@@ -146,7 +146,7 @@ bool  PrcGNetList::bSetSchemFiles( const wxArrayString & rosaFNames )
   if( m_ofnaSchemFiles.IsEmpty( ) )                            return( FALSE );
 
   // Set the log file path
-  ofn1 = rofnGetLogFile( );
+  ofn1 = roGetLogFile( );
   ofn1.SetPath( m_ofnaSchemFiles.Item( 0 ).GetPath( ) );
   bSetLogFile( ofn1.GetFullPath( ) );
 
@@ -177,7 +177,7 @@ bool  PrcGNetList::bSetNetLstFile( const wxString & rosFName )
   {
     if( rosFName == GNETLST_USE_SCHEM )
     { // Generate the netlist file name from the schematic file name
-      ofn1 = rofnGetSchemFile( );
+      ofn1 = roGetSchemFile( );
       ofn1.SetExt( wxT("ckt") );
     }
     else ofn1 = rosFName;
@@ -194,7 +194,7 @@ bool  PrcGNetList::bSetNetLstFile( const wxString & rosFName )
   m_ofnNetLstFile = ofn1;
 
   // Set the log file path
-  ofn1 = rofnGetLogFile( );
+  ofn1 = roGetLogFile( );
   ofn1.SetPath( m_ofnNetLstFile.GetPath( ) );
   bSetLogFile( ofn1.GetFullPath( ) );
 
@@ -233,7 +233,7 @@ bool  PrcGNetList::bSetGuileProc( const wxString & rosGProc )
 //   Success - The procedure name
 //   Failure - An empty file name
 
-const wxFileName & PrcGNetList::rofnGetSchemFile( size_t szIndex )
+const wxFileName & PrcGNetList::roGetSchemFile( size_t szIndex )
 {
   static  wxFileName  oFnEmpty;
 
@@ -302,7 +302,7 @@ bool  PrcGNetList::bExec( void )
   bSetArgLst( osArgLst.c_str( ) );
 
   // Set the working directory
-  os1 = rofnGetSchemFile( ).GetPath( );
+  os1 = roGetSchemFile( ).GetPath( );
   wxSetWorkingDirectory( os1 );
 
   // Execute the process
