@@ -97,7 +97,7 @@ bool  PrcGSchem::bSetSchems( const wxArrayString & roasFileNames )
   if( m_oafnSchems.IsEmpty( ) )                               return( FALSE );
 
   // Set the log file path
-  ofn1 = rofnGetLogFile( );
+  ofn1 = roGetLogFile( );
   ofn1.SetPath( m_oafnSchems.Item( 0 ).GetPath( ) );
   bSetLogFile( ofn1.GetFullPath( ) );
 
