@@ -6,7 +6,7 @@
 //                derived from a gSchem schematic file the user can envoke    *
 //                gschem and edit the schematic.                              *
 //  Started     : 18/02/2008                                                  *
-//  Last Update : 19/02/2008                                                  *
+//  Last Update : 30/05/2011                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -29,7 +29,7 @@ using  namespace  std;
 
 #include <iostream>
 
-// wxWindows Includes
+// wxWidgets Includes
 
 #include <wx/wx.h>
 #include <wx/tokenzr.h>
@@ -57,8 +57,8 @@ class PrcGSchem : public PrcBase
     bool  bSetSchems( const wxString & rosFileNames );
     bool  bSetSchems( const wxArrayString & roasFileNames );
 
-    const wxString      &   rosGetSchems( void );
-    const ArrayFileName & roafnGetSchems( void ) { return( m_oafnSchems ); }
+    const wxString      & rosGetSchems( void );
+    const ArrayFileName & roaGetSchems( void ) { return( m_oafnSchems ); }
 
     virtual  bool  bExec( void );
 };
