@@ -2,7 +2,7 @@
 //                                  PrcGWave.cpp                              *
 //                                 --------------                             *
 //  Started     : 29/03/2004                                                  *
-//  Last Update : 12/03/2010                                                  *
+//  Last Update : 18/04/2011                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -64,16 +64,20 @@ bool  PrcGWave::bSetResults( const wxString & rosFileName )
 }
 
 //*****************************************************************************
-// Delete the simulator banner message at the top of the results file.
-// (This is a bodge added temporarily so that GWave can be used as the results
-// plotter. GWave doesn't like the GnuCap banner at the start to the file so
-// remove it. 29/03/2004 ???)
+// Filter the results file so that the data viewer utility is happy with it.
+//
+// There are several things that a data viewer can object to :
+//  - gwave doesn't like the GNU-Cap banner at the start to the results file,
+//    so it's removed here.
+//  - gwave doesn't like error messages interspersed with the lines of data,
+//    so they are removed here.
+//  - For good measure lines and fields are also formatted.
 //
 // Return Values:
 //   TRUE  - Success
 //   FALSE - Failure
 
-bool  PrcGWave::bFormatFile( void )
+bool  PrcGWave::bFilterFile( void )
 {
   wxString  os1;
   size_t    szt1, szt2;
@@ -122,9 +126,9 @@ bool  PrcGWave::bFormatFile( void )
   }
 
   // Format each data line in the file
-  for( szt1=1; szt1<oFileCct.GetLineCount( ); szt1++ )
-    if( ! bFormatLine( oFileCct.GetLine( szt1 ) ) )
-      bRtn = FALSE;
+//  for( szt1=1; szt1<oFileCct.GetLineCount( ); szt1++ )
+//    if( ! bFormatLine( oFileCct.GetLine( szt1 ) ) )
+//      bRtn = FALSE;
 
   oFileCct.Write( ); // Save the changes to disk
   oFileCct.Close( ); // Close the file
@@ -141,7 +145,7 @@ bool  PrcGWave::bFormatFile( void )
 // Return Values:
 //   TRUE  - Success
 //   FALSE - Failure
-
+/*
 bool  PrcGWave::bFormatLine( wxString & rosLine )
 {
   wxStringTokenizer  ostk1;
@@ -167,7 +171,7 @@ bool  PrcGWave::bFormatLine( wxString & rosLine )
 
   return( TRUE );
 }
-
+*/
 //*****************************************************************************
 // Reformat the fields from the results file.
 //
@@ -177,7 +181,7 @@ bool  PrcGWave::bFormatLine( wxString & rosLine )
 // Return Values:
 //   TRUE  - Success
 //   FALSE - Failure
-
+/*
 bool  PrcGWave::bFormatField( wxString & rosField )
 {
   wxString  os1;
@@ -214,7 +218,7 @@ bool  PrcGWave::bFormatField( wxString & rosField )
 
   return( TRUE );
 }
-
+*/
 //*****************************************************************************
 // View the results of a simulation.
 // (Eg. using the following: gwave ../sch/test-amp1.gnucap.dc)
@@ -242,8 +246,8 @@ bool  PrcGWave::bExec( void )
   // Append input file name to argument list
   if( ! bSetArgLst( m_ofnResults.GetFullPath( ) ) ) return( FALSE );
 
-  // Format the file before passing it to the waveform viewer process
-  if( ! bFormatFile( ) )                            return( FALSE );
+  // Filter the file before passing it to the waveform viewer process
+  if( ! bFilterFile( ) )                            return( FALSE );
 
   // Execute the process
   if( ! PrcBase::bExecAsync( ) )                    return( FALSE );
