@@ -5,7 +5,7 @@
 //                waveform viewer. The user can view the raw simulation data  *
 //                or envoke this utility which plots the data graphically.    *
 //  Started     : 10/01/2008                                                  *
-//  Last Update : 22/01/2008                                                  *
+//  Last Update : 30/05/2011                                                  *
 //  Copyright   : (C) 2008 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -28,7 +28,7 @@ using  namespace  std;
 
 #include <iostream>
 
-// wxWindows Includes
+// wxWidgets Includes
 
 #include <wx/wx.h>
 #include <wx/tokenzr.h>
@@ -44,16 +44,14 @@ using  namespace  std;
 
 class PrcGaw : public PrcBase
 {
-  private:
+  private :
 
     wxFileName  m_ofnResults; // The full simulator results file name
 
     // Functions for reformatting the results file for input to the viewer
-    bool  bFormatFile ( void );
-    bool  bFormatLine ( wxString & rosLine );
-    bool  bFormatField( wxString & rosField );
+    bool  bFilterFile( void );
 
-  public:
+  public :
 
     PrcGaw( void );
    ~PrcGaw( );
