@@ -1,10 +1,10 @@
 //*****************************************************************************
 //                                  ChoUnits.cpp                              *
 //                                 --------------                             *
-//  Started     : 27/03/2004                                                  *
-//  Last Update : 22/05/2009                                                  *
-//  Copyright   : (C) 2004 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Started     : 27/03/2004                                                   *
+// Last Update : 11/04/2011                                                   *
+// Copyright   : (C) 2004 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -23,8 +23,7 @@
 
 ChoUnits::ChoUnits( void )
 {
-  m_eUnitsType = eUNITS_NONE;
-  m_osDefUnits = wxT("Units");
+  bClear( );
 }
 
 //*****************************************************************************
@@ -58,7 +57,7 @@ bool  ChoUnits::bCreate( wxWindow * poWin, wxWindowID oWinID, int iWidth )
   if( ! Create( poWin, oWinID, wxDefaultPosition, oSize ) ) return( FALSE );
 
   // Set the units
-  if( ! bSetUnitsType( m_eUnitsType) )                      return( FALSE );
+  if( ! bSetUnitsType( m_eUnitsType ) )                     return( FALSE );
   if( ! bSetUnits( m_osDefUnits ) )                         return( FALSE );
 
   return( TRUE );
@@ -66,15 +65,40 @@ bool  ChoUnits::bCreate( wxWindow * poWin, wxWindowID oWinID, int iWidth )
 
 //*****************************************************************************
 // Clear object attributes.
+//
+// Return Values :
+//   Success - TRUE
+//   Failure - FALSE
 
 bool  ChoUnits::bClear( void )
 {
-  if( ! bIsCreated( ) )                                return( FALSE );
+  m_eUnitsType = eUNITS_NONE;
+  m_eDefUType  = eUNITS_NONE;
+  m_osDefUnits = wxT("Units");
 
-  SetStringSelection( m_osDefUnits );
+  bSetUnitsType( eUNITS_NONE );
 
-  if( GetStringSelection( ).IsSameAs( m_osDefUnits ) ) return( TRUE );
-  else                                                 return( FALSE );
+  if( bIsCreated( ) ) wxChoice::Clear( );
+
+  return( TRUE );
+}
+
+//*****************************************************************************
+// Set default object attributes.
+//
+// Return Values :
+//   Success - TRUE
+//   Failure - FALSE
+
+bool  ChoUnits::bSetDefaults( void )
+{
+  // Set the default units type
+  if( ! bSetUnitsType( m_eDefUType ) ) return( FALSE );
+
+  // Set the default units
+  if( ! bSetUnits( m_osDefUnits ) )    return( FALSE );
+
+  return( TRUE );
 }
 
 //*****************************************************************************
@@ -89,139 +113,108 @@ bool  ChoUnits::bClear( void )
 
 bool  ChoUnits::bSetUnitsType( eUnitsType eUType )
 {
-  if( eUType != eUNITS_NONE )
-    if( eUType<eUNITS_FST || eUType>eUNITS_LST ) return( FALSE );
-  if( ! IsEmpty( ) )
-    if( m_eUnitsType == eUType )                 return( TRUE );
+  if( ! bIsCreated( ) )                      return( FALSE );
 
-  m_eUnitsType = eUType;
+  if( ! IsEmpty( ) && m_eUnitsType==eUType ) return( TRUE );
 
-  if( bIsCreated( ) )
+  Clear( );              // Delete existing choice items from the list
+
+  m_eUnitsType = eUType; // Set the objects units type attribute
+
+  // Load the new choice items into the control
+  switch( m_eUnitsType )
   {
-    Clear( ); // Delete existing choice items from the list
+    case eUNITS_CAP :  // Capacitance
+      Append( wxT("mF"), new wxStringClientData( wxT("-3")  ) );
+      Append( wxT("uF"), new wxStringClientData( wxT("-6")  ) );
+      Append( wxT("nF"), new wxStringClientData( wxT("-9")  ) );
+      Append( wxT("pF"), new wxStringClientData( wxT("-12") ) );
+      SetStringSelection( wxT("uF") );
+      break;
 
-    // Load the new choice items into the control
-    switch( m_eUnitsType )
-    {
-      case eUNITS_NONE:  // No units specified
-        Append( wxT("Units"), new wxStringClientData( wxT("0") ) );
-        bSetDefUnits( wxT("Units") );
-        break;
+    case eUNITS_IND :  // Inductance
+      Append( wxT("H") , new wxStringClientData( wxT("0")  ) );
+      Append( wxT("mH"), new wxStringClientData( wxT("-3") ) );
+      Append( wxT("uH"), new wxStringClientData( wxT("-6") ) );
+      SetStringSelection( wxT("mH") );
+      break;
 
-      case eUNITS_CAP:  // Capacitance
-        Append( wxT("mF"), new wxStringClientData( wxT("-3")  ) );
-        Append( wxT("uF"), new wxStringClientData( wxT("-6")  ) );
-        Append( wxT("nF"), new wxStringClientData( wxT("-9")  ) );
-        Append( wxT("pF"), new wxStringClientData( wxT("-12") ) );
-        bSetDefUnits( wxT("uF") );
-        break;
+    case eUNITS_RES :  // Resistance
+      Append( wxT("MOhm"), new wxStringClientData( wxT("6") ) );
+      Append( wxT("KOhm"), new wxStringClientData( wxT("3") ) );
+      Append( wxT("Ohm") , new wxStringClientData( wxT("0") ) );
+      SetStringSelection( wxT("KOhm") );
+      break;
 
-      case eUNITS_IND:  // Inductance
-        Append( wxT("H"),  new wxStringClientData( wxT("0")  ) );
-        Append( wxT("mH"), new wxStringClientData( wxT("-3") ) );
-        Append( wxT("uH"), new wxStringClientData( wxT("-6") ) );
-        bSetDefUnits( wxT("mH") );
-        break;
+    case eUNITS_VOLT : // Voltage
+      Append( wxT("KV"), new wxStringClientData(  wxT("3") ) );
+      Append( wxT("V") , new wxStringClientData(  wxT("0") ) );
+      Append( wxT("mV"), new wxStringClientData( wxT("-3") ) );
+      Append( wxT("uV"), new wxStringClientData( wxT("-6") ) );
+      SetStringSelection( wxT("mV") );
+      break;
 
-      case eUNITS_RES:  // Resistance
-        Append( wxT("MOhm"), new wxStringClientData( wxT("6") ) );
-        Append( wxT("KOhm"), new wxStringClientData( wxT("3") ) );
-        Append( wxT("Ohm"),  new wxStringClientData( wxT("0") ) );
-        bSetDefUnits( wxT("KOhm") );
-        break;
+    case eUNITS_CURR : // Current
+      Append( wxT("KA"), new wxStringClientData(  wxT("3") ) );
+      Append( wxT("A") , new wxStringClientData(  wxT("0") ) );
+      Append( wxT("mA"), new wxStringClientData( wxT("-3") ) );
+      Append( wxT("uA"), new wxStringClientData( wxT("-6") ) );
+      SetStringSelection( wxT("mA") );
+      break;
 
-      case eUNITS_VOLT: // Voltage
-        Append( wxT("KV"), new wxStringClientData(  wxT("3") ) );
-        Append( wxT("V"),  new wxStringClientData(  wxT("0") ) );
-        Append( wxT("mV"), new wxStringClientData( wxT("-3") ) );
-        Append( wxT("uV"), new wxStringClientData( wxT("-6") ) );
-        bSetDefUnits( wxT("mV") );
-        break;
+    case eUNITS_TIME : // Time
+      Append( wxT("sec") , new wxStringClientData(   wxT("0") ) );
+      Append( wxT("msec"), new wxStringClientData(  wxT("-3") ) );
+      Append( wxT("usec"), new wxStringClientData(  wxT("-6") ) );
+      Append( wxT("nsec"), new wxStringClientData(  wxT("-9") ) );
+      Append( wxT("psec"), new wxStringClientData( wxT("-12") ) );
+      SetStringSelection( wxT("msec") );
+      break;
 
-      case eUNITS_CURR: // Current
-        Append( wxT("KA"), new wxStringClientData(  wxT("3") ) );
-        Append( wxT("A"),  new wxStringClientData(  wxT("0") ) );
-        Append( wxT("mA"), new wxStringClientData( wxT("-3") ) );
-        Append( wxT("uA"), new wxStringClientData( wxT("-6") ) );
-        bSetDefUnits( wxT("mA") );
-        break;
+    case eUNITS_FREQ : // Frequency
+      Append( wxT("THz"), new wxStringClientData( wxT("12") ) );
+      Append( wxT("GHz"), new wxStringClientData(  wxT("9") ) );
+      Append( wxT("MHz"), new wxStringClientData(  wxT("6") ) );
+      Append( wxT("KHz"), new wxStringClientData(  wxT("3") ) );
+      Append( wxT("Hz") , new wxStringClientData(  wxT("0") ) );
+      SetStringSelection( wxT("KHz") );
+      break;
 
-      case eUNITS_TIME: // Time
-        Append( wxT("sec"),  new wxStringClientData(   wxT("0") ) );
-        Append( wxT("msec"), new wxStringClientData(  wxT("-3") ) );
-        Append( wxT("usec"), new wxStringClientData(  wxT("-6") ) );
-        Append( wxT("nsec"), new wxStringClientData(  wxT("-9") ) );
-        Append( wxT("psec"), new wxStringClientData( wxT("-12") ) );
-        bSetDefUnits( wxT("msec") );
-        break;
+    case eUNITS_PHASE : // Phase
+      Append( wxT("Degree"), new wxStringClientData( wxT("0") ) );
+      Append( wxT("Radian"), new wxStringClientData( wxT("0") ) );
+      Append( wxT("Grad")  , new wxStringClientData( wxT("0") ) );
+      SetStringSelection( wxT("Degree") );
+      break;
 
-      case eUNITS_FREQ: // Frequency
-        Append( wxT("THz"), new wxStringClientData( wxT("12") ) );
-        Append( wxT("GHz"), new wxStringClientData(  wxT("9") ) );
-        Append( wxT("MHz"), new wxStringClientData(  wxT("6") ) );
-        Append( wxT("KHz"), new wxStringClientData(  wxT("3") ) );
-        Append( wxT("Hz"),  new wxStringClientData(  wxT("0") ) );
-        bSetDefUnits( wxT("KHz") );
-        break;
+    case eUNITS_TEMP : // Temperature
+      Append( wxT("Deg C"), new wxStringClientData( wxT("0") ) );
+      Append( wxT("Deg F"), new wxStringClientData( wxT("0") ) );
+      Append( wxT("Deg K"), new wxStringClientData( wxT("0") ) );
+      SetStringSelection( wxT("Deg C") );
+      break;
 
-      case eUNITS_PHASE: // Phase
-        Append( wxT("Degree"), new wxStringClientData( wxT("0") ) );
-        Append( wxT("Radian"), new wxStringClientData( wxT("0") ) );
-        Append( wxT("Grad")  , new wxStringClientData( wxT("0") ) );
-        bSetDefUnits( wxT("Degree") );
-        break;
+    case eUNITS_SCLR : // Scalar
+      Append( wxT("Tera") , new wxStringClientData(  wxT("12") ) );
+      Append( wxT("Giga") , new wxStringClientData(   wxT("9") ) );
+      Append( wxT("Mega") , new wxStringClientData(   wxT("6") ) );
+      Append( wxT("Kilo") , new wxStringClientData(   wxT("3") ) );
+      Append( wxT("None") , new wxStringClientData(   wxT("0") ) );
+      Append( wxT("milli"), new wxStringClientData(  wxT("-3") ) );
+      Append( wxT("micro"), new wxStringClientData(  wxT("-6") ) );
+      Append( wxT("nano") , new wxStringClientData(  wxT("-9") ) );
+      Append( wxT("pico") , new wxStringClientData( wxT("-12") ) );
+      Append( wxT("femto"), new wxStringClientData( wxT("-15") ) );
+      SetStringSelection( wxT("None") );
+      break;
 
-      case eUNITS_TEMP: // Temperature
-        Append( wxT("Deg C"), new wxStringClientData( wxT("0") ) );
-        Append( wxT("Deg F"), new wxStringClientData( wxT("0") ) );
-        Append( wxT("Deg K"), new wxStringClientData( wxT("0") ) );
-        bSetDefUnits( wxT("Deg C") );
-        break;
-
-      case eUNITS_SCLR: // Scalar
-        Append( wxT("Tera"),  new wxStringClientData(  wxT("12") ) );
-        Append( wxT("Giga"),  new wxStringClientData(   wxT("9") ) );
-        Append( wxT("Mega"),  new wxStringClientData(   wxT("6") ) );
-        Append( wxT("Kilo"),  new wxStringClientData(   wxT("3") ) );
-        Append( wxT("none"),  new wxStringClientData(   wxT("0") ) );
-        Append( wxT("milli"), new wxStringClientData(  wxT("-3") ) );
-        Append( wxT("micro"), new wxStringClientData(  wxT("-6") ) );
-        Append( wxT("nano"),  new wxStringClientData(  wxT("-9") ) );
-        Append( wxT("pico"),  new wxStringClientData( wxT("-12") ) );
-        Append( wxT("femto"), new wxStringClientData( wxT("-15") ) );
-        bSetDefUnits( wxT("none") );
-        break;
-
-      default:
-        return( FALSE );
-    }
-
-    bClear( );
+    case eUNITS_NONE :  // No units specified
+      Append( wxT("Units"), new wxStringClientData( wxT("0") ) );
+      SetStringSelection( wxT("Units") );
+      break;
   }
 
-  return( TRUE );
-}
-
-//*****************************************************************************
-// Set the default units to be displayed (ie. at startup and after bClear( ) is
-// called).
-//
-// Argument List :
-//   rosUnits - The default units to be used
-//
-// Return Values :
-//   Success - TRUE
-//   Failure - FALSE
-
-bool  ChoUnits::bSetDefUnits( const wxString rosUnits )
-{
-  int  i1;
-
-  if( ! bIsCreated( ) )   return( FALSE );
-
-  i1 = FindString( rosUnits );
-  if( i1 == wxNOT_FOUND ) return( FALSE );
-  m_osDefUnits = rosUnits;
+  m_osDefUnits = GetStringSelection( );
 
   return( TRUE );
 }
@@ -244,6 +237,7 @@ bool  ChoUnits::bSetUnits( const wxString rosUnits )
 
   i1 = FindString( rosUnits );
   if( i1 == wxNOT_FOUND ) return( FALSE );
+
   SetSelection( i1 );
 
   return( TRUE );
@@ -284,6 +278,47 @@ bool  ChoUnits::bSetUnits( int iExponent )
   return( FALSE );
 }
 
+//*****************************************************************************
+// Set the default units.
+//
+// Argument List :
+//   rosUnits - The default units to be used
+//
+// Return Values :
+//   Success - TRUE
+//   Failure - FALSE
+/*
+bool  ChoUnits::bSetDefUnits( const wxString rosUnits )
+{
+  eUnitsType  eUType;
+  int         i1;
+
+  // Don't proceed unless the display object has been created
+  if( ! bIsCreated( ) )   return( FALSE );
+
+  // Temporarily set the units type to the default
+  if( m_eUnitsType != m_eDefUType )
+  {
+    eUType = m_eUnitsType;
+    bSetUnitsType( m_eDefUType );
+  }
+
+  // Attempt to find the specified units
+  i1 = FindString( rosUnits );
+
+  // Return the units type to the original value
+  if( eUType != m_eDefUType )
+    bSetUnitsType( eUType );
+
+  // If the units couldn't be found return
+  if( i1 == wxNOT_FOUND ) return( FALSE );
+
+  // Set the default units
+  m_osDefUnits = rosUnits;
+
+  return( TRUE );
+}
+*/
 //*****************************************************************************
 // Get the currently selected units.
 //
@@ -350,13 +385,14 @@ long  ChoUnits::liGetValue( float fValue )
 }
 
 //*****************************************************************************
-// Combine a value with it's units to produce the equivalent double value.
+// Combine a value with it's units to produce a single value.
 //
 // Argument List :
 //   fValue  - The float value
 //
 // Return Values :
-//   The value & units as a double
+//   Success - The value combined with it's units as a double
+//   Failure - 0.0
 
 double  ChoUnits::dfGetValue( float fValue )
 {
@@ -368,32 +404,34 @@ double  ChoUnits::dfGetValue( float fValue )
   if( ! bIsCreated( ) || fValue==0.0 ) return( 0.0 );
 
   i1 = GetSelection( );
+  if( i1 == wxNOT_FOUND )              return( 0.0 );
+
   os1 = ( (wxStringClientData *) GetClientObject( i1 ) )->GetData( );
   os1.ToLong( &li1 );
 
   switch( m_eUnitsType )
   {
-    case eUNITS_CAP:   // Capacitance
+    case eUNITS_CAP :   // Capacitance
 
-    case eUNITS_IND:   // Inductance
+    case eUNITS_IND :   // Inductance
 
-    case eUNITS_RES:   // Resistance
+    case eUNITS_RES :   // Resistance
 
-    case eUNITS_VOLT:  // Voltage
+    case eUNITS_VOLT :  // Voltage
 
-    case eUNITS_CURR:  // Current
+    case eUNITS_CURR :  // Current
 
-    case eUNITS_TIME:  // Time
+    case eUNITS_TIME :  // Time
 
-    case eUNITS_FREQ:  // Frequency
+    case eUNITS_FREQ :  // Frequency
 
-    case eUNITS_SCLR:  // Scalar
+    case eUNITS_SCLR :  // Scalar
       if( fValue == 0.0 ) df1 = 0.0;
       else if( li1 == 0 ) df1 = (double) fValue;
       else                df1 = (double) fValue * pow( (float) 10.0, (float) li1 );
       break;
 
-    case eUNITS_PHASE: // Phase (convert phase to Degree)
+    case eUNITS_PHASE : // Phase (convert phase to Degree)
       df1 = (double) fValue;
       switch( i1 )
       {
@@ -404,7 +442,7 @@ double  ChoUnits::dfGetValue( float fValue )
       }
       break;
 
-    case eUNITS_TEMP:  // Temperature (convert temperature to Deg. C)
+    case eUNITS_TEMP :  // Temperature (convert temperature to Deg. C)
       df1 = (double) fValue;
       switch( i1 )
       {
@@ -415,7 +453,7 @@ double  ChoUnits::dfGetValue( float fValue )
       }
       break;
 
-    default:
+    default :
       df1 = 0.0;
   }
 
@@ -446,13 +484,13 @@ const wxString & ChoUnits::rosGetValue( float fValue )
   osUnits = rosGetUnits( );
   if( osUnits.IsEmpty( ) ) return( osValue );
 
-  if( osUnits != wxT("none") )
+  if( osUnits != wxT("None") )
   {
     if( osUnits == wxT("micro") )
       osValue << wxT('u');
     else
     {
-      switch( osUnits.GetChar( 0 ) )
+      switch( (char) osUnits.GetChar( 0 ) )
       {
         case wxT('T'): osValue << wxT("Tera"); break;
         case wxT('G'): osValue << wxT("Giga"); break;
