@@ -2,7 +2,7 @@
 //                                ConvertType.hpp                             *
 //                               -----------------                            *
 //  Started     : 21/09/2004                                                  *
-//  Last Update : 19/02/2010                                                  *
+//  Last Update : 31/03/2011                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -300,30 +300,30 @@ bool  ConvertType::bDFltToStrEng( double dfNum, wxString & rosNum )
 // Parse a double float value into it's mantissa and exponent.
 //
 // Argument List :
-//   dfNum - The double float value to be parsed
-//   pfMan - A pointer to float   to hold the mantissa (1.000 to 9.999)
-//   piExp - A pointer to integer to hold the exponent
+//   dfNum  - The double float value to be parsed
+//   pdfMan - A pointer to double to hold the mantissa (1.000 to 9.999)
+//   pliExp - A pointer to long   to hold the exponent
 //
 // Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
-bool  ConvertType::bParseDFlt( double dfNum, float * pfMan, int * piExp )
+bool  ConvertType::bParseDFlt( double dfNum, double * pdfMan, long * pliExp )
 {
-  if( dfNum<-FLT_MAX || dfNum>FLT_MAX ) return( FALSE );
+  if( dfNum<-DBL_MAX || dfNum>DBL_MAX ) return( FALSE );
 
   if( dfNum != 0.0 )
   {
-    *piExp = (int) floor( log10( fabs( dfNum ) ) );
-    *pfMan = dfNum / pow( 10.0, *piExp );
+    *pliExp = (long) floor( log10( fabs( dfNum ) ) );
+    *pdfMan = dfNum / pow( 10.0, *pliExp );
 
-    if( fabs(*pfMan) <   1.0 ) { (*pfMan) *= 10.0; (*piExp)--; }
-    if( fabs(*pfMan) >= 10.0 ) { (*pfMan) /= 10.0; (*piExp)++; }
+    if( fabs(*pdfMan) <   1.0 ) { (*pdfMan) *= 10.0; (*pliExp)--; }
+    if( fabs(*pdfMan) >= 10.0 ) { (*pdfMan) /= 10.0; (*pliExp)++; }
   }
   else
   {
-    *pfMan = 0.0;
-    *piExp = 0;
+    *pdfMan = 0.0;
+    *pliExp = 0;
   }
 
   return( TRUE );
@@ -424,9 +424,23 @@ bool  ConvertType::bFltToStrEng( float fNum, wxString & rosNum )
 
 bool  ConvertType::bParseFlt( float fNum, float * pfMan, int * piExp )
 {
-  double  df1 = (double) fNum;
+  if( fNum<-FLT_MAX || fNum>FLT_MAX ) return( FALSE );
 
-  return( bParseDFlt( df1, pfMan, piExp ) );
+  if( fNum != 0.0 )
+  {
+    *piExp = (int) floorf( log10( fabs( fNum ) ) );
+    *pfMan = fNum / pow( 10.0, *piExp );
+
+    if( fabs(*pfMan) <   1.0 ) { (*pfMan) *= 10.0; (*piExp)--; }
+    if( fabs(*pfMan) >= 10.0 ) { (*pfMan) /= 10.0; (*piExp)++; }
+  }
+  else
+  {
+    *pfMan = 0.0;
+    *piExp = 0;
+  }
+
+  return( TRUE );
 }
 
 //*****************************************************************************
@@ -446,12 +460,10 @@ void  Usage( char * psAppName );
 int  main( int argc, char * argv[ ] )
 {
   wxString  osNum, os1;
-  double    dfNum;
-  long      liNum;
-  float     fNum;
-  int       iNum;
-  float     fMan;
-  int       iExp;
+  double    dfNum, dfMan;
+  long      liNum, liExp;
+  float     fNum,  fMan;
+  int       iNum,  iExp;
 
   // Validate the argument count passed to the application
   if( argc > 2 )           { Usage( argv[ 0 ] ); exit( EXIT_FAILURE ); }
@@ -466,7 +478,7 @@ int  main( int argc, char * argv[ ] )
 
   // Display the utility banner
   cout << "\n  ConvertType Class Test Utility"
-       << "\n    Version 1.05 (19/02/2010)\n\n";
+       << "\n    Version 1.06 (12/08/2011)\n\n";
 
   cout << "ConvertType::rosGetNum    ( ) : ";
   osNum = wxT("-10.0E-2uF");
@@ -504,9 +516,9 @@ int  main( int argc, char * argv[ ] )
 
   cout << "ConvertType::bParseDFlt   ( ) : ";
   dfNum = 12.3E-04;
-  if( ConvertType::bParseDFlt( dfNum, &fMan, &iExp ) )   cout << "Success";
+  if( ConvertType::bParseDFlt( dfNum, &dfMan, &liExp ) ) cout << "Success";
   else                                                   cout << "Failure";
-  cout << " (" << dfNum << " -> " << fMan << "E" << iExp << ")\n";
+  cout << " (" << dfNum << " -> " << dfMan << "E" << liExp << ")\n";
 
   cout << "ConvertType::bStrToInt    ( ) : ";
   osNum = wxT("123.45E-5");
