@@ -2,7 +2,7 @@
 //                                 PnlValue.cpp                               *
 //                                --------------                              *
 //  Started     : 14/09/2004                                                  *
-//  Last Update : 22/02/2010                                                  *
+//  Last Update : 11/04/2011                                                  *
 //  Copyright   : (C) 2004 by MSWaters                                        *
 //  Email       : M.Waters@bom.gov.au                                         *
 //*****************************************************************************
@@ -25,6 +25,7 @@ BEGIN_EVENT_TABLE( PnlValue, wxPanel )
 
   EVT_SPIN_UP  ( SpinCtrl::ID_SPINBTN, PnlValue::OnSpnScroll )
   EVT_SPIN_DOWN( SpinCtrl::ID_SPINBTN, PnlValue::OnSpnScroll )
+
   EVT_CHOICE   ( ID_CHO_UNITS,         PnlValue::OnChoUnits  )
 
 END_EVENT_TABLE( )
@@ -106,42 +107,44 @@ bool  PnlValue::bPhaseToDeg( float * pfValue )
 
 void  PnlValue::DoLayout( void )
 {
-  wxBoxSizer * poSizer;
+  wxBoxSizer  * poSzr;
   wxSizerFlags  oFlags;
 
-  poSizer = new wxBoxSizer( wxHORIZONTAL );
+  // Create the sizer for the panel
+  poSzr = new wxBoxSizer( wxHORIZONTAL );
 
   oFlags.Expand( );
   oFlags.Border( wxTOP | wxBOTTOM, 1 );
 
+  // Add the value label
   if( m_oLblName.GetParent( ) != NULL )
   {
     oFlags.Proportion( 1 );
+// The lines marked with ??? are a fix for a bug in wxWidgets ie. the following line has no effect.
     oFlags.Align( wxALIGN_LEFT | wxALIGN_CENTER_VERTICAL );
-// The lines marked with ??? are a fix for a bug in wxWidgets ie. the above
-// line has no effect.
 oFlags.Border( wxTOP, 7 );            // ??? 26/05/2007
-    poSizer->Add( &m_oLblName, oFlags );
+    poSzr->Add( &m_oLblName, oFlags );
 oFlags.Border( wxTOP | wxBOTTOM, 1 ); // ??? 26/05/2007
-    poSizer->AddSpacer( 5 );
+    poSzr->AddSpacer( 5 );
   }
 
+  // Add the value itself
   oFlags.Proportion( 0 );
   oFlags.Center( );
-  poSizer->Add( &m_oSpnValue, oFlags );
+  poSzr->Add( &m_oSpnValue, oFlags );
 
+  // Add units for the value
   if( m_bUseUnits )
   {
-    poSizer->AddSpacer( 2 );
-    poSizer->Add( &m_oChoUnits, oFlags );
+    poSzr->AddSpacer( 2 );
+    poSzr->Add( &m_oChoUnits, oFlags );
 oFlags.Border( wxTOP, 7 );            // ??? 26/05/2007
-    poSizer->Add( &m_oLblUnits, oFlags );
+    poSzr->Add( &m_oLblUnits, oFlags );
   }
 
-  SetSizer( poSizer );
-
-  // Set minimum size and initial size as calculated by the sizer
-  poSizer->SetSizeHints( this );
+  // Set the panel sizer and the min. & init. sizes as calculated by the sizer
+  SetSizer( poSzr );
+  poSzr->SetSizeHints( this );
 }
 
 //*****************************************************************************
@@ -164,19 +167,19 @@ bool  PnlValue::bCreate( wxWindow * poWin, wxWindowID oWinID, int iWidth,
   bool  bRtn=TRUE;
   int   iWd, iHt;
 
-  if( bIsCreated( ) )                     return( TRUE );
+  if( bIsCreated( ) )                                     return( TRUE );
 
   // Create the base class (wxPanel)
-  if( ! Create( poWin, oWinID, roPosn ) ) return( FALSE );
+  if( ! Create( poWin, oWinID, roPosn ) )                 return( FALSE );
 
+  // Create the variable name label
   if( iWidth > 0 )
-  { // Create the variable name label
-    bRtn = m_oLblName.Create( this, ID_UNUSED, wxT(""), wxDefaultPosition,
-                              wxSize( iWidth, PNLVALUE_HT ), wxALIGN_LEFT );
-  }
+    if( ! m_oLblName.Create( this, ID_UNUSED, wxT(""), wxDefaultPosition,
+                             wxSize( iWidth, PNLVALUE_HT ), wxALIGN_LEFT ) )
+                                                          bRtn = FALSE;
 
   // Create the value spin control
-  if( ! m_oSpnValue.bCreate( this, ID_SPN_VALUE, 80 ) ) bRtn = FALSE;
+  if( ! m_oSpnValue.bCreate( this, ID_SPN_VALUE, 80 ) )   bRtn = FALSE;
 
   // Create the units controls
   m_bUseUnits = bUnits;
@@ -189,17 +192,13 @@ bool  PnlValue::bCreate( wxWindow * poWin, wxWindowID oWinID, int iWidth,
     m_oChoUnits.GetClientSize( &iWd, &iHt );
     if( ! m_oLblUnits.Create( this, ID_LBL_UNITS, wxT(""), wxDefaultPosition,
                               wxSize( iWd, PNLVALUE_HT ), wxST_NO_AUTORESIZE ) )
-      bRtn = FALSE;
+                                                          bRtn = FALSE;
     m_oLblUnits.Show( FALSE );
   }
 
   // Layout the display objects
   DoLayout( );
 
-// (15/10/2008) I suspect that the following just fixes a bug in wxWidgets, the
-// back-ground of the parent window isn't inherited by it's children
-this->SetBackgroundColour( poWin->GetBackgroundColour( ) ); // ??? 15/10/2008
-
   return( bRtn );
 }
 
@@ -220,6 +219,23 @@ bool  PnlValue::bClear( void )
   return( bRtn );
 }
 
+//*****************************************************************************
+// Set default object attributes.
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  PnlValue::bSetDefaults( void )
+{
+  bool  bRtn=TRUE;
+
+  if( ! m_oSpnValue.bSetDefaults( ) ) bRtn = FALSE;
+  if( ! m_oChoUnits.bSetDefaults( ) ) bRtn = FALSE;
+
+  return( bRtn );
+}
+
 //*****************************************************************************
 // Set the name label.
 //
@@ -251,7 +267,7 @@ bool  PnlValue::bSetName( const wxString & rosName )
 //   Success - TRUE
 //   Failure - FALSE
 
-bool  PnlValue::bSetVarType( SpinCtrl::eVarType eVType )
+bool  PnlValue::bSetVarType( eVarType eVType )
 {
   if( ! bIsCreated( ) ) return( FALSE );
 
@@ -332,13 +348,12 @@ bool  PnlValue::bSetParms( float fDefValue, float fMinValue, float fMaxValue,
 //
 // Argument List :
 //   liValue  - The long integer value
-//   bNoUnits - Flag indicating if the units should be updated
 //
 // Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
-bool  PnlValue::bSetValue( long liValue, bool bNoUnits )
+bool  PnlValue::bSetValue( long liValue )
 {
   bool    bRtn=TRUE;
   float   fMan;
@@ -354,7 +369,7 @@ bool  PnlValue::bSetValue( long liValue, bool bNoUnits )
     else              liValue = (int) ( fMan - 0.5 );
   }
 
-  if( m_bUseUnits && m_oChoUnits.IsShown( ) && !bNoUnits )
+  if( m_bUseUnits && m_oChoUnits.IsShown( ) )
   {
     // Determine the spin control value and the units choice selection
     ConvertType::bParseFlt( (double) liValue, &fMan, &iExp );
@@ -379,13 +394,12 @@ bool  PnlValue::bSetValue( long liValue, bool bNoUnits )
 //
 // Argument List :
 //   dfValue  - The double float value
-//   bNoUnits - Flag indicating if the units should be updated
 //
 // Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
-bool  PnlValue::bSetValue( double dfValue, bool bNoUnits )
+bool  PnlValue::bSetValue( double dfValue )
 {
   bool   bRtn=TRUE;
   float  fMan=0.0;
@@ -397,7 +411,7 @@ bool  PnlValue::bSetValue( double dfValue, bool bNoUnits )
   bTempToDegC( &fMan );  // Convert value to Deg.C  if appropriate
   bPhaseToDeg( &fMan );  // Convert value to Degree if appropriate
 
-  if( m_bUseUnits && m_oChoUnits.IsShown( ) && !bNoUnits )
+  if( m_bUseUnits && m_oChoUnits.IsShown( ) )
   {
     // Determine the spin control value and the units choice selection
     ConvertType::bParseFlt( dfValue, &fMan, &iExp );
@@ -408,7 +422,7 @@ bool  PnlValue::bSetValue( double dfValue, bool bNoUnits )
     }
 
     // Set the spin control and choice control values
-    if( ! m_oChoUnits.bSetUnits( iExp ) )            bRtn = FALSE;
+    if(      ! m_oChoUnits.bSetUnits( iExp ) )       bRtn = FALSE;
     else if( ! m_oSpnValue.bSetValue( fMan ) )       bRtn = FALSE;
   }
   else
@@ -422,32 +436,32 @@ bool  PnlValue::bSetValue( double dfValue, bool bNoUnits )
 //
 // Argument List :
 //   rosValue - The string value
-//   bNoUnits - Flag indicating if the units should be updated
 //
 // Return Values :
 //   Success - TRUE
 //   Failure - FALSE
 
-bool  PnlValue::bSetValue( const wxString & rosValue, bool bNoUnits )
+bool  PnlValue::bSetValue( const wxString & rosValue )
 {
   wxString  os1;
-  double    df1;
-  float     f1;
-  int       i1;
+  double    df1, df2;
+  long      li1;
 
-  if( ! bIsCreated( ) )                              return( FALSE );
+  // Don't continue unless the panel has been created
+  if( ! bIsCreated( ) )                                return( FALSE );
 
   // Set the value
-  if( ! ConvertType::bStrToDFlt( rosValue, &df1 ) )  return( FALSE );
-  if( ! bSetValue( df1, bNoUnits ) )                 return( FALSE );
+  if( ! ConvertType::bStrToDFlt( rosValue, &df1 ) )    return( FALSE );
+  if( ! bSetValue( df1 ) )                             return( FALSE );
 
-  if( df1==0.0 && !bNoUnits )
-  { // If the value is attempt to set the units
+  // For zero values the units will have been ignored, attempt to set them here
+  if( df1 == 0.0 )
+  {
     os1 = rosValue;
     os1.at( 0 ) = '1';
-    if( ! ConvertType::bStrToDFlt( os1, &df1 ) )     return( FALSE );
-    if( ! ConvertType::bParseDFlt( df1, &f1, &i1 ) ) return( FALSE );
-    if( ! m_oChoUnits.bSetUnits( i1 ) )              return( FALSE );
+    if( ! ConvertType::bStrToDFlt( os1, &df1 ) )       return( FALSE );
+    if( ! ConvertType::bParseDFlt( df1, &df2, &li1 ) ) return( FALSE );
+    if( ! m_oChoUnits.bSetUnits( (int) li1 ) )         return( FALSE );
   }
 
   return( TRUE );
@@ -470,6 +484,7 @@ bool  PnlValue::bSetUnitsType( eUnitsType eUType )
   if( ! m_bUseUnits || ! bIsCreated( ) )       return( FALSE );
   if( m_oChoUnits.eGetUnitsType( ) == eUType ) return( TRUE );
   if( ! m_oChoUnits.bSetUnitsType( eUType ) )  return( FALSE );
+  m_oChoUnits.m_eDefUType = eUType;
 
   // Automatically set the spin control parameters
   switch( eUType )
@@ -507,7 +522,7 @@ bool  PnlValue::bSetUnitsType( eUnitsType eUType )
       break;
 
     case eUNITS_TEMP  :  // Temperature
-      bRtn = m_oSpnValue.bSetParms(  27.0,  -100.0,  200.0, 1.0,   5.0 );
+      bRtn = m_oSpnValue.bSetParms(  27.0,  -100.0,  200.0, 1.0 );
       break;
 
     case eUNITS_SCLR  :  // Scalar
