@@ -1,10 +1,10 @@
 //*****************************************************************************
 //                                  SpinCtrl.cpp                              *
 //                                 --------------                             *
-//  Started     : 20/03/2004                                                  *
-//  Last Update : 09/06/2009                                                  *
-//  Copyright   : (C) 2004 by MSWaters                                        *
-//  Email       : M.Waters@bom.gov.au                                         *
+// Started     : 20/03/2004                                                   *
+// Last Update : 19/05/2011                                                   *
+// Copyright   : (C) 2004 by MSWaters                                         *
+// Email       : M.Waters@bom.gov.au                                          *
 //*****************************************************************************
 
 //*****************************************************************************
@@ -24,7 +24,9 @@
 BEGIN_EVENT_TABLE( SpinCtrl, wxPanel )
 
   EVT_CHAR       (             SpinCtrl::OnTxtChar   )
+
   EVT_TEXT_MAXLEN( ID_TXTCTRL, SpinCtrl::OnTxtMaxLen )
+
   EVT_SPIN_UP    ( ID_SPINBTN, SpinCtrl::OnSbnInc    )
   EVT_SPIN_DOWN  ( ID_SPINBTN, SpinCtrl::OnSbnDec    )
 
@@ -33,7 +35,7 @@ END_EVENT_TABLE( )
 //*****************************************************************************
 // Constructor.
 //
-// Argument List:
+// Argument List :
 //   eVType - The type of the variable to be displayed
 
 SpinCtrl::SpinCtrl( eVarType eVType ) : wxPanel( )
@@ -79,12 +81,12 @@ void  SpinCtrl::DoLayout( void )
 //*****************************************************************************
 // Create an instance of this object.
 //
-// Argument List:
+// Argument List :
 //   poWin  - The parent window
 //   oWinID - The window identifier
 //   iWidth - The width the spin control in pixels
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -103,7 +105,7 @@ bool  SpinCtrl::bCreate( wxWindow * poWin, wxWindowID oWinID, int iWidth )
                       wxDefaultSize, wxSP_VERTICAL | wxSP_ARROW_KEYS );
 
   // Set the display object attributes
-  m_oTxtValue.SetMaxLength( SPNCTL_MAXLEN );
+  m_oTxtValue.SetMaxLength( SPN_MAXLEN );
   m_oSbnValue.SetRange( -0x8000, 0x7FFF );
   bSetParms( m_fDefValue, m_fMinValue, m_fMaxValue, m_fMinIncSz, m_fMaxIncSz );
   bSetValue( m_fDefValue );
@@ -117,22 +119,45 @@ bool  SpinCtrl::bCreate( wxWindow * poWin, wxWindowID oWinID, int iWidth )
 //*****************************************************************************
 // Clear the object attributes.
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
 bool  SpinCtrl::bClear( void )
+{
+  m_eVarType  = eVAR_NONE;
+  m_fDefValue = NOVAL_FLT;
+  m_fMinValue = NOVAL_FLT;
+  m_fMaxValue = NOVAL_FLT;
+  m_fMinIncSz = NOVAL_FLT;
+  m_fMaxIncSz = NOVAL_FLT;
+
+  if( ! bIsCreated( ) ) return( FALSE );
+
+  m_oTxtValue.Clear( );
+
+  return( TRUE );
+}
+
+//*****************************************************************************
+// Set default object attributes.
+//
+// Return Values :
+//   TRUE  - Success
+//   FALSE - Failure
+
+bool  SpinCtrl::bSetDefaults( void )
 {
   return( bSetValue( m_fDefValue ) );
 }
 
 //*****************************************************************************
-// Set the variable type to displayed by the spin control.
+// Set the variable type to be displayed by the spin control.
 //
-// Argument List:
+// Argument List :
 //   eVType - The variable type specifier
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -159,10 +184,10 @@ bool  SpinCtrl::bSetVarType( eVarType eVType )
 //*****************************************************************************
 // Set the current value of the spin control.
 //
-// Argument List:
+// Argument List :
 //   fValue - The float value
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -220,10 +245,10 @@ bool  SpinCtrl::bSetValue( float fValue )
 //*****************************************************************************
 // Set the current value of the spin control.
 //
-// Argument List:
+// Argument List :
 //   fValue - The string value
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -240,10 +265,10 @@ bool  SpinCtrl::bSetValue( const wxString & rosValue )
 //*****************************************************************************
 // Set the initial value of the spin control.
 //
-// Argument List:
+// Argument List :
 //   fDefValue - The spin control default value
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -265,11 +290,11 @@ bool  SpinCtrl::bSetDefValue( float fDefValue )
 // step size means that the spin control is incremented by an amount dependent
 // on it's current value.
 //
-// Argument List:
+// Argument List :
 //   fMinIncSz - The minimum spin control increment size
 //   fMaxIncSz - The maximum spin control increment size
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -293,11 +318,11 @@ bool  SpinCtrl::bSetIncSz( float fMinIncSz, float fMaxIncSz )
 //*****************************************************************************
 // Set the spincontrol range.
 //
-// Argument List:
+// Argument List :
 //   fMinValue - The spin control minimum value
 //   fMaxValue - The spin control maximum value
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -309,14 +334,14 @@ bool  SpinCtrl::bSetRange( float fMinValue, float fMaxValue )
 //*****************************************************************************
 // Set all the spin control parameters.
 //
-// Argument List:
+// Argument List :
 //   fDefValue - The spin control default value
 //   fMinValue - The spin control minimum value
 //   fMaxValue - The spin control maximum value
 //   fMinIncSz - The spin control minimum increment size (must be positive)
 //   fMaxIncSz - The spin control maximum increment size (must be positive)
 //
-// Return Values:
+// Return Values :
 //   TRUE  - Success
 //   FALSE - Failure
 
@@ -367,7 +392,7 @@ bool  SpinCtrl::bSetParms( float fDefValue, float fMinValue, float fMaxValue,
 //*****************************************************************************
 // Get the current spin control value as an integer.
 //
-// Return Values:
+// Return Values :
 //   Success - The integer value
 //   Failure - INT_MIN
 
@@ -390,7 +415,7 @@ int  SpinCtrl::iGetValue( void )
 //*****************************************************************************
 // Get the current spin control value as a float.
 //
-// Return Values:
+// Return Values :
 //   Success - The float value
 //   Failure - -FLT_MAX
 
@@ -412,7 +437,7 @@ float  SpinCtrl::fGetValue( void )
 //*****************************************************************************
 // Get the current spin control value as a string.
 //
-// Return Values:
+// Return Values :
 //   Success - The string value
 //   Failure - An empty string
 
@@ -438,7 +463,7 @@ const wxString & SpinCtrl::rosGetValue( void )
 //*****************************************************************************
 // Key press event handler.
 //
-// Argument List:
+// Argument List :
 //   roEvtKey - An object holding information about the event
 
 void  SpinCtrl::OnTxtChar( wxKeyEvent & roEvtKey )
@@ -478,16 +503,16 @@ void  SpinCtrl::OnTxtChar( wxKeyEvent & roEvtKey )
     case WXK_BACK :
     case WXK_DELETE :
       break;
+
     default :
       wxBell( );  // Sound the system bell
-std::cerr << "SpinCtrl::OnTxtChar( ) - Invalid character\n"; // ??? 08/08/2007
   }
 }
 
 //*****************************************************************************
 // Text control maximum length reached event handler.
 //
-// Argument List:
+// Argument List :
 //   roEvtCmd - An object holding information about the event
 
 void  SpinCtrl::OnTxtMaxLen( wxCommandEvent & roEvtCmd )
@@ -498,42 +523,54 @@ void  SpinCtrl::OnTxtMaxLen( wxCommandEvent & roEvtCmd )
 //*****************************************************************************
 // Spin button scroll up event handler.
 //
-// Argument List:
+// Argument List :
 //   roEvtSpn - An object holding information about the event
 
 void  SpinCtrl::OnSbnInc( wxSpinEvent & roEvtSpn )
 {
+  static  uint  ui_msec=0;
+  float     fValue, fIncSz;
   wxString  os1;
-  double    df1;
-  float     fValue, fIncSz, f1;
-  int       i1;
+  double    df1, df2;
+  long      li1;
+  uint      ui1;
+
+  // Allow additional event handlers to be called
+  roEvtSpn.Skip( );
+
+  // Increment the text control SPN_RPTRATE times per second
+  ui1 = (uint) wxGetLocalTimeMillis( ).GetLo( );
+  if( ui1>ui_msec && (ui1-ui_msec)<SPN_PERIOD )      return;
+  ui_msec = ui1;
 
   // Get the current text control value
   os1 = m_oTxtValue.GetValue( );
   df1 = 0.0;
-  if( ! ConvertType::bStrToDFlt( os1, &df1 ) )     return;
-  if( ! ConvertType::bParseDFlt( df1, &f1, &i1 ) ) return;
+  if( ! ConvertType::bStrToDFlt( os1, &df1 ) )       return;
+  if( ! ConvertType::bParseDFlt( df1, &df2, &li1 ) ) return;
   fValue = (float) df1;
 
   // Determine the increment size to use
-  if( f1 == -1.0 ) i1--;
+  if( df2 == -1.0 ) li1--;
   if( m_eVarType==eVAR_SCI || m_eVarType==eVAR_ENG )
   {
-    fIncSz = (float) pow( 10.0, (double) i1-1 );
+    fIncSz = (float) pow( 10.0, (double) li1-1 );
     if( fValue == 0.0 ) fIncSz = m_fMinValue;
   }
   else
   {
-    fIncSz = (float) pow( 10.0, (double) i1 );
+    fIncSz = (float) pow( 10.0, (double) li1 );
     if( fIncSz < m_fMinIncSz ) fIncSz = m_fMinIncSz;
     if( fIncSz > m_fMaxIncSz ) fIncSz = m_fMaxIncSz;
   }
 
   // Determine if the text control has been altered by the user
-  f1 = ceilf( fValue / fIncSz ) * fIncSz - fValue;
+  df2 = ceil( (double) fValue / (double) fIncSz ) * (double) fIncSz
+                                                             - (double) fValue;
   // Allow for small errors in the floating point calculations
-  if( fabs(f1 / fIncSz)>0.0001 && fabs((f1 - fIncSz) / fIncSz)>0.0001 )
-    fIncSz = f1;
+  if( fabs(   df2 / (double) fIncSz )                     > 0.0001 &&
+      fabs( ( df2 - (double) fIncSz ) / (double) fIncSz ) > 0.0001 )
+    fIncSz = (float) df2;
 
   // Increment the value
   if( fValue < m_fMaxValue )
@@ -546,48 +583,61 @@ void  SpinCtrl::OnSbnInc( wxSpinEvent & roEvtSpn )
     if( fValue < m_fMinValue ) fValue = m_fMinValue;
   }
 
-  bSetValue( fValue );    // Set the text control value
-
-  roEvtSpn.Skip( TRUE );  // Allow additional event handlers to be called
+  // Set the text control value
+  bSetValue( fValue );
 }
 
 //*****************************************************************************
 // Spin button scroll down event handler.
 //
-// Argument List:
+// Argument List :
 //   roEvtSpn - An object holding information about the event
 
 void  SpinCtrl::OnSbnDec( wxSpinEvent & roEvtSpn )
 {
+  static  uint  ui_msec=0;
+  float     fValue, fIncSz;
   wxString  os1;
-  double    df1=0.0;
-  float     fValue, fIncSz, f1;
-  int       i1;
+  double    df1, df2;
+  long      li1;
+  uint      ui1;
+
+  // Allow additional event handlers to be called
+  roEvtSpn.Skip( );
+
+  // Decrement the text control SPN_RPTRATE times per second
+  ui1 = (uint) wxGetLocalTimeMillis( ).GetLo( );
+  if( ui1>ui_msec && (ui1-ui_msec)<SPN_PERIOD )      return;
+  ui_msec = ui1;
 
   // Get the current text control value
-  if( ! ConvertType::bStrToDFlt( m_oTxtValue.GetValue( ), &df1 ) ) return;
-  if( ! ConvertType::bParseDFlt( df1, &f1, &i1 ) )                 return;
+  os1 = m_oTxtValue.GetValue( );
+  df1 = 0.0;
+  if( ! ConvertType::bStrToDFlt( os1, &df1 ) )       return;
+  if( ! ConvertType::bParseDFlt( df1, &df2, &li1 ) ) return;
   fValue = (float) df1;
 
   // Determine the decrement size to use
-  if( f1 == 1.0 ) i1--;
+  if( df2 == 1.0 ) li1--;
   if( m_eVarType==eVAR_SCI || m_eVarType==eVAR_ENG )
   {
-    fIncSz = (float) pow( 10.0, (double) i1-1 );
+    fIncSz = (float) pow( 10.0, (double) li1-1 );
     if( fValue == 0.0 ) fIncSz = m_fMinValue;
   }
   else
   {
-    fIncSz = (float) pow( 10.0, (double) i1 );
+    fIncSz = (float) pow( 10.0, (double) li1 );
     if( fIncSz < m_fMinIncSz ) fIncSz = m_fMinIncSz;
     if( fIncSz > m_fMaxIncSz ) fIncSz = m_fMaxIncSz;
   }
 
   // Determine if the text control has been altered by the user
-  f1 = fValue - floorf( fValue / fIncSz ) * fIncSz;
+  df2 = (double) fValue
+                - floor( (double) fValue / (double) fIncSz ) * (double) fIncSz;
   // Allow for small errors in the floating point calculations
-  if( fabs(f1 / fIncSz)>0.0001 && fabs((f1 - fIncSz) / fIncSz)>0.0001 )
-    fIncSz = f1;
+  if( fabs(   df2 / (double) fIncSz )                     > 0.0001 &&
+      fabs( ( df2 - (double) fIncSz ) / (double) fIncSz ) > 0.0001 )
+    fIncSz = (float) df2;
 
   // Decrement the value
   if( fValue > m_fMinValue )
@@ -600,9 +650,8 @@ void  SpinCtrl::OnSbnDec( wxSpinEvent & roEvtSpn )
     fValue = 0.0;
   }
 
-  bSetValue( fValue );    // Set the text control value
-
-  roEvtSpn.Skip( TRUE );  // Allow additional event handlers to be called
+  // Set the text control value
+  bSetValue( fValue );
 }
 
 //*****************************************************************************
