@@ -21,15 +21,15 @@
 //*****************************************************************************
 // Initialize static variables for class
 
-int  TextCtrl::m_iLinesMax = TXTCTL_LINESDEF;
-int  TextCtrl::m_iLinesDsp = TXTCTL_DISPDEF;
+int  TextCtrl::m_iLinesMax = TCTL_LINESDEF;
+int  TextCtrl::m_iLinesDsp = TCTL_DISPDEF;
 
 //*****************************************************************************
 // Constructor.
 
 TextCtrl::TextCtrl( void ) : wxTextCtrl( )
 {
-  bSetInitMsg( TXTCTL_INITMSG );
+  bSetInitMsg( TCTL_INITMSG );
 
   bClear( );
 }
@@ -119,7 +119,7 @@ bool  TextCtrl::bInitialize( void )
     SetWindowStyle( GetWindowStyle( ) | wxTE_CENTRE );
 
     // Display the requisite number of blank lines
-    for( i1=1; i1<TXTCTL_INITLINES; i1++ )
+    for( i1=1; i1<TCTL_INITLINES; i1++ )
       AppendText( wxT("\n") );
 
     // Display the default message
@@ -143,7 +143,7 @@ bool  TextCtrl::bIsEmpty( void )
 
   if( wxTextCtrl::IsEmpty( ) )                                return( TRUE );
 
-  for( li1=1; li1<TXTCTL_INITLINES; li1++ )
+  for( li1=1; li1<TCTL_INITLINES; li1++ )
     if( ! GetLineText( li1-1 ).IsEmpty( ) )                   return( FALSE );
 
   if( GetLineText( li1 ).Find( m_osInitMsg ) == wxNOT_FOUND ) return( FALSE );
@@ -182,7 +182,7 @@ bool  TextCtrl::bSetInitMsg( const wxString & rosMsg )
 
 bool  TextCtrl::bSetLinesMax( int iLines )
 {
-  if( iLines<TXTCTL_LINESMIN || iLines>TXTCTL_LINESMAX ) return( FALSE );
+  if( iLines<TCTL_LINESMIN || iLines>TCTL_LINESMAX ) return( FALSE );
 
   m_iLinesMax = iLines;
 
@@ -201,7 +201,7 @@ bool  TextCtrl::bSetLinesMax( int iLines )
 
 bool  TextCtrl::bSetLinesDsp( int iLines )
 {
-  if( iLines<TXTCTL_DISPMIN || iLines>TXTCTL_DISPMAX ) return( FALSE );
+  if( iLines<TCTL_DISPMIN || iLines>TCTL_DISPMAX ) return( FALSE );
 
   m_iLinesDsp = iLines;
 
